


******************************************************************
********************** 0. Create basic dataset **********************
******************************************************************

global path "C:\Users\okonj\Dropbox\Project Nordic Offshore Evasion\PaperInequality\WorkDenmark\RandomAudits"
global popsize = 12549036

/*** load data from main workbook ***/
clear all
import excel "$path\RandomAudits.xlsx", clear sheet("ToStata") firstrow
drop if year==.
drop U

/*** create numerical wealth group variable ***/
*28 wealth groups*
egen wealthgroup = group(ptile_w) 
*13 wealth groups used in main analysis of random audits *
gen wealthgroup2=wealthgroup
replace wealthgroup2=10 if wealthgroup>=10 & wealthgroup<=14
replace wealthgroup2=11 if wealthgroup>=15 & wealthgroup<=18
replace wealthgroup2=12 if wealthgroup>=19 & wealthgroup<=23
replace wealthgroup2=13 if wealthgroup>=24 & wealthgroup<=28
*14 wealth categories with separate top 0.1%*
gen wealthgroup3=wealthgroup2
replace wealthgroup3=14 if wealthgroup==24

/*** create variables for population size ***/
cap drop newnum*
by wealthgroup, sort: egen totpop = sum(num_all)
gen newnum_all = .
replace newnum_all = $popsize * (num_all/totpop) * 0.1 if wealthgroup<=9
replace newnum_all = $popsize * (num_all/totpop) * 0.01 if wealthgroup>=10 & wealthgroup<=18
replace newnum_all = $popsize* (num_all/totpop) * 0.001 if wealthgroup>=19 & wealthgroup<=28
gen newnum_wag = num_wag * (newnum_all/num_all)
gen newnum_se = num_se * (newnum_all/num_all)
sort year wealthgroup

/*** scale dataset up to "population size" ***/
expand newnum_all
gen obs=1

/*** create micro-observations for evasion ***/
by year ptile_w, sort: gen obsno = _n

/*** separate self-employed and wage earners ***/
gen selfemployed = .
replace selfemployed = 0 if obsno <= newnum_wag
replace selfemployed = 1 if obsno > newnum_wag & obsno <= newnum_all

/*** separate evaders from non-evaders ***/
gen haserror = .
replace haserror = 1 if obsno > 0    &    obsno <= newnum_wag * error_rate_wag
replace haserror = 0 if obsno > newnum_wag * error_rate_wag    &   obsno <= newnum_wag
replace haserror = 1 if obsno > newnum_wag   &   obsno <= (newnum_wag + newnum_se * error_rate_se)
replace haserror = 0 if obsno > (newnum_wag + newnum_se * error_rate_se)   &   obsno<=newnum_all

/*** create new error variable ***/
gen avg_error = .
replace avg_error = 0 if haserror==0
replace avg_error = error_inc_wag if haserror==1 & selfemployed==0
replace avg_error = error_inc_se if haserror==1 & selfemployed==1

/*** create new reported income variable (in sheet "DistribEvasion": column P * colum C / column G)  ***/
gen avg_income = .
replace avg_income = 166755 if wealthgroup2==1
replace avg_income = 110135 if wealthgroup2==2
replace avg_income = 143723 if wealthgroup2==3
replace avg_income = 183663 if wealthgroup2==4
replace avg_income = 212395 if wealthgroup2==5
replace avg_income = 238903 if wealthgroup2==6
replace avg_income = 264552 if wealthgroup2==7
replace avg_income = 285239 if wealthgroup2==8
replace avg_income = 303540 if wealthgroup2==9
replace avg_income = 334724 if wealthgroup2==10
replace avg_income = 429570 if wealthgroup2==11
replace avg_income = 658865 if wealthgroup2==12
replace avg_income = 1757238 if wealthgroup2==13

/*** create more granular wealth group measure for merge with sd information ***/
*(parameters from the sheet "Parameters" in the book "RandomAudits_20170623"*
gen wealthgroup0=wealthgroup
replace wealthgroup0=. if wealthgroup==28
*2008 - wage earners*
replace wealthgroup0 = 30 if wealthgroup==28 & year==2008 & haserror == 1 & selfemployed == 0 & obsno > 0 & obsno <= 0.5*(newnum_wag * error_rate_wag)
replace wealthgroup0 = 33 if wealthgroup==28 & year==2008 & haserror == 1 & selfemployed == 0 & obsno > 0.5*(newnum_wag * error_rate_wag) & obsno <= (newnum_wag * error_rate_wag)
*2008 - self-employed*
replace wealthgroup0 = 28 if wealthgroup==28 & year==2008 & haserror == 1 & selfemployed == 1 & obsno > newnum_wag   &   obsno <= newnum_wag + 0.18564*(newnum_se * error_rate_se)
replace wealthgroup0 = 29 if wealthgroup==28 & year==2008 & haserror == 1 & selfemployed == 1 & obsno > newnum_wag + 0.18564*(newnum_se * error_rate_se) & obsno <= newnum_wag + 0.38564*(newnum_se * error_rate_se)
replace wealthgroup0 = 33 if wealthgroup==28 & year==2008 & haserror == 1 & selfemployed == 1 & obsno > newnum_wag + 0.38564*(newnum_se * error_rate_se) & obsno <= newnum_wag + 0.60*(newnum_se * error_rate_se)
replace wealthgroup0 = 34 if wealthgroup==28 & year==2008 & haserror == 1 & selfemployed == 1 & obsno > newnum_wag + 0.6*(newnum_se * error_rate_se) & obsno <= newnum_wag + 0.80*(newnum_se * error_rate_se)
replace wealthgroup0 = 36 if wealthgroup==28 & year==2008 & haserror == 1 & selfemployed == 1 & obsno > newnum_wag + 0.8*(newnum_se * error_rate_se) & obsno <= (newnum_wag + newnum_se * error_rate_se)
*2010 - wage earners*
replace wealthgroup0 = 30 if wealthgroup==28 & year==2010 & haserror == 1 & selfemployed == 0 & obsno > 0 & obsno <= 0.333333*(newnum_wag * error_rate_wag)
replace wealthgroup0 = 34 if wealthgroup==28 & year==2010 & haserror == 1 & selfemployed == 0 & obsno > 0.333333*(newnum_wag * error_rate_wag) & obsno <= 0.666666*(newnum_wag * error_rate_wag)
replace wealthgroup0 = 36 if wealthgroup==28 & year==2010 & haserror == 1 & selfemployed == 0 & obsno > 0.666666*(newnum_wag * error_rate_wag) & obsno <= (newnum_wag * error_rate_wag)
*2010 - self-employed*
replace wealthgroup0 = 28 if wealthgroup==28 & year==2010 & haserror == 1 & selfemployed == 1 & obsno > newnum_wag   &   obsno <= newnum_wag + 0.121765601*(newnum_se * error_rate_se)
replace wealthgroup0 = 29 if wealthgroup==28 & year==2010 & haserror == 1 & selfemployed == 1 & obsno > newnum_wag + 0.121765601*(newnum_se * error_rate_se) & obsno <= newnum_wag + 0.365296804*(newnum_se * error_rate_se)
replace wealthgroup0 = 30 if wealthgroup==28 & year==2010 & haserror == 1 & selfemployed == 1 & obsno > newnum_wag + 0.365296804*(newnum_se * error_rate_se) & obsno <= newnum_wag + 0.487062405*(newnum_se * error_rate_se)
replace wealthgroup0 = 31 if wealthgroup==28 & year==2010 & haserror == 1 & selfemployed == 1 & obsno > newnum_wag + 0.487062405*(newnum_se * error_rate_se) & obsno <= newnum_wag + 0.608828006*(newnum_se * error_rate_se)
replace wealthgroup0 = 33 if wealthgroup==28 & year==2010 & haserror == 1 & selfemployed == 1 & obsno > newnum_wag + 0.608828006*(newnum_se * error_rate_se) & obsno <= newnum_wag + 0.730593607*(newnum_se * error_rate_se)
replace wealthgroup0 = 37 if wealthgroup==28 & year==2010 & haserror == 1 & selfemployed == 1 & obsno > newnum_wag + 0.730593607*(newnum_se * error_rate_se) & obsno <= (newnum_wag + newnum_se * error_rate_se)
*2012 - wage earners*
replace wealthgroup0 = 29 if wealthgroup==28 & year==2012 & haserror == 1 & selfemployed == 0 & obsno > 0 & obsno <= 0.5*(newnum_wag * error_rate_wag)
replace wealthgroup0 = 31 if wealthgroup==28 & year==2012 & haserror == 1 & selfemployed == 0 & obsno > 0.5*(newnum_wag * error_rate_wag) & obsno <= (newnum_wag * error_rate_wag)
*2012 - self-employed*
replace wealthgroup0 = 30 if wealthgroup==28 & year==2012 & haserror == 1 & selfemployed == 1 & obsno > newnum_wag   &   obsno <= newnum_wag + 0.141562854*(newnum_se * error_rate_se)
replace wealthgroup0 = 33 if wealthgroup==28 & year==2012 & haserror == 1 & selfemployed == 1 & obsno > newnum_wag + 0.141562854*(newnum_se * error_rate_se) & obsno <= newnum_wag + 0.29218573*(newnum_se * error_rate_se)
replace wealthgroup0 = 34 if wealthgroup==28 & year==2012 & haserror == 1 & selfemployed == 1 & obsno > newnum_wag + 0.29218573*(newnum_se * error_rate_se) & obsno <= newnum_wag + 0.433748584*(newnum_se * error_rate_se)
replace wealthgroup0 = 35 if wealthgroup==28 & year==2012 & haserror == 1 & selfemployed == 1 & obsno > newnum_wag + 0.433748584*(newnum_se * error_rate_se) & obsno <= newnum_wag + 0.575311438*(newnum_se * error_rate_se)
replace wealthgroup0 = 36 if wealthgroup==28 & year==2012 & haserror == 1 & selfemployed == 1 & obsno > newnum_wag + 0.575311438*(newnum_se * error_rate_se) & obsno <= newnum_wag + 0.716874292*(newnum_se * error_rate_se)
replace wealthgroup0 = 37 if wealthgroup==28 & year==2012 & haserror == 1 & selfemployed == 1 & obsno > newnum_wag + 0.716874292*(newnum_se * error_rate_se) & obsno <= (newnum_wag + newnum_se * error_rate_se)

/*** save dataset ***/
sort year wealthgroup0
save "$path\BootstrapStandardErrors\BootstrapDataset.dta", replace

/*** Prepare merge with sd information ***/
*read raw data*
clear all
import excel "$path\BootstrapStandardErrors\RandomAudits_20170623.xlsx", clear sheet("Tostata") firstrow
drop if year==.
egen wealthgroup0 = group(ptile_w) /*most detailed: 37 wealth groups*/
keep 	error_sd_se ///
		error_sd_wag /// 
		error_semean_wag ///
		error_n_wag ///
		error_semean_se ///
		error_n_se ///
		wealthgroup0 ///
		year
		
*correct standard deviations of errors from the first batch of data*
destring *, replace
drop error_sd_wag error_sd_se
gen error_sd_wag = error_semean_wag * (error_n_wag)^0.5 
gen error_sd_se = error_semean_se * (error_n_se)^0.5
replace error_sd_wag=0 if error_sd_wag==.
replace error_sd_se=0 if error_sd_se==.
*sort and save dataset*
sort year wealthgroup0
save "$path\BootstrapStandardErrors\BootstrapDataset_aux.dta", replace

/*** merge with sd information ***/
use "$path\BootstrapStandardErrors\BootstrapDataset.dta", clear
merge m:1 year wealthgroup0 using "$path\BootstrapStandardErrors\BootstrapDataset_aux.dta"
tab _merge
drop if _merge==2
drop _merge
erase "$path\BootstrapStandardErrors\BootstrapDataset_aux.dta" 

/*** add simulated error variable ***/
gen error = .
replace error = 0 if haserror==0
set seed 1
replace error = rnormal(error_inc_wag, error_sd_wag) if haserror==1 & selfemployed==0
replace error = rnormal(error_inc_se, error_sd_se) if haserror==1 & selfemployed==1

/*** Add average tax rates ***/
gen avg_taxrate = .
replace avg_taxrate = 0.32957892 if wealthgroup2==1
replace avg_taxrate = 0.304370758 if wealthgroup2==2
replace avg_taxrate = 0.319589228 if wealthgroup2==3
replace avg_taxrate = 0.343859511 if wealthgroup2==4
replace avg_taxrate = 0.35704747 if wealthgroup2==5
replace avg_taxrate = 0.363550348 if wealthgroup2==6
replace avg_taxrate = 0.370420221 if wealthgroup2==7
replace avg_taxrate = 0.376913136 if wealthgroup2==8
replace avg_taxrate = 0.38148342 if wealthgroup2==9
replace avg_taxrate = 0.387368805 if wealthgroup2==10
replace avg_taxrate = 0.423381194 if wealthgroup2==11
replace avg_taxrate = 0.489795916 if wealthgroup2==12
replace avg_taxrate = (0.019347851*0.524527265 + 0.004845575*0.549378369 + 0.007077793*0.521442439 + 0.008684337*0.497938948)/(0.019347851 + 0.004845575 + 0.007077793 + 0.008684337) if wealthgroup2==13
* in last row: average tax rates weighted by income shares *

/*** Add marginal tax rates ***/
gen marg_taxrate = .
replace marg_taxrate = 0.4221000 if wealthgroup2==1
replace marg_taxrate = 0.3805000 if wealthgroup2==2
replace marg_taxrate = 0.4258000 if wealthgroup2==3
replace marg_taxrate = 0.4352000 if wealthgroup2==4
replace marg_taxrate = 0.4454000 if wealthgroup2==5
replace marg_taxrate = 0.4568000 if wealthgroup2==6
replace marg_taxrate = 0.4670000 if wealthgroup2==7
replace marg_taxrate = 0.4759000 if wealthgroup2==8
replace marg_taxrate = 0.4815000 if wealthgroup2==9
replace marg_taxrate = 0.4862000 if wealthgroup2==10
replace marg_taxrate = 0.5152500 if wealthgroup2==11
replace marg_taxrate = 0.5584000 if wealthgroup2==12
replace marg_taxrate = (0.04*0.5657500 + 0.005*0.5672000 + 0.004*0.5552500 + 0.001*0.5600195)/0.05 if wealthgroup2==13

/*** Define sample size by wealthgroup ***/
gen temp = num_audited_wag + num_audited_se
by wealthgroup year, sort: replace temp =. if _n~=1
by wealthgroup2, sort: egen num_audited_all = sum(temp)
drop temp
*same for slightly more granular wealth groups
gen temp = num_audited_wag + num_audited_se
by wealthgroup year, sort: replace temp =. if _n~=1
by wealthgroup3, sort: egen num_audited_all3 = sum(temp)
drop temp


/*** save full dataset ***/
save "$path\BootstrapStandardErrors\BootstrapDataset.dta", replace

STOP

**********************************************************************************
**************** 1. Baseline estimates with standard errors **********************
**********************************************************************************


/*** Reconstruct baseline point estimates: with collapse ***/
use "$path\BootstrapStandardErrors\BootstrapDataset.dta", clear
collapse (mean) marg_taxrate avg_taxrate haserror avg_error avg_income (sum) obs, by(wealthgroup2)
gen error2trueincome = avg_error / (avg_income+avg_error)
gen taxevaded2trueincome = marg_taxrate * avg_error / (avg_income+avg_error)
gen taxpaid2trueincome = avg_taxrate * avg_income / (avg_income+avg_error)
gen evadedtax2taxliab = taxevaded2trueincome / (taxevaded2trueincome + taxpaid2trueincome)
gen errorrate_baseline = evadedtax2taxliab
gen errorrate_bs = .
gen errorrate_lower = .
gen errorrate_upper = .
gen errorrate_se = .
keep errorrate_* wealthgroup2
save "$path\BootstrapStandardErrors\Fig6_results", replace

/*** Create program that computes errorrate in new samples ****/
cap program drop ComputeErrorRate
program ComputeErrorRate, rclass
args y
cap drop taxevaded taxliab sum_taxevaded sum_taxliab evadedtax2taxliab
gen taxevaded = marg_taxrate * error
gen taxliab = avg_taxrate * (avg_income + error)
by wealthgroup2, sort: egen sum_taxevaded=sum(taxevaded)
by wealthgroup2, sort: egen sum_taxliab=sum(taxliab)
gen `y' = sum_taxevaded / sum_taxliab
sum `y', meanonly
return scalar x = r(mean)
end

/*** Loop over wealth groups ***/
forvalues i = 1/13 {

/*** Create smaller dataset with only one wealthgroup ***/
use "$path\BootstrapStandardErrors\BootstrapDataset.dta", clear
keep if wealthgroup2==`i'

/*** Determine sample size ***/
sum num_audited_all, d
global samplesize=r(mean)

/*** Use program to bootstrap disclosure rates and standard errors ***/
set seed 1
global noreps = 100
bootstrap r(x), reps($noreps) nowarn nodots size($samplesize): ComputeErrorRate evadedtax2taxliab

/*** save estimates in scalars ***/
matrix confintervals = e(ci_normal)
matrix pointestimates = e(b)
matrix V = e(V)
matrix standarderror = vecdiag(cholesky(diag(vecdiag(V))))
global pointest = pointestimates[1,1]
global lowerconf = confintervals[1,1]
global upperconf = confintervals[2,1]
global standarderror = standarderror[1,1]

/*** save estimates in dataset ***/
use "$path\BootstrapStandardErrors\Fig6_results", clear
replace errorrate_bs = $pointest if wealthgroup==`i'
replace errorrate_lower = $lowerconf if wealthgroup==`i'
replace errorrate_upper = $upperconf if wealthgroup==`i'
replace errorrate_se = $standarderror if wealthgroup==`i'
save "$path\BootstrapStandardErrors\Fig6_results", replace
}

/*** make nice graph ***/
label define categories 1 "P0-10" 2 "P10-20" 3 "P20-30" 4 "P30-40" 5 "P40-50" 6 "P50-60" 7 "P60-70" 8 "P70-80" 9 "P80-90" 10 "P90-95" 11 "P95-99" 12 "P99-99.5" 13 "P99.5-100" 
label values wealthgroup categories
twoway (connect errorrate_bs wealthgroup) (rcap errorrate_upper errorrate_lower wealthgroup), ///
scheme(s1mono) xlabel(1 2 3 4 5 6 7 8 9 10 11 12 13, valuelabel labsize(small) angle(90)) legend(off) ///
xtitle("wealth group") ytitle("error rate in random audits") note("number of replications in bootstrap: $noreps")
graph export "$path\BootstrapStandardErrors\Fig6_graph.pdf", as(pdf) replace


******************************************************************************************************
**************** 2. Estimates with slightly more granular wealth bins at the top *********************
******************************************************************************************************

/*** Reconstruct baseline point estimates: with collapse ***/
use "$path\BootstrapStandardErrors\BootstrapDataset.dta", clear
collapse (mean) marg_taxrate avg_taxrate haserror avg_error avg_income (sum) obs, by(wealthgroup3)
gen error2trueincome = avg_error / (avg_income+avg_error)
gen taxevaded2trueincome = marg_taxrate * avg_error / (avg_income+avg_error)
gen taxpaid2trueincome = avg_taxrate * avg_income / (avg_income+avg_error)
gen evadedtax2taxliab = taxevaded2trueincome / (taxevaded2trueincome + taxpaid2trueincome)
gen errorrate_baseline = evadedtax2taxliab
gen errorrate_bs = .
gen errorrate_lower = .
gen errorrate_upper = .
gen errorrate_se = .
keep errorrate_* wealthgroup3
save "$path\BootstrapStandardErrors\Fig6_results_withtop01", replace

/*** Create program that computes errorrate in new samples ****/
cap program drop ComputeErrorRate
program ComputeErrorRate, rclass
args y
cap drop taxevaded taxliab sum_taxevaded sum_taxliab evadedtax2taxliab
gen taxevaded = marg_taxrate * error
gen taxliab = avg_taxrate * (avg_income + error)
by wealthgroup3, sort: egen sum_taxevaded=sum(taxevaded)
by wealthgroup3, sort: egen sum_taxliab=sum(taxliab)
gen `y' = sum_taxevaded / sum_taxliab
sum `y', meanonly
return scalar x = r(mean)
end

/*** Loop over wealth groups ***/
forvalues i = 1/14 {

/*** Create smaller dataset with only one wealthgroup ***/
use "$path\BootstrapStandardErrors\BootstrapDataset.dta", clear
keep if wealthgroup3==`i'

/*** Determine sample size ***/
sum num_audited_all3, d
global samplesize=r(mean)

/*** Use program to bootstrap disclosure rates and standard errors ***/
set seed 1
global noreps = 100
bootstrap r(x), reps($noreps) nowarn nodots size($samplesize): ComputeErrorRate evadedtax2taxliab

/*** save estimates in scalars ***/
matrix confintervals = e(ci_normal)
matrix pointestimates = e(b)
matrix V = e(V)
matrix standarderror = vecdiag(cholesky(diag(vecdiag(V))))
global pointest = pointestimates[1,1]
global lowerconf = confintervals[1,1]
global upperconf = confintervals[2,1]
global standarderror = standarderror[1,1]

/*** save estimates in dataset ***/
use "$path\BootstrapStandardErrors\Fig6_results_withtop01", clear
replace errorrate_bs = $pointest if wealthgroup3==`i'
replace errorrate_lower = $lowerconf if wealthgroup3==`i'
replace errorrate_upper = $upperconf if wealthgroup3==`i'
replace errorrate_se = $standarderror if wealthgroup3==`i'
save "$path\BootstrapStandardErrors\Fig6_results_withtop01", replace
}

/*** make nice graph ***/
label define categories 1 "P0-10" 2 "P10-20" 3 "P20-30" 4 "P30-40" 5 "P40-50" 6 "P50-60" 7 "P60-70" 8 "P70-80" 9 "P80-90" 10 "P90-95" 11 "P95-99" 12 "P99-99.5" 13 "P99.5-P99.9" 14 "P99.9-P100"
label values wealthgroup3 categories
twoway (connect errorrate_bs wealthgroup3) (rcap errorrate_upper errorrate_lower wealthgroup3), ///
scheme(s1mono) xlabel(1 2 3 4 5 6 7 8 9 10 11 12 13 14, valuelabel labsize(small) angle(90)) legend(off) ///
xtitle("wealth group") ytitle("error rate in random audits") note("number of replications in bootstrap: $noreps")
graph export "$path\BootstrapStandardErrors\Fig6_graph_withtop01.pdf", as(pdf) replace

