*! Originally created by Niels, Dec. 2016
* Updated by GZ March 2017 (fixing bug on missing pension income)

*************************************************************************************
*************************************************************************************
*** This do-file computes the marginal tax on labor and wealth in Danmark in 2006 ***
***							(Niels, 16 December 2016) 							  **	*
*************************************************************************************
*************************************************************************************

/* Set directory */
* cd "C:\Users\okonj\Dropbox\Project Nordic Offshore Evasion\PaperInequality\WorkDenmark\TaxSystem"
/* Import test data */
* this imports 56 synthetic observations from test dataset *
* to run the file on real data: 
* 	- block out the import of test data
*	- unblock lines 37-40 + 99-101 that draw DST variables instead
* 	- define actual marginal portfolio weights in lines 93-96 
* import excel "TestData_TaxDenmark2006.xlsx", sheet("Sheet1") firstrow clear

***************************************
************ LABOR INCOME *************
***************************************


/* Parameters of the tax system */
global exemption1 = 38500
global exemption2 = 265500
global exemption3 = 318700
global payroll = 0.08
global municipal = 0.3333
global lowstate = 0.0548
global middlestate = 0.06
global highstate = 0.15

/* Pick relevant variables from DST */
gen capincome = RENTEINDK - QRENTUD2
gen laborincome = QSPLINDK - capincome // Assume QRENTUD2 is already subtracted from QSPLINDK (not clear it's true)
gen deductions = 0 // Already deducted from QSPLINDK. DST var is LIGNFRDP = union membership, child custody, transport etc.
gen pensioncontr = 0 // Already deducted from QSPLINDK.  DST var is ANDFRAD but we don't have it  

/* Actual tax payments */
* Auxilary variables *
gen persincome = laborincome*(1-$payroll) - pensioncontr
gen beskdeduction = min(7300, 0.025*laborincome)
gen taxincome = persincome + capincome - deductions - beskdeduction
gen poscapincome = 0 
replace poscapincome = capincome if capincome >= 0 & capincome != .
* Define income tax bill *
gen payrollpay = max(0,$payroll*laborincome)
gen muntaxpay = max(0,taxincome-$exemption1)*$municipal
gen statetax1pay = max(0,persincome + poscapincome - $exemption1)*$lowstate
gen statetax2pay = max(0,persincome + poscapincome - $exemption2)*$middlestate
gen statetax3pay = max(0,persincome + poscapincome - $exemption3)*$highstate
gen totalinctax = payrollpay + muntaxpay + statetax1pay + statetax2pay + statetax3pay


/* Counterfactual tax payments with labor income 1,000 DKK higher*/
* Auxilary variables *
gen laborincomeX = laborincome + 1000
gen persincomeX = laborincomeX*(1-$payroll) - pensioncontr
gen beskdeductionX = min(7300, 0.025*laborincomeX)
gen taxincomeX = persincomeX + capincome - deductions - beskdeductionX
* Define income tax bill *
gen payrollpayX = max(0,laborincomeX*$payroll)
gen muntaxpayX = max(0,taxincomeX-$exemption1)*$municipal
gen statetax1payX = max(0,persincomeX + poscapincome - $exemption1)*$lowstate
gen statetax2payX = max(0,persincomeX + poscapincome - $exemption2)*$middlestate
gen statetax3payX = max(0,persincomeX + poscapincome - $exemption3)*$highstate
gen totalinctaxX = payrollpayX + muntaxpayX + statetax1payX + statetax2payX + statetax3payX

/* Marginal tax on labor income */
gen margtaxrate_labor = (totalinctaxX - totalinctax) / 1000


***************************************
************ CAPITAL INCOME ***********
***************************************

/* Parameters of the tax system */
global share1incrate = 0.28
global share2incrate = 0.43
global exemption_share = 44300
global house1rate = 0.01
global house2rate = 0.03
global exemption_house = 3040000
global landrate = 0.024

/* Define return */
global return = 0.02

/* Define marginal portfolio weights */
global weight_share = 1.0
global weight_house = 0
global weight_land = 0
global weight_bond = 0

/* Pick relevant variables from DST */
gen shareincome = AKTIEINDK 
gen housevalue = KOEJD
gen landvalue = 0 /*I cannot find this variable in the register but it shouldn't matter since the rate is flat*/

/* Actual tax payments */
* Define tax bills for share income, property and land (all except interest which is linked to labor income taxation)*
gen share1tax = max(0, shareincome)*$share1incrate
gen share2tax = max(0, shareincome - $exemption_share) * ($share2incrate - $share1incrate) 
*gen house1tax = max(0, housevalue)*$house1rate
*gen house2tax = max(0, housevalue - $exemption_house) * ($house2rate - $house1rate)
* gen landtax = max(0, landvalue)*$landrate 

/* Counterfactual tax payments with income / wealth 1 DKK higher */
* Auxilary variables *
gen shareincomeY = shareincome + 1000
gen housevalueY = housevalue + 1000
gen landvalueY = landvalue + 1000
gen capincomeY = capincome + 1000
gen taxincomeY = persincome + capincomeY - deductions - beskdeduction
gen poscapincomeY = 0 
replace poscapincomeY = capincomeY if capincomeY >= 0
* Define tax bills for all except interest income*
gen share1taxY = max(0, shareincomeY)*$share1incrate
gen share2taxY = max(0, shareincomeY - $exemption_share) * ($share2incrate - $share1incrate) 
gen house1taxY = max(0, housevalueY)*$house1rate
gen house2taxY = max(0, housevalueY - $exemption_house) * ($house2rate - $house1rate)
gen landtaxY = max(0, landvalueY)*$landrate 
* Define tax bill for labor + interest income*
gen muntaxpayY = max(0,taxincomeY-$exemption1)*$municipal
gen statetax1payY = max(0,persincome + poscapincomeY - $exemption1)*$lowstate
gen statetax2payY = max(0,persincome + poscapincomeY - $exemption2)*$middlestate
gen statetax3payY = max(0,persincome + poscapincomeY - $exemption3)*$highstate
gen totalinctaxY = payrollpay + muntaxpayY + statetax1payY + statetax2payY + statetax3payY

/* Marginal tax increase by investing an additional DKK 1,000 - each asset class separately */
gen margtaxshare = $return * (share1taxY + share2taxY - share1tax - share2tax)
gen margtaxhouse = house1taxY + house2taxY - house1tax - house2tax
gen margtaxland = landtaxY - landtax
gen margtaxbond = $return * (totalinctaxY - totalinctax)

/* Total marginal tax on capital */
gen margtaxrate_capital =  ///
	($weight_share * margtaxshare + ///
	 $weight_house * margtaxhouse + ///
	 $weight_land * margtaxland + ///
	 $weight_bond * margtaxbond)  ///
	/ ($return * 1000)


* Export marginal tax rates by g-percentile of market value wealth
	rename margtaxrate_capital rate_capital
	rename margtaxrate_labor rate_labor
    collapse (sum) wealth QSPLINDK AKTIEINDK SKATTOT_NY (max) rate_labor rate_capital, by(household_ID)
    gperc wealth QSPLINDK AKTIEINDK SKATTOT_NY rate_labor rate_capital, matname(rate_dkk_06)
		clear
		svmat rate_dkk_06, names(col)
		qui compress
		export excel using "taxrate_DKK06.xlsx", first(var) replace 





** Notes
// RENTEINDK = interest income
// QRENTUD2 = deductible interest expense
// LOENMV = taxable wage earnings, including fringe benefits & stock options
// QSPLINDK = taxable income ("Taxable income is equal to all income that comes to general taxation, reduced by a number of deductions.")
// The principal deductions are: - employee deductions (transportation, unemployment insurance and union dues) 
// - overdue interest payments 
// - payments to private pension plans 
// QSPLINDK excluds AKTIEINDK (taxed separately since 1991)

