
clear
set more off

**************************************************************************************
* Voluntary disclosure data
* Cleans raw data set for multiple observations per case, and generates variables
* Also merge to family info and generate variables for parents being disclosers 
***************************************************************************************

	global prog   "\\...\CLEAN\prog"
	global source "\\...\source_data\no"
	global data   "\\...\CLEAN\data"
    global temp   "\\...\data\no-backup"
 
cap log close
log using $prog\makedata0_disclosersCLEAN.log, replace

* Raw voluntary disclosure data 2007-2014
use $source\frivillig_retting.dta, clear
  rename FNR_NN ID
  duplicates drop
  drop if ID==.
  gen vd_case_in_process=(I_ARBEID=="J")
  gen vd_case_dropped=(henlagt=="J")
  gen vd_case_closed=(VEDTAK_AAR!=.)  
  rename KONTAKT_AAR  vd_year_of_contact
  rename VEDTAK_AAR vd_year_of_decision
  rename inntekt vd_taxed_disclosed_income
  rename formue vd_taxed_disclosed_wealth
  rename land vd_disclosed_country
  drop I_ARBEID henlagt
 
*fix duplicates, where one is without country and/or amounts, and the others are
  duplicates tag ID, gen(x) 
  sort x ID vd_disclosed_country 
  replace vd_taxed_disclosed_income=0 if vd_taxed_disclosed_income==.
  replace vd_taxed_disclosed_wealth=0 if vd_taxed_disclosed_wealth==.
  
  collapse (max) vd_case_in_process  vd_case_dropped vd_case_closed (min) vd_year_of_contact vd_year_of_decision (last) vd_disclosed_country (sum) vd_taxed_disclosed_income vd_taxed_disclosed_wealth, by(ID)
 
  replace vd_taxed_disclosed_income=. if vd_taxed_disclosed_income==0
  replace vd_taxed_disclosed_wealth=. if vd_taxed_disclosed_wealth==0
  replace vd_case_closed=0 if vd_case_dropped==1
  replace vd_case_in_process=0 if vd_case_dropped==1
  label var vd_year_of_contact "year of first contact for voluntary disclosure"
  label var vd_taxed_disclosed_income "Total increased taxable income, sum all years, for closed cases, voluntary disclosure"
  label var vd_taxed_disclosed_wealth "Total increased wealth, sum all years, for closed cases, voluntary disclosure"
  label var vd_year_of_decision "Year of closure of case, voluntary disclosure"
  label var vd_disclosed_country "The country where infome/wealth originates, voluntary disclosure"
  label var vd_case_closed "case closed, voluntary disclosure"
  label var vd_case_dropped "case dropped, voluntary disclosure"
  label var vd_case_in_process "case still in process, voluntary disclosure"
  sort ID
save $temp\vd_orig.dta, replace

 
*** 2015-update
 use $source\nye_vd_data_2015\frivillig_retting_2015.dta, clear
  rename FNR_NN ID
  duplicates drop
  drop if ID==.
  gen vd_case_in_process=(I_ARBEID=="J")
  gen vd_case_dropped=(henlagt=="J")
  gen vd_case_closed=(VEDTAK_AAR!=.)  
  rename KONTAKT_AAR  vd_year_of_contact
  rename VEDTAK_AAR vd_year_of_decision
  rename inntekt vd_taxed_disclosed_income
  rename formue vd_taxed_disclosed_wealth
  rename land vd_disclosed_country
  rename ANTALL_AAR vd_number_years
  drop I_ARBEID henlagt
 
*fix duplicates, where one is without country and/or amounts, and the others are
  duplicates tag ID, gen(x)
  sort x ID vd_disclosed_country 
  replace vd_taxed_disclosed_income=0 if vd_taxed_disclosed_income==.
  replace vd_taxed_disclosed_wealth=0 if vd_taxed_disclosed_wealth==.
  replace vd_number_years=0 if vd_number_years==.

  collapse (max) vd_case_in_process  vd_case_dropped vd_case_closed vd_number_years (min) vd_year_of_contact vd_year_of_decision (last) vd_disclosed_country (sum) vd_taxed_disclosed_income vd_taxed_disclosed_wealth, by(ID)
 
  replace vd_taxed_disclosed_income=. if vd_taxed_disclosed_income==0
  replace vd_taxed_disclosed_wealth=. if vd_taxed_disclosed_wealth==0
  replace vd_number_years=. if vd_number_years==0
  replace vd_case_closed=0 if vd_case_dropped==1
  replace vd_case_in_process=0 if vd_case_dropped==1
  label var vd_year_of_contact "year of first contact for voluntary disclosure"
  label var vd_taxed_disclosed_income "Total increased taxable income, sum all years, for closed cases, voluntary disclosure"
  label var vd_taxed_disclosed_wealth "Total increased wealth, sum all years, for closed cases, voluntary disclosure"
  label var vd_year_of_decision "Year of closure of case, voluntary disclosure"
  label var vd_disclosed_country "The country where infome/wealth originates, voluntary disclosure"
  label var vd_case_closed "case closed, voluntary disclosure"
  label var vd_case_dropped "case dropped, voluntary disclosure"
  label var vd_case_in_process "case still in process, voluntary disclosure"
  label var vd_number_years "number of years for the disclosure"
  sort ID
save $temp\vd_update15.dta, replace
 
  
*** 2016-update
use $source\nye_vd_sept2016\frivillig_retting_2016_cleaned.dta
  rename FNR_NN ID
  duplicates drop
  drop if ID==.
  gen vd_case_in_process=(I_ARBEID=="J")
  gen vd_case_dropped=(henlagt=="J")
  gen vd_case_closed=(VEDTAK_AAR!=.)  
  rename KONTAKT_AAR  vd_year_of_contact
  rename VEDTAK_AAR vd_year_of_decision
  rename inntekt vd_taxed_disclosed_income
  rename formue vd_taxed_disclosed_wealth
  rename land vd_disclosed_country
  drop I_ARBEID henlagt
 
*fix duplicates, where one is without country and/or amounts, and the others are
  duplicates tag ID, gen(x)
  sort x ID vd_disclosed_country 
  replace vd_taxed_disclosed_income=0 if vd_taxed_disclosed_income==.
  replace vd_taxed_disclosed_wealth=0 if vd_taxed_disclosed_wealth==.
  replace vd_number_years=0 if vd_number_years==.
 
 collapse (max) vd_case_in_process  vd_case_dropped vd_case_closed vd_number_years (min) vd_year_of_contact vd_year_of_decision (last) vd_disclosed_country (sum) vd_taxed_disclosed_income vd_taxed_disclosed_wealth, by(ID)
 
  replace vd_taxed_disclosed_income=. if vd_taxed_disclosed_income==0
  replace vd_taxed_disclosed_wealth=. if vd_taxed_disclosed_wealth==0
  replace vd_number_years=. if vd_number_years==0
  replace vd_case_closed=0 if vd_case_dropped==1
  replace vd_case_in_process=0 if vd_case_dropped==1
  label var vd_year_of_contact "year of first contact for voluntary disclosure"
  label var vd_taxed_disclosed_income "Total increased taxable income, sum all years, for closed cases, voluntary disclosure"
  label var vd_taxed_disclosed_wealth "Total increased wealth, sum all years, for closed cases, voluntary disclosure"
  label var vd_year_of_decision "Year of closure of case, voluntary disclosure"
  label var vd_disclosed_country "The country where infome/wealth originates, voluntary disclosure"
  label var vd_case_closed "case closed, voluntary disclosure"
  label var vd_case_dropped "case dropped, voluntary disclosure"
  label var vd_case_in_process "case still in process, voluntary disclosure"
  label var vd_number_years "number of years for the disclosure"
  sort ID
save $temp\vd_update16.dta, replace
 
 
 *Now merge all these cases and make one file, with updated case closed status
use $temp\vd_orig.dta, clear
  gen x=1
  append using $temp\vd_update15.dta
  replace x=2 if x==.
  duplicates report ID
  sort ID x vd_disclosed_country 
  replace vd_number_years=0 if vd_number_years==.
  
  collapse (last) vd_case_in_process  vd_case_dropped vd_case_closed vd_year_of_decision  vd_disclosed_country vd_taxed_disclosed_income vd_taxed_disclosed_wealth (first) vd_year_of_contact (max) vd_number_years, by(ID)

  replace vd_number_years=. if vd_number_years==0
  replace vd_case_closed=0 if vd_case_dropped==1
  replace vd_case_in_process=0 if vd_case_dropped==1
  
  gen x=1
  append using $temp\vd_update16.dta
  replace x=2 if x==.
  duplicates report ID
  sort ID x vd_disclosed_country 
  replace vd_number_years=0 if vd_number_years==.
  
  collapse (last) vd_case_in_process  vd_case_dropped vd_case_closed vd_year_of_decision  vd_disclosed_country vd_taxed_disclosed_income vd_taxed_disclosed_wealth (first) vd_year_of_contact (max) vd_number_years, by(ID)

  replace vd_number_years=. if vd_number_years==0
  replace vd_case_closed=0 if vd_case_dropped==1
  replace vd_case_in_process=0 if vd_case_dropped==1
  replace vd_year_of_contact=2016 if vd_year_of_contact==2106
  tab vd_year_of_contact, m 
 
* Fix year of contact
 forvalues y=2006(1)2016 {
  replace vd_year_of_contact = `y' if vd_year_of_contact>=`y' & vd_year_of_contact<`y'+1
 }
 
*Make common contry codes as the other data
  replace vd_disclosed_country=	"99"	 if	  vd_disclosed_country==	"Annet - få obs" 
  replace vd_disclosed_country= "99" if  substr(vd_disclosed_country,1,3)=="Ann" 
  replace vd_disclosed_country=	"AU"	 if	  vd_disclosed_country==	"Australia"
  replace vd_disclosed_country=	"BE"	 if	  vd_disclosed_country==	"Belgia"
  replace vd_disclosed_country=	"BR"	 if	  vd_disclosed_country==	"Brasil"
  replace vd_disclosed_country=	"CA"	 if	  vd_disclosed_country==	"Canada"
  replace vd_disclosed_country=	"DK"	 if	  vd_disclosed_country==	"Danmark"
  replace vd_disclosed_country=	"AE"	 if	  vd_disclosed_country==	"Dubai"
  replace vd_disclosed_country=	"EE"	 if	  vd_disclosed_country==	"Estland"
  replace vd_disclosed_country=	"PH"	 if	  vd_disclosed_country==	"Filippinene"
  replace vd_disclosed_country=	"FI"	 if	  vd_disclosed_country==	"Finland"
  replace vd_disclosed_country=	"FR"	 if	  vd_disclosed_country==	"Frankrike"
  replace vd_disclosed_country=	"GI"	 if	  vd_disclosed_country==	"Gibraltar"
  replace vd_disclosed_country=	"GG"	 if	  vd_disclosed_country==	"Guernsey"
  replace vd_disclosed_country=	"GR"	 if	  vd_disclosed_country==	"Hellas"
  replace vd_disclosed_country=	"HK"	 if	  vd_disclosed_country==	"Hong Kong"
  replace vd_disclosed_country=	"IN"	 if	  vd_disclosed_country==	"India"
  replace vd_disclosed_country=	"IE"	 if	  vd_disclosed_country==	"Ireland"
  replace vd_disclosed_country=	"IE"	 if	  vd_disclosed_country==	"Irland"
  replace vd_disclosed_country=	"IM"	 if	  vd_disclosed_country==	"Isle"
  replace vd_disclosed_country=	"IM"	 if	  vd_disclosed_country==	"Isle of Man"
  replace vd_disclosed_country=	"IM"	 if  substr(vd_disclosed_country,1,4)==	"Isle"
  replace vd_disclosed_country=	"IT"	 if	  vd_disclosed_country==	"Italia"
  replace vd_disclosed_country=	"IT"	 if	  vd_disclosed_country==	"Italia/Spania"
  replace vd_disclosed_country=	"JE"	 if	  vd_disclosed_country==	"Jersey"
  replace vd_disclosed_country=	"JE"	 if  substr(vd_disclosed_country,1,4)==	"Jers"
  replace vd_disclosed_country=	"JE"	 if  substr(vd_disclosed_country,4,4)==	"Jers"
  replace vd_disclosed_country=	"CY"	 if	  vd_disclosed_country==	"Kypros"
  replace vd_disclosed_country=	"LI"	 if	  vd_disclosed_country==	"Lichtenstein"
  replace vd_disclosed_country=	"LI"	 if	  vd_disclosed_country==	"Liechtenstein"
  replace vd_disclosed_country=   "LT"     if   vd_disclosed_country==     "Litauen"
  replace vd_disclosed_country=	"LU"	 if	  vd_disclosed_country==	"Luxembourg"
  replace vd_disclosed_country=	"LU"	 if	  vd_disclosed_country==	"Luxemburg"
  replace vd_disclosed_country=	"LU"	 if	  vd_disclosed_country==	"Luxemburg og Luxembourg"
  replace vd_disclosed_country=	"MO"	 if	  vd_disclosed_country==	"macau"
  replace vd_disclosed_country=	"NL"	 if	  vd_disclosed_country==	"Nederland"
  replace vd_disclosed_country=	"NO"	 if	  vd_disclosed_country==	"Norge"
  replace vd_disclosed_country=	"PK"	 if	  vd_disclosed_country==	"Pakistan"
  replace vd_disclosed_country=	"PL"	 if	  vd_disclosed_country==	"Polen og Norge"
  replace vd_disclosed_country=	"PT"	 if	  vd_disclosed_country==	"Portugal"
  replace vd_disclosed_country=	"SC"	 if	  vd_disclosed_country==	"Seychellene"
  replace vd_disclosed_country=	"SG"	 if	  vd_disclosed_country==	"Singapore"
  replace vd_disclosed_country=	"ES"	 if	  vd_disclosed_country==	"Spania"
  replace vd_disclosed_country=	"GB"	 if	  vd_disclosed_country==	"England og Storbritania" 
  replace vd_disclosed_country=	"GB"	 if	  vd_disclosed_country==	"England"
  replace vd_disclosed_country=	"GB"	 if	  vd_disclosed_country==	"Storbritania"
  replace vd_disclosed_country=	"GB"	 if	  vd_disclosed_country==	"Storbritannia"
  replace vd_disclosed_country=	"GB"	 if	  vd_disclosed_country==	"Irland, Storbritt."
  replace vd_disclosed_country=	"GB"	 if	  vd_disclosed_country==	"Skottland"
  replace vd_disclosed_country=	"GB"	 if	  vd_disclosed_country==	"UK"
  replace vd_disclosed_country=	"CH"	 if	  vd_disclosed_country==	"Sveits"
  replace vd_disclosed_country=	"CH"	 if	  vd_disclosed_country==	"Sveits "
  replace vd_disclosed_country=	"SE"	 if	  vd_disclosed_country==	"Sverige"
  replace vd_disclosed_country=	"ZA"	 if	  substr(vd_disclosed_country,3,8)=="r-Afrika"   
  replace vd_disclosed_country=	"TH"	 if	  vd_disclosed_country==	"Thailand"
  replace vd_disclosed_country=	"CZ"	 if	  vd_disclosed_country==	"Tsjekkia"
  replace vd_disclosed_country=	"TR"	 if	  vd_disclosed_country==	"Tyrkia"
  replace vd_disclosed_country=	"DE"	 if	  vd_disclosed_country==	"Tyskland"
  replace vd_disclosed_country=	"US"	 if	  vd_disclosed_country==	"USA"
  replace vd_disclosed_country=	"US"	 if	  vd_disclosed_country==	"Usa"
  replace vd_disclosed_country=	"HU"	 if	  vd_disclosed_country==	"Ungarn"
  replace vd_disclosed_country=	"AT"	 if	  vd_disclosed_country==	"Østerrike"
  replace vd_disclosed_country=	"AT"	 if	  substr(vd_disclosed_country,2,3)=="ste"
  replace vd_disclosed_country=	"US"	 if	  vd_disclosed_country==	"USA "
  replace vd_disclosed_country=	"LU"	 if	  vd_disclosed_country==	"Luxenbourg"
  replace vd_disclosed_country=	"IT"	 if	  vd_disclosed_country==	"Italia "
  replace vd_disclosed_country=	""	     if	  vd_disclosed_country==	"Forhåndsvarsel"
  replace vd_disclosed_country=	"BE"	 if	  vd_disclosed_country==	"Belgia "
  replace vd_disclosed_country=	"KY"	 if	  vd_disclosed_country==	"Cayman Island"
  replace vd_disclosed_country=	"KY"	 if	  vd_disclosed_country==	"Cayman Islands"
  replace vd_disclosed_country=	"QA"	 if	  vd_disclosed_country==	"Qatar"
  replace vd_disclosed_country=	"VG"	 if	  vd_disclosed_country==	"British Virgin Islands"
  replace vd_disclosed_country=	"ID"	 if	  vd_disclosed_country==	"Indonesia"
  replace vd_disclosed_country=	"IS"	 if	  vd_disclosed_country==	"Island"
  replace vd_disclosed_country=	"MT"	 if	  vd_disclosed_country==	"Malta"
  replace vd_disclosed_country=	"NZ"	 if	  vd_disclosed_country==	"New Zealand"
  replace vd_disclosed_country=	"RU"	 if	  vd_disclosed_country==	"Russland"
  replace vd_disclosed_country=	"KR"	 if	  vd_disclosed_country==	"Sør-Korea"
 
  tab vd_year_of_contact, m
  tab vd_year_of_decision, m
  tab vd_case_dropped, m
  tab vd_case_in_process, m
  tab vd_case_closed, m
  tab vd_disclosed_country, m
  sort ID
  sum
save $data\voluntary_disclosure.dta, replace 

********* 
 
*make a dataset with indicator wether individual ever report foreign income, all cases included 
  keep ID 
  sort ID
  gen vd_evader=1
  label var vd_evader "Has ever self-reported any foreign hidden wealth or income"
save  $data\vd_dummy.dta, replace

**********
                                                   
* Make dummy for parent being discloser and year of first contact for parent discloser

use $data\voluntary_disclosure.dta, clear
  keep ID vd_year_of_contact
  rename vd_year_of_contact parent_year_of_contact
  gen parent_evader=1
  sort ID
save $temp\parvd.dta, replace
 
* Make parent data set
use $source\slekt.dta, clear
  keep if KNY_KNYTNING_TYPE=="FORE"
  drop KNY_KNYTNING_TYPE
  rename FNR_FRA_NN childID
  rename FNR_TIL_NN ID
  duplicates drop
  sort ID
		
  merge m:1 ID using $temp\parvd.dta
  drop if _m==2
  keep childID parent_evader parent_year_of_contact 
  replace parent_evader=0 if parent_evader==.
  rename childID ID
  tab parent_evader
  sort ID
	
*have to collapse on individual level, one obs per individual
  replace parent_year_of_contact=5000 if parent_year_of_contact==.
  
  collapse (max) parent_evader (min) parent_year_of_contact, by(ID)
	
  label var parent_evader "parent is voluntary discloser"
  label var parent_year_of_contact "year of vd-parent first disclosure"
  tab parent_evader, m
  replace parent_year_of_contact=. if parent_year_of_contact==5000
  tab parent_year_of_contact, m
  sort ID
  compress
save  $data\parent_vd.dta, replace

********
* add info on corretions in tax statements following disclosure

use $source\nye_vd_data_2015\endringer_sa_poster.dta, clear
  drop if diff_alminnt==0 & diff_nettoformue==0
  
  foreach var in diff_f_housing diff_f_business diff_f_shares diff_f_bonds diff_f_deposit diff_f_foreignshares diff_f_foreignbonds diff_nettoformue diff_alminnt {
   replace `var'=0 if `var'==.
  }

  replace diff_f_shares = diff_f_shares + diff_f_foreignshares
  replace diff_f_bonds = diff_f_bonds + diff_f_foreignbonds
  drop diff_f_foreignshares diff_f_foreignbonds
 
 *make annual data sets to 
  sort ID year
  
  foreach yr in 01 02 03 04 05 06 07 08 09 10 11 12 13 {
   preserve
   keep if year==20`yr'
   drop year
   sort ID
   foreach var in diff_f_housing diff_f_business diff_f_shares diff_f_bonds diff_f_deposit diff_nettoformue diff_alminnt {
    sum `var', det
    count if `var'!=0
   }
   rename diff_f_deposit diff_f_deposits
   save $temp\corr_`yr'.dta, replace
   restore
   }

 ********
clear
cap log close
