
clear
set more off

******  makedata1_individual_caracteristics.do ****************************
*                                                    
* Construct socio-economic variables from various sources on individuals
* Note: raw data has been modified prior to delivery in order to keep anonymity of observations
*
* Migration info is from year 2013, with migration data going far back
*
* Part A: Individual characteristics 
* Part C: 80% rule
* Part D: combines datasets 
*
***************************************************************************

	global prog "\\...\data\durable\CLEAN\prog"
	global source "\\...\data\durable\source_data\no"
	global data "\\...\data\durable\CLEAN\data"
    global temp "\\...\data\no-backup"

cap log close
log using $prog\makedata1_individual_caracteristicCLEAN.log, replace


************************************************************************
*** PART A: INDIVIDUAL CHARACTERISTICS ***
************************************************************************

use $source\dsf.dta, clear
	
/* Fix spouse problem: same individual is listed as spouse to multiple individuals, 
   and consistently over time. It appears that if a couple is divorced/separated, 
   the person of interest is listed with the ID of the ex-spouse if the person of 
   interest has not remarried. However, the ex-spouse can remarry, and will then 
   also be listed as spouse of another person. This is particularly current in the 
   earlier years */

	*how many are we talking of, by year how many spouses have multiple registrations as spouses?
	duplicates tag ektf_fn aar , generate(bigamy)
	tab aar bigamy
	*sivilstand=2 means married, 4=divorced, 5=separated, 3=widow(er), 1=single
	tab aar sivilstand if bigamy>0 & bigamy<6
	*remove the spouse from a person of interest, if registered as divorced/separated
	replace ektf_fnr=. if sivilstand=="4" | sivilstand=="5" 
	drop bigamy
	
/* Fix duplicates of the IDs for non-native Norwegians.
    Immigration: use first data
	Migration: use last data
	Country: give uncertain country, could be due to persons with uncertain identity
	County: person can have moved. keep then the county when ind_status-code is 1.
	Married/unmarried: keep married (cannot changes from married to unmarried, would then change to divorced) */

	sort fnr_nn aar
	duplicates tag fnr_nn aar , generate(dupl)
	tab aar dupl
save $temp\temp1.dta, replace

	keep if dupl > 0
	duplicates drop
	sort fnr_nn aar 
	destring fylke, replace
	replace ektf_fnr=0 if ektf_fnr==.
	replace dsf_status_kode2=9 if ektf_fnr==.
	replace fylke=0 if fylke==.
	collapse (max) fylke (min) dsf_status_kode2 (max) ektf_fnr (first) fodselaar kjonn sivilstand utlandsforbindelse2 fra_land2 fra_land_aar til_land2 til_land_aar, by(fnr_nn aar)
	tostring fylke, replace
	replace ektf_fnr=. if ektf_fnr==0
save $temp\temp2.dta, replace
use  $temp\temp1.dta, clear
	drop if dupl>0
	drop dupl
	append using $temp\temp2.dta
	sort fnr_nn aar
	duplicates report fnr_nn aar 
	
	rename aar year
	rename fnr_nn ID
	rename ektf_fnr ind_ID_spouse
	rename fylke ind_county
	rename fodselaar ind_birth_year
	rename dsf_status_kode2 ind_status
	replace ind_status=. if ind_status==99
	rename sivilstand ind_marital
	rename utlandsforbindelse2 ind_foreign_country
	rename fra_land2 ind_immigration_country
	rename fra_land_aar ind_immigration_year
	rename til_land2 ind_emigration_country
	rename til_land_aar ind_emigration_year
	gen ind_male=1 if kjonn=="M"
	replace ind_male=0 if kjonn=="K"
	tab ind_male, m
	drop kjonn
	label var ind_birth_year "Birth year, rounded to closest ten year"
	label var ind_county "fylke, first two cifers of municipality code"
	label var ind_status "1:Resident, 3:Emigrated, 5:Dead"
	label var ind_male "sex, 1 if male, 0 if female"
	label var ind_marital "1:unmarried, 2:married, 3:widow/er, 4:divorced, 5:separated"
	label var ind_foreign_country "foreign nationality or birth country, 99fewobs"
	label var ind_immigration_country "immigrating from this country"
	label var ind_immigration_year "immigrating this year"
	label var ind_emigration_country "emmigrating to this country"
	label var ind_emigration_year "emmigrating this year"
	label var ind_ID_spouse "unique individual identifier of spouse"
	label var ID "unique individual identifier"

* Recoding foreign nationality / birth country
	replace ind_foreign_country="99" if ind_foreign_country=="Få obs"
	replace ind_foreign_country="AL" if ind_foreign_country=="111"
	replace ind_foreign_country="AD" if ind_foreign_country=="114"
	replace ind_foreign_country="BE" if ind_foreign_country=="112"
	replace ind_foreign_country="BA" if ind_foreign_country=="155"
	replace ind_foreign_country="BG" if ind_foreign_country=="113"
	replace ind_foreign_country="DK" if ind_foreign_country=="101"
	replace ind_foreign_country="EE" if ind_foreign_country=="115"
	replace ind_foreign_country="FI" if ind_foreign_country=="103"
	replace ind_foreign_country="FR" if ind_foreign_country=="117"
	replace ind_foreign_country="FO" if ind_foreign_country=="104"
	replace ind_foreign_country="GI" if ind_foreign_country=="118"
	replace ind_foreign_country="GL" if ind_foreign_country=="102"
	replace ind_foreign_country="GG" if ind_foreign_country=="162"
	replace ind_foreign_country="GR" if ind_foreign_country=="119"
	replace ind_foreign_country="BY" if ind_foreign_country=="120"
	replace ind_foreign_country="IE" if ind_foreign_country=="121"
	replace ind_foreign_country="IS" if ind_foreign_country=="105"
	replace ind_foreign_country="IT" if ind_foreign_country=="123"
	replace ind_foreign_country="JE" if ind_foreign_country=="163"
	replace ind_foreign_country="XK" if ind_foreign_country=="161"
	replace ind_foreign_country="HR" if ind_foreign_country=="122"
	replace ind_foreign_country="CY" if ind_foreign_country=="500"
	replace ind_foreign_country="LV" if ind_foreign_country=="124"
	replace ind_foreign_country="LI" if ind_foreign_country=="128"
	replace ind_foreign_country="LT" if ind_foreign_country=="136"
	replace ind_foreign_country="LU" if ind_foreign_country=="129"
	replace ind_foreign_country="MK" if ind_foreign_country=="156"
	replace ind_foreign_country="MT" if ind_foreign_country=="126"
	replace ind_foreign_country="IM" if ind_foreign_country=="164"
	replace ind_foreign_country="MD" if ind_foreign_country=="138"
	replace ind_foreign_country="MC" if ind_foreign_country=="130"
	replace ind_foreign_country="ME" if ind_foreign_country=="160"
	replace ind_foreign_country="NL" if ind_foreign_country=="127"
	replace ind_foreign_country="NO" if ind_foreign_country=="0"
	replace ind_foreign_country="PL" if ind_foreign_country=="131"
	replace ind_foreign_country="PT" if ind_foreign_country=="132"
	replace ind_foreign_country="RO" if ind_foreign_country=="133"
	replace ind_foreign_country="RU" if ind_foreign_country=="140"
	replace ind_foreign_country="SM" if ind_foreign_country=="134"
	replace ind_foreign_country="RS" if ind_foreign_country=="159"
	replace ind_foreign_country="SK" if ind_foreign_country=="157"
	replace ind_foreign_country="SI" if ind_foreign_country=="146"
	replace ind_foreign_country="ES" if ind_foreign_country=="137"
	replace ind_foreign_country="GB" if ind_foreign_country=="139"
	replace ind_foreign_country="CH" if ind_foreign_country=="141"
	replace ind_foreign_country="SE" if ind_foreign_country=="106"
	replace ind_foreign_country="CZ" if ind_foreign_country=="158"
	replace ind_foreign_country="TR" if ind_foreign_country=="143"
	replace ind_foreign_country="DE" if ind_foreign_country=="144"
	replace ind_foreign_country="UA" if ind_foreign_country=="148"
	replace ind_foreign_country="HU" if ind_foreign_country=="152"
	replace ind_foreign_country="VA" if ind_foreign_country=="154"
	replace ind_foreign_country="AT" if ind_foreign_country=="153"
	replace ind_foreign_country="DZ" if ind_foreign_country=="203"
	replace ind_foreign_country="AO" if ind_foreign_country=="204"
	replace ind_foreign_country="BJ" if ind_foreign_country=="229"
	replace ind_foreign_country="BW" if ind_foreign_country=="205"
	replace ind_foreign_country="BF" if ind_foreign_country=="393"
	replace ind_foreign_country="BI" if ind_foreign_country=="216"
	replace ind_foreign_country="CF" if ind_foreign_country=="337"
	replace ind_foreign_country="DJ" if ind_foreign_country=="250"
	replace ind_foreign_country="EG" if ind_foreign_country=="249"
	replace ind_foreign_country="GQ" if ind_foreign_country=="235"
	replace ind_foreign_country="CI" if ind_foreign_country=="239"
	replace ind_foreign_country="ER" if ind_foreign_country=="241"
	replace ind_foreign_country="ET" if ind_foreign_country=="246"
	replace ind_foreign_country="GA" if ind_foreign_country=="254"
	replace ind_foreign_country="GM" if ind_foreign_country=="256"
	replace ind_foreign_country="GH" if ind_foreign_country=="260"
	replace ind_foreign_country="GN" if ind_foreign_country=="264"
	replace ind_foreign_country="GW" if ind_foreign_country=="266"
	replace ind_foreign_country="CM" if ind_foreign_country=="270"
	replace ind_foreign_country="CV" if ind_foreign_country=="273"
	replace ind_foreign_country="KE" if ind_foreign_country=="276"
	replace ind_foreign_country="KM" if ind_foreign_country=="220"
	replace ind_foreign_country="CD" if ind_foreign_country=="279"
	replace ind_foreign_country="CG" if ind_foreign_country=="278"
	replace ind_foreign_country="LS" if ind_foreign_country=="281"
	replace ind_foreign_country="LR" if ind_foreign_country=="283"
	replace ind_foreign_country="LY" if ind_foreign_country=="286"
	replace ind_foreign_country="MG" if ind_foreign_country=="289"
	replace ind_foreign_country="MW" if ind_foreign_country=="296"
	replace ind_foreign_country="ML" if ind_foreign_country=="299"
	replace ind_foreign_country="MA" if ind_foreign_country=="303"
	replace ind_foreign_country="MR" if ind_foreign_country=="306"
	replace ind_foreign_country="MU" if ind_foreign_country=="307"
	replace ind_foreign_country="YT" if ind_foreign_country=="322"
	replace ind_foreign_country="MZ" if ind_foreign_country=="319"
	replace ind_foreign_country="NA" if ind_foreign_country=="308"
	replace ind_foreign_country="NE" if ind_foreign_country=="309"
	replace ind_foreign_country="NG" if ind_foreign_country=="313"
	replace ind_foreign_country="RE" if ind_foreign_country=="323"
	replace ind_foreign_country="RW" if ind_foreign_country=="329"
	replace ind_foreign_country="ST" if ind_foreign_country=="333"
	replace ind_foreign_country="SN" if ind_foreign_country=="336"
	replace ind_foreign_country="SC" if ind_foreign_country=="338"
	replace ind_foreign_country="SL" if ind_foreign_country=="339"
	replace ind_foreign_country="SO" if ind_foreign_country=="346"
	replace ind_foreign_country="SD" if ind_foreign_country=="356"
	replace ind_foreign_country="SZ" if ind_foreign_country=="357"
	replace ind_foreign_country="ZA" if ind_foreign_country=="359"
	replace ind_foreign_country="SS" if ind_foreign_country=="355"
	replace ind_foreign_country="TZ" if ind_foreign_country=="369"
	replace ind_foreign_country="TO" if ind_foreign_country=="813"
	replace ind_foreign_country="TD" if ind_foreign_country=="373"
	replace ind_foreign_country="TN" if ind_foreign_country=="379"
	replace ind_foreign_country="UG" if ind_foreign_country=="386"
	replace ind_foreign_country="EH" if ind_foreign_country=="304"
	replace ind_foreign_country="ZM" if ind_foreign_country=="389"
	replace ind_foreign_country="ZW" if ind_foreign_country=="326"
	replace ind_foreign_country="AF" if ind_foreign_country=="404"
	replace ind_foreign_country="AI" if ind_foreign_country=="660"
	replace ind_foreign_country="AM" if ind_foreign_country=="406"
	replace ind_foreign_country="AW" if ind_foreign_country=="657"
	replace ind_foreign_country="AZ" if ind_foreign_country=="407"
	replace ind_foreign_country="BH" if ind_foreign_country=="409"
	replace ind_foreign_country="BD" if ind_foreign_country=="410"
	replace ind_foreign_country="BT" if ind_foreign_country=="412"
	replace ind_foreign_country="BN" if ind_foreign_country=="416"
	replace ind_foreign_country="AE" if ind_foreign_country=="426"
	replace ind_foreign_country="PS" if ind_foreign_country=="524"
	replace ind_foreign_country="PH" if ind_foreign_country=="428"
	replace ind_foreign_country="GE" if ind_foreign_country=="430"
	replace ind_foreign_country="HK" if ind_foreign_country=="436"
	replace ind_foreign_country="IN" if ind_foreign_country=="444"
	replace ind_foreign_country="ID" if ind_foreign_country=="448"
	replace ind_foreign_country="IQ" if ind_foreign_country=="452"
	replace ind_foreign_country="IR" if ind_foreign_country=="456"
	replace ind_foreign_country="IL" if ind_foreign_country=="460"
	replace ind_foreign_country="JP" if ind_foreign_country=="464"
	replace ind_foreign_country="JO" if ind_foreign_country=="476"
	replace ind_foreign_country="KH" if ind_foreign_country=="478"
	replace ind_foreign_country="KZ" if ind_foreign_country=="480"
	replace ind_foreign_country="CN" if ind_foreign_country=="484"
	replace ind_foreign_country="KG" if ind_foreign_country=="502"
	replace ind_foreign_country="KI" if ind_foreign_country=="815"
	replace ind_foreign_country="KW" if ind_foreign_country=="496"
	replace ind_foreign_country="LA" if ind_foreign_country=="504"
	replace ind_foreign_country="LB" if ind_foreign_country=="508"
	replace ind_foreign_country="MO" if ind_foreign_country=="510"
	replace ind_foreign_country="MY" if ind_foreign_country=="512"
	replace ind_foreign_country="MV" if ind_foreign_country=="513"
	replace ind_foreign_country="MH" if ind_foreign_country=="835"
	replace ind_foreign_country="MN" if ind_foreign_country=="516"
	replace ind_foreign_country="MM" if ind_foreign_country=="420"
	replace ind_foreign_country="NP" if ind_foreign_country=="528"
	replace ind_foreign_country="KP" if ind_foreign_country=="488"
	replace ind_foreign_country="MP" if ind_foreign_country=="840"
	replace ind_foreign_country="OM" if ind_foreign_country=="520"
	replace ind_foreign_country="PK" if ind_foreign_country=="534"
	replace ind_foreign_country="PW" if ind_foreign_country=="839"
	replace ind_foreign_country="QA" if ind_foreign_country=="540"
	replace ind_foreign_country="SA" if ind_foreign_country=="544"
	replace ind_foreign_country="SG" if ind_foreign_country=="548"
	replace ind_foreign_country="LK" if ind_foreign_country=="424"
	replace ind_foreign_country="SH" if ind_foreign_country=="209"
	replace ind_foreign_country="SY" if ind_foreign_country=="564"
	replace ind_foreign_country="KR" if ind_foreign_country=="492"
	replace ind_foreign_country="TJ" if ind_foreign_country=="550"
	replace ind_foreign_country="TW" if ind_foreign_country=="432"
	replace ind_foreign_country="TH" if ind_foreign_country=="568"
	replace ind_foreign_country="TM" if ind_foreign_country=="552"
	replace ind_foreign_country="UZ" if ind_foreign_country=="554"
	replace ind_foreign_country="VU" if ind_foreign_country=="812"
	replace ind_foreign_country="VN" if ind_foreign_country=="575"
	replace ind_foreign_country="YE" if ind_foreign_country=="578"
	replace ind_foreign_country="TL" if ind_foreign_country=="537"
	replace ind_foreign_country="AG" if ind_foreign_country=="603"
	replace ind_foreign_country="BS" if ind_foreign_country=="605"
	replace ind_foreign_country="BB" if ind_foreign_country=="602"
	replace ind_foreign_country="BZ" if ind_foreign_country=="604"
	replace ind_foreign_country="BM" if ind_foreign_country=="606"
	replace ind_foreign_country="BQ" if ind_foreign_country=="659"
	replace ind_foreign_country="CA" if ind_foreign_country=="612"
	replace ind_foreign_country="KY" if ind_foreign_country=="613"
	replace ind_foreign_country="CR" if ind_foreign_country=="616"
	replace ind_foreign_country="CU" if ind_foreign_country=="620"
	replace ind_foreign_country="VI" if ind_foreign_country=="601"
	replace ind_foreign_country="VG" if ind_foreign_country=="608"
	replace ind_foreign_country="DO" if ind_foreign_country=="624"
	replace ind_foreign_country="IO" if ind_foreign_country=="213"
	replace ind_foreign_country="DM" if ind_foreign_country=="622"
	replace ind_foreign_country="SV" if ind_foreign_country=="672"
	replace ind_foreign_country="GD" if ind_foreign_country=="629"
	replace ind_foreign_country="GP" if ind_foreign_country=="631"
	replace ind_foreign_country="GT" if ind_foreign_country=="632"
	replace ind_foreign_country="HT" if ind_foreign_country=="636"
	replace ind_foreign_country="HN" if ind_foreign_country=="644"
	replace ind_foreign_country="JM" if ind_foreign_country=="648"
	replace ind_foreign_country="MQ" if ind_foreign_country=="650"
	replace ind_foreign_country="MX" if ind_foreign_country=="652"
	replace ind_foreign_country="MS" if ind_foreign_country=="654"
	replace ind_foreign_country="NI" if ind_foreign_country=="664"
	replace ind_foreign_country="PA" if ind_foreign_country=="668"
	replace ind_foreign_country="PR" if ind_foreign_country=="685"
	replace ind_foreign_country="KN" if ind_foreign_country=="677"
	replace ind_foreign_country="LC" if ind_foreign_country=="678"
	replace ind_foreign_country="VC" if ind_foreign_country=="679"
	replace ind_foreign_country="BL" if ind_foreign_country=="687"
	replace ind_foreign_country="MF" if ind_foreign_country=="686"
	replace ind_foreign_country="PM" if ind_foreign_country=="676"
	replace ind_foreign_country="SX" if ind_foreign_country=="658"
	replace ind_foreign_country="TT" if ind_foreign_country=="680"
	replace ind_foreign_country="TC" if ind_foreign_country=="681"
	replace ind_foreign_country="US" if ind_foreign_country=="684"
	replace ind_foreign_country="AR" if ind_foreign_country=="705"
	replace ind_foreign_country="BO" if ind_foreign_country=="710"
	replace ind_foreign_country="BR" if ind_foreign_country=="715"
	replace ind_foreign_country="CL" if ind_foreign_country=="725"
	replace ind_foreign_country="CO" if ind_foreign_country=="730"
	replace ind_foreign_country="EC" if ind_foreign_country=="735"
	replace ind_foreign_country="FK" if ind_foreign_country=="740"
	replace ind_foreign_country="GF" if ind_foreign_country=="745"
	replace ind_foreign_country="GY" if ind_foreign_country=="720"
	replace ind_foreign_country="PY" if ind_foreign_country=="755"
	replace ind_foreign_country="PE" if ind_foreign_country=="760"
	replace ind_foreign_country="SR" if ind_foreign_country=="765"
	replace ind_foreign_country="UY" if ind_foreign_country=="770"
	replace ind_foreign_country="VE" if ind_foreign_country=="775"
	replace ind_foreign_country="AS" if ind_foreign_country=="802"
	replace ind_foreign_country="AU" if ind_foreign_country=="805"
	replace ind_foreign_country="CX" if ind_foreign_country=="807"
	replace ind_foreign_country="CK" if ind_foreign_country=="809"
	replace ind_foreign_country="FJ" if ind_foreign_country=="811"
	replace ind_foreign_country="PF" if ind_foreign_country=="814"
	replace ind_foreign_country="GU" if ind_foreign_country=="817"
	replace ind_foreign_country="CC" if ind_foreign_country=="808"
	replace ind_foreign_country="FM" if ind_foreign_country=="826"
	replace ind_foreign_country="NR" if ind_foreign_country=="818"
	replace ind_foreign_country="NZ" if ind_foreign_country=="820"
	replace ind_foreign_country="NU" if ind_foreign_country=="821"
	replace ind_foreign_country="NF" if ind_foreign_country=="822"
	replace ind_foreign_country="NC" if ind_foreign_country=="833"
	replace ind_foreign_country="PG" if ind_foreign_country=="827"
	replace ind_foreign_country="PN" if ind_foreign_country=="828"
	replace ind_foreign_country="SB" if ind_foreign_country=="806"
	replace ind_foreign_country="WS" if ind_foreign_country=="830"
	replace ind_foreign_country="TG" if ind_foreign_country=="376"
	replace ind_foreign_country="TK" if ind_foreign_country=="829"
	replace ind_foreign_country="TV" if ind_foreign_country=="816"
	replace ind_foreign_country="UM" if ind_foreign_country=="819"
	replace ind_foreign_country="WF" if ind_foreign_country=="832"
	replace ind_foreign_country="XZ" if ind_foreign_country=="980"
	replace ind_foreign_country="XX" if ind_foreign_country=="990"
	replace ind_foreign_country="NO" if ind_foreign_country=="NORGE"
	replace ind_foreign_country="DK" if ind_foreign_country=="DANMARK"
	replace ind_foreign_country="GL" if ind_foreign_country=="GRØNLAND"
	replace ind_foreign_country="FI" if ind_foreign_country=="FINLAND"
	replace ind_foreign_country="FO" if ind_foreign_country=="FÆRØYENE"
	replace ind_foreign_country="IS" if ind_foreign_country=="ISLAND"
	replace ind_foreign_country="SE" if ind_foreign_country=="SVERIGE"
	replace ind_foreign_country="AL" if ind_foreign_country=="ALBANIA"
	replace ind_foreign_country="BE" if ind_foreign_country=="BELGIA"
	replace ind_foreign_country="BG" if ind_foreign_country=="BULGARIA"
	replace ind_foreign_country="AD" if ind_foreign_country=="ANDORRA"
	replace ind_foreign_country="EE" if ind_foreign_country=="ESTLAND"
	replace ind_foreign_country="FR" if ind_foreign_country=="FRANKRIKE"
	replace ind_foreign_country="GI" if ind_foreign_country=="GIBRALTAR"
	replace ind_foreign_country="GR" if ind_foreign_country=="HELLAS"
	replace ind_foreign_country="BY" if ind_foreign_country=="HVITERUSSLAND"
	replace ind_foreign_country="IE" if ind_foreign_country=="IRLAND"
	replace ind_foreign_country="HR" if ind_foreign_country=="KROATIA"
	replace ind_foreign_country="IT" if ind_foreign_country=="ITALIA"
	replace ind_foreign_country="LV" if ind_foreign_country=="LATVIA"
	replace ind_foreign_country="MT" if ind_foreign_country=="MALTA"
	replace ind_foreign_country="NL" if ind_foreign_country=="NEDERLAND"
	replace ind_foreign_country="LI" if ind_foreign_country=="LIECHTENSTEIN"
	replace ind_foreign_country="LU" if ind_foreign_country=="LUXEMBOURG"
	replace ind_foreign_country="MC" if ind_foreign_country=="MONACO"
	replace ind_foreign_country="PL" if ind_foreign_country=="POLEN"
	replace ind_foreign_country="PT" if ind_foreign_country=="PORTUGAL"
	replace ind_foreign_country="RO" if ind_foreign_country=="ROMANIA"
	replace ind_foreign_country="SM" if ind_foreign_country=="SAN MARINO"
	replace ind_foreign_country="LT" if ind_foreign_country=="LITAUEN"
	replace ind_foreign_country="ES" if ind_foreign_country=="SPANIA"
	replace ind_foreign_country="MD" if ind_foreign_country=="MOLDOVA"
	replace ind_foreign_country="GB" if ind_foreign_country=="STORBRITANNIA"
	replace ind_foreign_country="RU" if ind_foreign_country=="RUSSLAND"
	// classify earlier Soviet union as Russia
	replace ind_foreign_country="RU" if ind_foreign_country=="SOVJETUNIONEN"
	replace ind_foreign_country="CH" if ind_foreign_country=="SVEITS"
	replace ind_foreign_country="TR" if ind_foreign_country=="TYRKIA"
	replace ind_foreign_country="DE" if ind_foreign_country=="TYSKLAND"
	replace ind_foreign_country="SI" if ind_foreign_country=="SLOVENIA"
	replace ind_foreign_country="UA" if ind_foreign_country=="UKRAINA"
	replace ind_foreign_country="HU" if ind_foreign_country=="UNGARN"
	replace ind_foreign_country="AT" if ind_foreign_country=="ØSTERRIKE"
	replace ind_foreign_country="VA" if ind_foreign_country=="VATIKANSTATEN"
	replace ind_foreign_country="BA" if ind_foreign_country=="BOSNIA-HERCEGOVINA"
	replace ind_foreign_country="MK" if ind_foreign_country=="MAKEDONIA"
	replace ind_foreign_country="SK" if ind_foreign_country=="SLOVAKIA"
	replace ind_foreign_country="CZ" if ind_foreign_country=="DEN TSJEKKISKE REP."
	// Classify Checholovachey as Chech
	replace ind_foreign_country="CZ" if ind_foreign_country=="TSJEKKOSLOVAKIA"
	replace ind_foreign_country="RS" if ind_foreign_country=="SERBIA"
	// Have from serbia montenegro befor the split up, so classify that as serbia
	replace ind_foreign_country="RS" if ind_foreign_country=="SERBIA OG MONTENEGRO"
	replace ind_foreign_country="ME" if ind_foreign_country=="MONTENEGRO"
	replace ind_foreign_country="XK" if ind_foreign_country=="KOSOVO"
	replace ind_foreign_country="DZ" if ind_foreign_country=="ALGERIE"
	replace ind_foreign_country="AO" if ind_foreign_country=="ANGOLA"
	replace ind_foreign_country="BW" if ind_foreign_country=="BOTSWANA"
	replace ind_foreign_country="SH" if ind_foreign_country=="ST.HELENA"
	replace ind_foreign_country="IO" if ind_foreign_country=="BRITISK-INDISKE HAV"
	replace ind_foreign_country="BI" if ind_foreign_country=="BURUNDI"
	replace ind_foreign_country="KM" if ind_foreign_country=="KOMORENE"
	replace ind_foreign_country="BJ" if ind_foreign_country=="BENIN"
	replace ind_foreign_country="GQ" if ind_foreign_country=="EKVATORIAL-GUINEA"
	replace ind_foreign_country="CI" if ind_foreign_country=="ELFENBEINSKYSTEN"
	replace ind_foreign_country="ER" if ind_foreign_country=="ERITREA"
	replace ind_foreign_country="ET" if ind_foreign_country=="ETIOPIA"
	replace ind_foreign_country="EG" if ind_foreign_country=="EGYPT"
	replace ind_foreign_country="DJ" if ind_foreign_country=="DJIBOUTI"
	replace ind_foreign_country="GA" if ind_foreign_country=="GABON"
	replace ind_foreign_country="GM" if ind_foreign_country=="GAMBIA"
	replace ind_foreign_country="GH" if ind_foreign_country=="GHANA"
	replace ind_foreign_country="GN" if ind_foreign_country=="GUINEA"
	replace ind_foreign_country="GW" if ind_foreign_country=="GUINEA-BISSAU"
	replace ind_foreign_country="CM" if ind_foreign_country=="KAMERUN"
	replace ind_foreign_country="CV" if ind_foreign_country=="KAPP VERDE"
	replace ind_foreign_country="KE" if ind_foreign_country=="KENYA"
	replace ind_foreign_country="CG" if ind_foreign_country=="KONGO, REPUBLIKKEN"
	replace ind_foreign_country="CD" if ind_foreign_country=="KONGO, DEN DEMOKR. REPUBL"
	replace ind_foreign_country="LS" if ind_foreign_country=="LESOTHO"
	replace ind_foreign_country="LR" if ind_foreign_country=="LIBERIA"
	replace ind_foreign_country="LY" if ind_foreign_country=="LIBYA"
	replace ind_foreign_country="MG" if ind_foreign_country=="MADAGASKAR"
	replace ind_foreign_country="MW" if ind_foreign_country=="MALAWI"
	replace ind_foreign_country="ML" if ind_foreign_country=="MALI"
	replace ind_foreign_country="MA" if ind_foreign_country=="MAROKKO"
	replace ind_foreign_country="EH" if ind_foreign_country=="VEST-SAHARA"
	replace ind_foreign_country="MR" if ind_foreign_country=="MAURITANIA"
	replace ind_foreign_country="MU" if ind_foreign_country=="MAURITIUS"
	replace ind_foreign_country="NA" if ind_foreign_country=="NAMIBIA"
	replace ind_foreign_country="NE" if ind_foreign_country=="NIGER"
	replace ind_foreign_country="NG" if ind_foreign_country=="NIGERIA"
	replace ind_foreign_country="MZ" if ind_foreign_country=="MOSAMBIK"
	replace ind_foreign_country="YT" if ind_foreign_country=="MAYOTTE"
	replace ind_foreign_country="RE" if ind_foreign_country=="RUNION"
	replace ind_foreign_country="ZW" if ind_foreign_country=="ZIMBABWE"
	replace ind_foreign_country="RW" if ind_foreign_country=="RWANDA"
	replace ind_foreign_country="ST" if ind_foreign_country=="SAO TOME OG PRINCIPE"
	replace ind_foreign_country="SN" if ind_foreign_country=="SENEGAL"
	replace ind_foreign_country="CF" if ind_foreign_country=="SENTRALAFRIKANSKE REPUBLIKK"
	replace ind_foreign_country="SC" if ind_foreign_country=="SEYCHELLENE"
	replace ind_foreign_country="SL" if ind_foreign_country=="SIERRA LEONE"
	replace ind_foreign_country="SO" if ind_foreign_country=="SOMALIA"
	replace ind_foreign_country="SD" if ind_foreign_country=="SUDAN"
	replace ind_foreign_country="SZ" if ind_foreign_country=="SWAZILAND"
	replace ind_foreign_country="ZA" if ind_foreign_country=="SØR-AFRIKA"
	replace ind_foreign_country="TZ" if ind_foreign_country=="TANZANIA"
	replace ind_foreign_country="TD" if ind_foreign_country=="TCHAD"
	replace ind_foreign_country="TG" if ind_foreign_country=="TOGO"
	replace ind_foreign_country="TN" if ind_foreign_country=="TUNISIA"
	replace ind_foreign_country="UG" if ind_foreign_country=="UGANDA"
	replace ind_foreign_country="ZM" if ind_foreign_country=="ZAMBIA"
	replace ind_foreign_country="BF" if ind_foreign_country=="BURKINA FASO"
	replace ind_foreign_country="AF" if ind_foreign_country=="AFGHANISTAN"
	replace ind_foreign_country="AM" if ind_foreign_country=="ARMENIA"
	replace ind_foreign_country="AZ" if ind_foreign_country=="AZERBAJDZJAN"
	replace ind_foreign_country="BH" if ind_foreign_country=="BAHRAIN"
	replace ind_foreign_country="BD" if ind_foreign_country=="BANGLADESH"
	replace ind_foreign_country="BT" if ind_foreign_country=="BHUTAN"
	replace ind_foreign_country="BN" if ind_foreign_country=="BRUNEI"
	replace ind_foreign_country="MM" if ind_foreign_country=="MYANMAR (BURMA)"
	replace ind_foreign_country="LK" if ind_foreign_country=="SRI LANKA"
	replace ind_foreign_country="AE" if ind_foreign_country=="DE ARABISKE EMIRATER"
	replace ind_foreign_country="PH" if ind_foreign_country=="FILIPPINENE"
	replace ind_foreign_country="GE" if ind_foreign_country=="GEORGIA"
	replace ind_foreign_country="TW" if ind_foreign_country=="TAIWAN"
	replace ind_foreign_country="HK" if ind_foreign_country=="HONGKONG"
	replace ind_foreign_country="IN" if ind_foreign_country=="INDIA"
	replace ind_foreign_country="ID" if ind_foreign_country=="INDONESIA"
	replace ind_foreign_country="IQ" if ind_foreign_country=="IRAK"
	replace ind_foreign_country="IR" if ind_foreign_country=="IRAN"
	replace ind_foreign_country="IL" if ind_foreign_country=="ISRAEL"
	replace ind_foreign_country="JP" if ind_foreign_country=="JAPAN"
	replace ind_foreign_country="JO" if ind_foreign_country=="JORDAN"
	replace ind_foreign_country="KH" if ind_foreign_country=="KAMPUTCHEA"
	replace ind_foreign_country="KZ" if ind_foreign_country=="KAZAKHSTAN"
	replace ind_foreign_country="CN" if ind_foreign_country=="KINA"
	replace ind_foreign_country="KP" if ind_foreign_country=="NORD-KOREA"
	replace ind_foreign_country="KR" if ind_foreign_country=="SØR-KOREA"
	replace ind_foreign_country="KW" if ind_foreign_country=="KUWAIT"
	replace ind_foreign_country="CY" if ind_foreign_country=="KYPROS"
	replace ind_foreign_country="KG" if ind_foreign_country=="KYRGYZSTAN"
	replace ind_foreign_country="LA" if ind_foreign_country=="LAOS"
	replace ind_foreign_country="LB" if ind_foreign_country=="LIBANON"
	replace ind_foreign_country="MO" if ind_foreign_country=="MACAO"
	replace ind_foreign_country="MY" if ind_foreign_country=="MALAYSIA"
	replace ind_foreign_country="MV" if ind_foreign_country=="MALDIVENE"
	replace ind_foreign_country="MN" if ind_foreign_country=="MONGOLIA"
	replace ind_foreign_country="OM" if ind_foreign_country=="OMAN"
	replace ind_foreign_country="PS" if ind_foreign_country=="DET PALESTINSKE OMRÅDET"
	replace ind_foreign_country="NP" if ind_foreign_country=="NEPAL"
	replace ind_foreign_country="PK" if ind_foreign_country=="PAKISTAN"
	replace ind_foreign_country="TL" if ind_foreign_country=="ØST-TIMOR"
	replace ind_foreign_country="QA" if ind_foreign_country=="QATAR"
	replace ind_foreign_country="SA" if ind_foreign_country=="SAUDI-ARABIA"
	replace ind_foreign_country="SG" if ind_foreign_country=="SINGAPORE"
	replace ind_foreign_country="TJ" if ind_foreign_country=="TADZJIKISTAN"
	replace ind_foreign_country="TM" if ind_foreign_country=="TURKMENISTAN"
	replace ind_foreign_country="UZ" if ind_foreign_country=="UZBEKISTAN"
	replace ind_foreign_country="SY" if ind_foreign_country=="SYRIA"
	replace ind_foreign_country="TH" if ind_foreign_country=="THAILAND"
	replace ind_foreign_country="VN" if ind_foreign_country=="VIETNAM"
	replace ind_foreign_country="YE" if ind_foreign_country=="YEMEN"
	replace ind_foreign_country="VI" if ind_foreign_country=="JOMFRUØYENE AM."
	replace ind_foreign_country="BB" if ind_foreign_country=="BARBADOS"
	replace ind_foreign_country="AG" if ind_foreign_country=="ANTIGUA OG BARBUDA"
	replace ind_foreign_country="BZ" if ind_foreign_country=="BELIZE"
	replace ind_foreign_country="BS" if ind_foreign_country=="BAHAMAS"
	replace ind_foreign_country="BM" if ind_foreign_country=="BERMUDA"
	replace ind_foreign_country="VG" if ind_foreign_country=="JOMFRUØYENE BRIT."
	replace ind_foreign_country="CA" if ind_foreign_country=="CANADA"
	replace ind_foreign_country="KY" if ind_foreign_country=="CAYMANØYENE"
	replace ind_foreign_country="CR" if ind_foreign_country=="COSTA RICA"
	replace ind_foreign_country="CU" if ind_foreign_country=="CUBA"
	replace ind_foreign_country="DM" if ind_foreign_country=="DOMINICA"
	replace ind_foreign_country="DO" if ind_foreign_country=="DEN DOMINIKANSKE REP"
	replace ind_foreign_country="GD" if ind_foreign_country=="GRENADA"
	replace ind_foreign_country="GP" if ind_foreign_country=="GUADELOUPE"
	replace ind_foreign_country="GT" if ind_foreign_country=="GUATEMALA"
	replace ind_foreign_country="HT" if ind_foreign_country=="HAITI"
	replace ind_foreign_country="HN" if ind_foreign_country=="HONDURAS"
	replace ind_foreign_country="JM" if ind_foreign_country=="JAMAICA"
	replace ind_foreign_country="MQ" if ind_foreign_country=="MARTINIQUE"
	replace ind_foreign_country="MX" if ind_foreign_country=="MEXICO"
	replace ind_foreign_country="MS" if ind_foreign_country=="MONTSERRAT"
	replace ind_foreign_country="AW" if ind_foreign_country=="DE NEDERLANDSKE ANTILLENE"
	replace ind_foreign_country="SX" if ind_foreign_country=="ARUBA"
	replace ind_foreign_country="BQ" if ind_foreign_country=="ANGUILLA"
	replace ind_foreign_country="AI" if ind_foreign_country=="NICARAGUA"
	replace ind_foreign_country="NI" if ind_foreign_country=="PANAMA"
	replace ind_foreign_country="PA" if ind_foreign_country=="PANAMAKANALSONEN"
	replace ind_foreign_country="SV" if ind_foreign_country=="EL SALVADOR"
	replace ind_foreign_country="PM" if ind_foreign_country=="ST.PIERRE OG MIQUELON"
	replace ind_foreign_country="KN" if ind_foreign_country=="ST.KITTS OG NEVIS"
	replace ind_foreign_country="LC" if ind_foreign_country=="ST. LUCIA"
	replace ind_foreign_country="VC" if ind_foreign_country=="ST. VINCENT OG GRENADINENE"
	replace ind_foreign_country="TT" if ind_foreign_country=="TRINIDAD OG TOBAGO"
	replace ind_foreign_country="TC" if ind_foreign_country=="TURKS/CAICOSØYENE"
	replace ind_foreign_country="US" if ind_foreign_country=="USA"
	replace ind_foreign_country="PR" if ind_foreign_country=="PUERTO RICO"
	replace ind_foreign_country="MF" if ind_foreign_country=="ST.MARTIN"
	replace ind_foreign_country="BL" if ind_foreign_country=="ST.BARTHELEMY"
	replace ind_foreign_country="AR" if ind_foreign_country=="ARGENTINA"
	replace ind_foreign_country="BO" if ind_foreign_country=="BOLIVIA"
	replace ind_foreign_country="BR" if ind_foreign_country=="BRASIL"
	replace ind_foreign_country="GY" if ind_foreign_country=="GUYANA"
	replace ind_foreign_country="CL" if ind_foreign_country=="CHILE"
	replace ind_foreign_country="CO" if ind_foreign_country=="COLOMBIA"
	replace ind_foreign_country="EC" if ind_foreign_country=="ECUADOR"
	replace ind_foreign_country="FK" if ind_foreign_country=="FALKLANDSØYENE"
	replace ind_foreign_country="GF" if ind_foreign_country=="FRANSK GUYANA"
	replace ind_foreign_country="PY" if ind_foreign_country=="PARAGUAY"
	replace ind_foreign_country="PE" if ind_foreign_country=="PERU"
	replace ind_foreign_country="SR" if ind_foreign_country=="SURINAME"
	replace ind_foreign_country="UY" if ind_foreign_country=="URUGUAY"
	replace ind_foreign_country="VE" if ind_foreign_country=="VENEZUELA"
	replace ind_foreign_country="AS" if ind_foreign_country=="AM. SAMOA"
	replace ind_foreign_country="AU" if ind_foreign_country=="AUSTRALIA"
	replace ind_foreign_country="SB" if ind_foreign_country=="SALOMONØYENE"
	replace ind_foreign_country="CX" if ind_foreign_country=="CHRISTMASØYA"
	replace ind_foreign_country="CC" if ind_foreign_country=="KOKOSØYENE"
	replace ind_foreign_country="CK" if ind_foreign_country=="COOKØYENE"
	replace ind_foreign_country="FJ" if ind_foreign_country=="FIJI"
	replace ind_foreign_country="VU" if ind_foreign_country=="VANUATU"
	replace ind_foreign_country="TO" if ind_foreign_country=="TONGA"
	replace ind_foreign_country="PF" if ind_foreign_country=="FRANSK POLYNESIA"
	replace ind_foreign_country="KI" if ind_foreign_country=="KIRIBATI"
	replace ind_foreign_country="TV" if ind_foreign_country=="TUVALU"
	replace ind_foreign_country="GU" if ind_foreign_country=="GUAM"
	replace ind_foreign_country="NR" if ind_foreign_country=="NAURU"
	replace ind_foreign_country="UM" if ind_foreign_country=="MINDRE STILLEHAVSØYER"
	replace ind_foreign_country="NZ" if ind_foreign_country=="NEW ZEALAND"
	replace ind_foreign_country="NU" if ind_foreign_country=="NIUE"
	replace ind_foreign_country="NF" if ind_foreign_country=="NORFOLKØYA"
	replace ind_foreign_country="FM" if ind_foreign_country=="MIKRONESIAFØDERASJONEN"
	replace ind_foreign_country="PG" if ind_foreign_country=="PAPUA NY-GUINEA"
	replace ind_foreign_country="PN" if ind_foreign_country=="PITCAIRN"
	replace ind_foreign_country="TK" if ind_foreign_country=="TOKELAU"
	replace ind_foreign_country="WS" if ind_foreign_country=="VEST-SAMOA"
	replace ind_foreign_country="WF" if ind_foreign_country=="WALLIS/FUTUNAØYENE"
	replace ind_foreign_country="NC" if ind_foreign_country=="NY-KALEDONIA"
	replace ind_foreign_country="MH" if ind_foreign_country=="MARSHALLØYENE"
	replace ind_foreign_country="PW" if ind_foreign_country=="PALAU"
	replace ind_foreign_country="MP" if ind_foreign_country=="NORD-MARIANENE"
	replace ind_foreign_country=".." if ind_foreign_country=="STATSLØS"
	replace ind_foreign_country=".." if ind_foreign_country=="UOPPGITT/UKJENT"
	replace ind_foreign_country=".." if ind_foreign_country=="Ingen"

* Clean up the county variable 
	tab ind_county, m
	foreach var in 1 2 3 4 5 6 7 8 9 {
		replace ind_county="0`var'" if ind_county=="`var'"
	}
	replace ind_county=" " if ind_county=="0"
	tab ind_county, m

* Make dummy for foreign born or foreign nationality
	tab ind_foreign_country, m
	gen ind_foreigner=1
	replace ind_foreigner=0 if ind_foreign_country=="NO"
	label variable ind_foreigner "dummy equal to 1 if foreigner - foreign born or nationality"
	tab ind_foreigner, m

* Create some lagged variables
	tab ind_marital, m
	destring ind_marital, replace
	replace ind_marital=. if ind_marital==0 | ind_marital==10
	tab ind_marital, m
	sort ID year
	egen pers=group(ID)
	xtset pers year
	gen lag_stat=l.ind_status
	gen lag_marital=l.ind_marital
	drop pers

* Make indicator for divorce or marriage
	gen ind_divorced=0
		replace ind_divorced=1 if lag_marital==2 & (ind_marital==4 | ind_marital==5)
		label variable ind_divorced "divorced during the year"
		tab ind_divorced, m
	gen ind_married=0
		replace ind_married=1 if ind_marital==2 & (lag_marital==1 | lag_marital==4 | lag_marital==3)
		label variable ind_married "got married during the year"
		tab ind_married, m
		drop lag_marital

	tab ind_immigration_country, m
	tab ind_immigration_year, m
	tab ind_emigration_country, m
	tab ind_emigration_year, m 
	keep ID year ind* lag*
	d
	sum
	compress
save $temp\temp_dsf.dta, replace

* Emigration info
	keep if year==2013
	drop if ind_emigration_country==" " &  ind_emigration_year==1000
	keep ID ind_emigration_country ind_emigration_year   
	// Identify the country codes using http://dbh.nsd.uib.no/dokumentasjon/landkoder.action
	// Country info is reomoved for many emigrators due to anonymzation issues; code this as having country "99"  
	gen ind_e_country=""			
	replace ind_e_country="99" if ind_emigration_country=="FÅ obs"
	replace ind_e_country="AL" if ind_emigration_country=="111"
	replace ind_e_country="AD" if ind_emigration_country=="114"
	replace ind_e_country="BE" if ind_emigration_country=="112"
	replace ind_e_country="BA" if ind_emigration_country=="155"
	replace ind_e_country="BG" if ind_emigration_country=="113"
	replace ind_e_country="DK" if ind_emigration_country=="101"
	replace ind_e_country="EE" if ind_emigration_country=="115"
	replace ind_e_country="FI" if ind_emigration_country=="103"
	replace ind_e_country="FR" if ind_emigration_country=="117"
	replace ind_e_country="FO" if ind_emigration_country=="104"
	replace ind_e_country="GI" if ind_emigration_country=="118"
	replace ind_e_country="GL" if ind_emigration_country=="102"
	replace ind_e_country="GG" if ind_emigration_country=="162"
	replace ind_e_country="GR" if ind_emigration_country=="119"
	replace ind_e_country="BY" if ind_emigration_country=="120"
	replace ind_e_country="IE" if ind_emigration_country=="121"
	replace ind_e_country="IS" if ind_emigration_country=="105"
	replace ind_e_country="IT" if ind_emigration_country=="123"
	replace ind_e_country="JE" if ind_emigration_country=="163"
	replace ind_e_country="XK" if ind_emigration_country=="161"
	replace ind_e_country="HR" if ind_emigration_country=="122"
	replace ind_e_country="CY" if ind_emigration_country=="500"
	replace ind_e_country="LV" if ind_emigration_country=="124"
	replace ind_e_country="LI" if ind_emigration_country=="128"
	replace ind_e_country="LT" if ind_emigration_country=="136"
	replace ind_e_country="LU" if ind_emigration_country=="129"
	replace ind_e_country="MK" if ind_emigration_country=="156"
	replace ind_e_country="MT" if ind_emigration_country=="126"
	replace ind_e_country="IM" if ind_emigration_country=="164"
	replace ind_e_country="MD" if ind_emigration_country=="138"
	replace ind_e_country="MC" if ind_emigration_country=="130"
	replace ind_e_country="ME" if ind_emigration_country=="160"
	replace ind_e_country="NL" if ind_emigration_country=="127"
	replace ind_e_country="NO" if ind_emigration_country=="0"
	replace ind_e_country="PL" if ind_emigration_country=="131"
	replace ind_e_country="PT" if ind_emigration_country=="132"
	replace ind_e_country="RO" if ind_emigration_country=="133"
	replace ind_e_country="RU" if ind_emigration_country=="140"
	replace ind_e_country="SM" if ind_emigration_country=="134"
	replace ind_e_country="RS" if ind_emigration_country=="159"
	replace ind_e_country="SK" if ind_emigration_country=="157"
	replace ind_e_country="SI" if ind_emigration_country=="146"
	replace ind_e_country="ES" if ind_emigration_country=="137"
	replace ind_e_country="GB" if ind_emigration_country=="139"
	replace ind_e_country="CH" if ind_emigration_country=="141"
	replace ind_e_country="SE" if ind_emigration_country=="106"
	replace ind_e_country="CZ" if ind_emigration_country=="158"
	replace ind_e_country="TR" if ind_emigration_country=="143"
	replace ind_e_country="DE" if ind_emigration_country=="144"
	replace ind_e_country="UA" if ind_emigration_country=="148"
	replace ind_e_country="HU" if ind_emigration_country=="152"
	replace ind_e_country="VA" if ind_emigration_country=="154"
	replace ind_e_country="AT" if ind_emigration_country=="153"
	replace ind_e_country="DZ" if ind_emigration_country=="203"
	replace ind_e_country="AO" if ind_emigration_country=="204"
	replace ind_e_country="BJ" if ind_emigration_country=="229"
	replace ind_e_country="BW" if ind_emigration_country=="205"
	replace ind_e_country="BF" if ind_emigration_country=="393"
	replace ind_e_country="BI" if ind_emigration_country=="216"
	replace ind_e_country="CF" if ind_emigration_country=="337"
	replace ind_e_country="DJ" if ind_emigration_country=="250"
	replace ind_e_country="EG" if ind_emigration_country=="249"
	replace ind_e_country="GQ" if ind_emigration_country=="235"
	replace ind_e_country="CI" if ind_emigration_country=="239"
	replace ind_e_country="ER" if ind_emigration_country=="241"
	replace ind_e_country="ET" if ind_emigration_country=="246"
	replace ind_e_country="GA" if ind_emigration_country=="254"
	replace ind_e_country="GM" if ind_emigration_country=="256"
	replace ind_e_country="GH" if ind_emigration_country=="260"
	replace ind_e_country="GN" if ind_emigration_country=="264"
	replace ind_e_country="GW" if ind_emigration_country=="266"
	replace ind_e_country="CM" if ind_emigration_country=="270"
	replace ind_e_country="CV" if ind_emigration_country=="273"
	replace ind_e_country="KE" if ind_emigration_country=="276"
	replace ind_e_country="KM" if ind_emigration_country=="220"
	replace ind_e_country="CD" if ind_emigration_country=="279"
	replace ind_e_country="CG" if ind_emigration_country=="278"
	replace ind_e_country="LS" if ind_emigration_country=="281"
	replace ind_e_country="LR" if ind_emigration_country=="283"
	replace ind_e_country="LY" if ind_emigration_country=="286"
	replace ind_e_country="MG" if ind_emigration_country=="289"
	replace ind_e_country="MW" if ind_emigration_country=="296"
	replace ind_e_country="ML" if ind_emigration_country=="299"
	replace ind_e_country="MA" if ind_emigration_country=="303"
	replace ind_e_country="MR" if ind_emigration_country=="306"
	replace ind_e_country="MU" if ind_emigration_country=="307"
	replace ind_e_country="YT" if ind_emigration_country=="322"
	replace ind_e_country="MZ" if ind_emigration_country=="319"
	replace ind_e_country="NA" if ind_emigration_country=="308"
	replace ind_e_country="NE" if ind_emigration_country=="309"
	replace ind_e_country="NG" if ind_emigration_country=="313"
	replace ind_e_country="RE" if ind_emigration_country=="323"
	replace ind_e_country="RW" if ind_emigration_country=="329"
	replace ind_e_country="ST" if ind_emigration_country=="333"
	replace ind_e_country="SN" if ind_emigration_country=="336"
	replace ind_e_country="SC" if ind_emigration_country=="338"
	replace ind_e_country="SL" if ind_emigration_country=="339"
	replace ind_e_country="SO" if ind_emigration_country=="346"
	replace ind_e_country="SD" if ind_emigration_country=="356"
	replace ind_e_country="SZ" if ind_emigration_country=="357"
	replace ind_e_country="ZA" if ind_emigration_country=="359"
	replace ind_e_country="SS" if ind_emigration_country=="355"
	replace ind_e_country="TZ" if ind_emigration_country=="369"
	replace ind_e_country="TO" if ind_emigration_country=="813"
	replace ind_e_country="TD" if ind_emigration_country=="373"
	replace ind_e_country="TN" if ind_emigration_country=="379"
	replace ind_e_country="UG" if ind_emigration_country=="386"
	replace ind_e_country="EH" if ind_emigration_country=="304"
	replace ind_e_country="ZM" if ind_emigration_country=="389"
	replace ind_e_country="ZW" if ind_emigration_country=="326"
	replace ind_e_country="AF" if ind_emigration_country=="404"
	replace ind_e_country="AI" if ind_emigration_country=="660"
	replace ind_e_country="AM" if ind_emigration_country=="406"
	replace ind_e_country="AW" if ind_emigration_country=="657"
	replace ind_e_country="AZ" if ind_emigration_country=="407"
	replace ind_e_country="BH" if ind_emigration_country=="409"
	replace ind_e_country="BD" if ind_emigration_country=="410"
	replace ind_e_country="BT" if ind_emigration_country=="412"
	replace ind_e_country="BN" if ind_emigration_country=="416"
	replace ind_e_country="AE" if ind_emigration_country=="426"
	replace ind_e_country="PS" if ind_emigration_country=="524"
	replace ind_e_country="PH" if ind_emigration_country=="428"
	replace ind_e_country="GE" if ind_emigration_country=="430"
	replace ind_e_country="HK" if ind_emigration_country=="436"
	replace ind_e_country="IN" if ind_emigration_country=="444"
	replace ind_e_country="ID" if ind_emigration_country=="448"
	replace ind_e_country="IQ" if ind_emigration_country=="452"
	replace ind_e_country="IR" if ind_emigration_country=="456"
	replace ind_e_country="IL" if ind_emigration_country=="460"
	replace ind_e_country="JP" if ind_emigration_country=="464"
	replace ind_e_country="JO" if ind_emigration_country=="476"
	replace ind_e_country="KH" if ind_emigration_country=="478"
	replace ind_e_country="KZ" if ind_emigration_country=="480"
	replace ind_e_country="CN" if ind_emigration_country=="484"
	replace ind_e_country="KG" if ind_emigration_country=="502"
	replace ind_e_country="KI" if ind_emigration_country=="815"
	replace ind_e_country="KW" if ind_emigration_country=="496"
	replace ind_e_country="LA" if ind_emigration_country=="504"
	replace ind_e_country="LB" if ind_emigration_country=="508"
	replace ind_e_country="MO" if ind_emigration_country=="510"
	replace ind_e_country="MY" if ind_emigration_country=="512"
	replace ind_e_country="MV" if ind_emigration_country=="513"
	replace ind_e_country="MH" if ind_emigration_country=="835"
	replace ind_e_country="MN" if ind_emigration_country=="516"
	replace ind_e_country="MM" if ind_emigration_country=="420"
	replace ind_e_country="NP" if ind_emigration_country=="528"
	replace ind_e_country="KP" if ind_emigration_country=="488"
	replace ind_e_country="MP" if ind_emigration_country=="840"
	replace ind_e_country="OM" if ind_emigration_country=="520"
	replace ind_e_country="PK" if ind_emigration_country=="534"
	replace ind_e_country="PW" if ind_emigration_country=="839"
	replace ind_e_country="QA" if ind_emigration_country=="540"
	replace ind_e_country="SA" if ind_emigration_country=="544"
	replace ind_e_country="SG" if ind_emigration_country=="548"
	replace ind_e_country="LK" if ind_emigration_country=="424"
	replace ind_e_country="SH" if ind_emigration_country=="209"
	replace ind_e_country="SY" if ind_emigration_country=="564"
	replace ind_e_country="KR" if ind_emigration_country=="492"
	replace ind_e_country="TJ" if ind_emigration_country=="550"
	replace ind_e_country="TW" if ind_emigration_country=="432"
	replace ind_e_country="TH" if ind_emigration_country=="568"
	replace ind_e_country="TM" if ind_emigration_country=="552"
	replace ind_e_country="UZ" if ind_emigration_country=="554"
	replace ind_e_country="VU" if ind_emigration_country=="812"
	replace ind_e_country="VN" if ind_emigration_country=="575"
	replace ind_e_country="YE" if ind_emigration_country=="578"
	replace ind_e_country="TL" if ind_emigration_country=="537"
	replace ind_e_country="AG" if ind_emigration_country=="603"
	replace ind_e_country="BS" if ind_emigration_country=="605"
	replace ind_e_country="BB" if ind_emigration_country=="602"
	replace ind_e_country="BZ" if ind_emigration_country=="604"
	replace ind_e_country="BM" if ind_emigration_country=="606"
	replace ind_e_country="BQ" if ind_emigration_country=="659"
	replace ind_e_country="CA" if ind_emigration_country=="612"
	replace ind_e_country="KY" if ind_emigration_country=="613"
	replace ind_e_country="CR" if ind_emigration_country=="616"
	replace ind_e_country="CU" if ind_emigration_country=="620"
	replace ind_e_country="VI" if ind_emigration_country=="601"
	replace ind_e_country="VG" if ind_emigration_country=="608"
	replace ind_e_country="DO" if ind_emigration_country=="624"
	replace ind_e_country="IO" if ind_emigration_country=="213"
	replace ind_e_country="DM" if ind_emigration_country=="622"
	replace ind_e_country="SV" if ind_emigration_country=="672"
	replace ind_e_country="GD" if ind_emigration_country=="629"
	replace ind_e_country="GP" if ind_emigration_country=="631"
	replace ind_e_country="GT" if ind_emigration_country=="632"
	replace ind_e_country="HT" if ind_emigration_country=="636"
	replace ind_e_country="HN" if ind_emigration_country=="644"
	replace ind_e_country="JM" if ind_emigration_country=="648"
	replace ind_e_country="MQ" if ind_emigration_country=="650"
	replace ind_e_country="MX" if ind_emigration_country=="652"
	replace ind_e_country="MS" if ind_emigration_country=="654"
	replace ind_e_country="NI" if ind_emigration_country=="664"
	replace ind_e_country="PA" if ind_emigration_country=="668"
	replace ind_e_country="PR" if ind_emigration_country=="685"
	replace ind_e_country="KN" if ind_emigration_country=="677"
	replace ind_e_country="LC" if ind_emigration_country=="678"
	replace ind_e_country="VC" if ind_emigration_country=="679"
	replace ind_e_country="BL" if ind_emigration_country=="687"
	replace ind_e_country="MF" if ind_emigration_country=="686"
	replace ind_e_country="PM" if ind_emigration_country=="676"
	replace ind_e_country="SX" if ind_emigration_country=="658"
	replace ind_e_country="TT" if ind_emigration_country=="680"
	replace ind_e_country="TC" if ind_emigration_country=="681"
	replace ind_e_country="US" if ind_emigration_country=="684"
	replace ind_e_country="AR" if ind_emigration_country=="705"
	replace ind_e_country="BO" if ind_emigration_country=="710"
	replace ind_e_country="BR" if ind_emigration_country=="715"
	replace ind_e_country="CL" if ind_emigration_country=="725"
	replace ind_e_country="CO" if ind_emigration_country=="730"
	replace ind_e_country="EC" if ind_emigration_country=="735"
	replace ind_e_country="FK" if ind_emigration_country=="740"
	replace ind_e_country="GF" if ind_emigration_country=="745"
	replace ind_e_country="GY" if ind_emigration_country=="720"
	replace ind_e_country="PY" if ind_emigration_country=="755"
	replace ind_e_country="PE" if ind_emigration_country=="760"
	replace ind_e_country="SR" if ind_emigration_country=="765"
	replace ind_e_country="UY" if ind_emigration_country=="770"
	replace ind_e_country="VE" if ind_emigration_country=="775"
	replace ind_e_country="AS" if ind_emigration_country=="802"
	replace ind_e_country="AU" if ind_emigration_country=="805"
	replace ind_e_country="CX" if ind_emigration_country=="807"
	replace ind_e_country="CK" if ind_emigration_country=="809"
	replace ind_e_country="FJ" if ind_emigration_country=="811"
	replace ind_e_country="PF" if ind_emigration_country=="814"
	replace ind_e_country="GU" if ind_emigration_country=="817"
	replace ind_e_country="CC" if ind_emigration_country=="808"
	replace ind_e_country="FM" if ind_emigration_country=="826"
	replace ind_e_country="NR" if ind_emigration_country=="818"
	replace ind_e_country="NZ" if ind_emigration_country=="820"
	replace ind_e_country="NU" if ind_emigration_country=="821"
	replace ind_e_country="NF" if ind_emigration_country=="822"
	replace ind_e_country="NC" if ind_emigration_country=="833"
	replace ind_e_country="PG" if ind_emigration_country=="827"
	replace ind_e_country="PN" if ind_emigration_country=="828"
	replace ind_e_country="SB" if ind_emigration_country=="806"
	replace ind_e_country="WS" if ind_emigration_country=="830"
	replace ind_e_country="TG" if ind_emigration_country=="376"
	replace ind_e_country="TK" if ind_emigration_country=="829"
	replace ind_e_country="TV" if ind_emigration_country=="816"
	replace ind_e_country="UM" if ind_emigration_country=="819"
	replace ind_e_country="WF" if ind_emigration_country=="832"
	replace ind_e_country="XZ" if ind_emigration_country=="980"
	replace ind_e_country="XX" if ind_emigration_country=="990"

	label var ind_e_country "Emigration country 99fewobs"
	tab  ind_e_country
	drop ind_emigration_country
    sort ID
    d
    sum
	compress
save $temp\emigrator.dta,replace

   keep ID 
   duplicates drop 
   sort ID
   gen ind_emigrates=1
   label var ind_emigrates "emigrates at some point, dummy"
save $temp\emigrates_dummy.dta,replace 
 
* create annual datasets for when immigrating
foreach yr in 00 01 02 03 04 05 06 07 08 09 10 11 12 13 {   
  use $temp\emigrator.dta, clear
	   keep if ind_emigration_year==20`yr'
	   keep ID ind_e_country
	   label var ind_e_country "emigrating to this country this year 99fewobs"
	   sort ID
  save $temp\emigrator_`yr'.dta,replace 
  }
      
* Immigration: same procedure as emigration
	// identify country codes using http://dbh.nsd.uib.no/dokumentasjon/landkoder.action
	// Country of immigration removed for many immigrants due to anonymzation issues
   
use $temp\temp_dsf.dta, clear 
	keep if year==2013
	drop if ind_immigration_country==" " & ind_immigration_year==1000
	keep ID ind_immigration_country ind_immigration_year 
		  
	gen ind_i_country=""			
	replace ind_i_country="99" if ind_immigration_country=="FÅ obs"
	replace ind_i_country="AL" if ind_immigration_country=="111"
	replace ind_i_country="AD" if ind_immigration_country=="114"
	replace ind_i_country="BE" if ind_immigration_country=="112"
	replace ind_i_country="BA" if ind_immigration_country=="155"
	replace ind_i_country="BG" if ind_immigration_country=="113"
	replace ind_i_country="DK" if ind_immigration_country=="101"
	replace ind_i_country="EE" if ind_immigration_country=="115"
	replace ind_i_country="FI" if ind_immigration_country=="103"
	replace ind_i_country="FR" if ind_immigration_country=="117"
	replace ind_i_country="FO" if ind_immigration_country=="104"
	replace ind_i_country="GI" if ind_immigration_country=="118"
	replace ind_i_country="GL" if ind_immigration_country=="102"
	replace ind_i_country="GG" if ind_immigration_country=="162"
	replace ind_i_country="GR" if ind_immigration_country=="119"
	replace ind_i_country="BY" if ind_immigration_country=="120"
	replace ind_i_country="IE" if ind_immigration_country=="121"
	replace ind_i_country="IS" if ind_immigration_country=="105"
	replace ind_i_country="IT" if ind_immigration_country=="123"
	replace ind_i_country="JE" if ind_immigration_country=="163"
	replace ind_i_country="XK" if ind_immigration_country=="161"
	replace ind_i_country="HR" if ind_immigration_country=="122"
	replace ind_i_country="CY" if ind_immigration_country=="500"
	replace ind_i_country="LV" if ind_immigration_country=="124"
	replace ind_i_country="LI" if ind_immigration_country=="128"
	replace ind_i_country="LT" if ind_immigration_country=="136"
	replace ind_i_country="LU" if ind_immigration_country=="129"
	replace ind_i_country="MK" if ind_immigration_country=="156"
	replace ind_i_country="MT" if ind_immigration_country=="126"
	replace ind_i_country="IM" if ind_immigration_country=="164"
	replace ind_i_country="MD" if ind_immigration_country=="138"
	replace ind_i_country="MC" if ind_immigration_country=="130"
	replace ind_i_country="ME" if ind_immigration_country=="160"
	replace ind_i_country="NL" if ind_immigration_country=="127"
	replace ind_i_country="NO" if ind_immigration_country=="0"
	replace ind_i_country="PL" if ind_immigration_country=="131"
	replace ind_i_country="PT" if ind_immigration_country=="132"
	replace ind_i_country="RO" if ind_immigration_country=="133"
	replace ind_i_country="RU" if ind_immigration_country=="140"
	replace ind_i_country="SM" if ind_immigration_country=="134"
	replace ind_i_country="RS" if ind_immigration_country=="159"
	replace ind_i_country="SK" if ind_immigration_country=="157"
	replace ind_i_country="SI" if ind_immigration_country=="146"
	replace ind_i_country="ES" if ind_immigration_country=="137"
	replace ind_i_country="GB" if ind_immigration_country=="139"
	replace ind_i_country="CH" if ind_immigration_country=="141"
	replace ind_i_country="SE" if ind_immigration_country=="106"
	replace ind_i_country="CZ" if ind_immigration_country=="158"
	replace ind_i_country="TR" if ind_immigration_country=="143"
	replace ind_i_country="DE" if ind_immigration_country=="144"
	replace ind_i_country="UA" if ind_immigration_country=="148"
	replace ind_i_country="HU" if ind_immigration_country=="152"
	replace ind_i_country="VA" if ind_immigration_country=="154"
	replace ind_i_country="AT" if ind_immigration_country=="153"
	replace ind_i_country="DZ" if ind_immigration_country=="203"
	replace ind_i_country="AO" if ind_immigration_country=="204"
	replace ind_i_country="BJ" if ind_immigration_country=="229"
	replace ind_i_country="BW" if ind_immigration_country=="205"
	replace ind_i_country="BF" if ind_immigration_country=="393"
	replace ind_i_country="BI" if ind_immigration_country=="216"
	replace ind_i_country="CF" if ind_immigration_country=="337"
	replace ind_i_country="DJ" if ind_immigration_country=="250"
	replace ind_i_country="EG" if ind_immigration_country=="249"
	replace ind_i_country="GQ" if ind_immigration_country=="235"
	replace ind_i_country="CI" if ind_immigration_country=="239"
	replace ind_i_country="ER" if ind_immigration_country=="241"
	replace ind_i_country="ET" if ind_immigration_country=="246"
	replace ind_i_country="GA" if ind_immigration_country=="254"
	replace ind_i_country="GM" if ind_immigration_country=="256"
	replace ind_i_country="GH" if ind_immigration_country=="260"
	replace ind_i_country="GN" if ind_immigration_country=="264"
	replace ind_i_country="GW" if ind_immigration_country=="266"
	replace ind_i_country="CM" if ind_immigration_country=="270"
	replace ind_i_country="CV" if ind_immigration_country=="273"
	replace ind_i_country="KE" if ind_immigration_country=="276"
	replace ind_i_country="KM" if ind_immigration_country=="220"
	replace ind_i_country="CD" if ind_immigration_country=="279"
	replace ind_i_country="CG" if ind_immigration_country=="278"
	replace ind_i_country="LS" if ind_immigration_country=="281"
	replace ind_i_country="LR" if ind_immigration_country=="283"
	replace ind_i_country="LY" if ind_immigration_country=="286"
	replace ind_i_country="MG" if ind_immigration_country=="289"
	replace ind_i_country="MW" if ind_immigration_country=="296"
	replace ind_i_country="ML" if ind_immigration_country=="299"
	replace ind_i_country="MA" if ind_immigration_country=="303"
	replace ind_i_country="MR" if ind_immigration_country=="306"
	replace ind_i_country="MU" if ind_immigration_country=="307"
	replace ind_i_country="YT" if ind_immigration_country=="322"
	replace ind_i_country="MZ" if ind_immigration_country=="319"
	replace ind_i_country="NA" if ind_immigration_country=="308"
	replace ind_i_country="NE" if ind_immigration_country=="309"
	replace ind_i_country="NG" if ind_immigration_country=="313"
	replace ind_i_country="RE" if ind_immigration_country=="323"
	replace ind_i_country="RW" if ind_immigration_country=="329"
	replace ind_i_country="ST" if ind_immigration_country=="333"
	replace ind_i_country="SN" if ind_immigration_country=="336"
	replace ind_i_country="SC" if ind_immigration_country=="338"
	replace ind_i_country="SL" if ind_immigration_country=="339"
	replace ind_i_country="SO" if ind_immigration_country=="346"
	replace ind_i_country="SD" if ind_immigration_country=="356"
	replace ind_i_country="SZ" if ind_immigration_country=="357"
	replace ind_i_country="ZA" if ind_immigration_country=="359"
	replace ind_i_country="SS" if ind_immigration_country=="355"
	replace ind_i_country="TZ" if ind_immigration_country=="369"
	replace ind_i_country="TO" if ind_immigration_country=="813"
	replace ind_i_country="TD" if ind_immigration_country=="373"
	replace ind_i_country="TN" if ind_immigration_country=="379"
	replace ind_i_country="UG" if ind_immigration_country=="386"
	replace ind_i_country="EH" if ind_immigration_country=="304"
	replace ind_i_country="ZM" if ind_immigration_country=="389"
	replace ind_i_country="ZW" if ind_immigration_country=="326"
	replace ind_i_country="AF" if ind_immigration_country=="404"
	replace ind_i_country="AI" if ind_immigration_country=="660"
	replace ind_i_country="AM" if ind_immigration_country=="406"
	replace ind_i_country="AW" if ind_immigration_country=="657"
	replace ind_i_country="AZ" if ind_immigration_country=="407"
	replace ind_i_country="BH" if ind_immigration_country=="409"
	replace ind_i_country="BD" if ind_immigration_country=="410"
	replace ind_i_country="BT" if ind_immigration_country=="412"
	replace ind_i_country="BN" if ind_immigration_country=="416"
	replace ind_i_country="AE" if ind_immigration_country=="426"
	replace ind_i_country="PS" if ind_immigration_country=="524"
	replace ind_i_country="PH" if ind_immigration_country=="428"
	replace ind_i_country="GE" if ind_immigration_country=="430"
	replace ind_i_country="HK" if ind_immigration_country=="436"
	replace ind_i_country="IN" if ind_immigration_country=="444"
	replace ind_i_country="ID" if ind_immigration_country=="448"
	replace ind_i_country="IQ" if ind_immigration_country=="452"
	replace ind_i_country="IR" if ind_immigration_country=="456"
	replace ind_i_country="IL" if ind_immigration_country=="460"
	replace ind_i_country="JP" if ind_immigration_country=="464"
	replace ind_i_country="JO" if ind_immigration_country=="476"
	replace ind_i_country="KH" if ind_immigration_country=="478"
	replace ind_i_country="KZ" if ind_immigration_country=="480"
	replace ind_i_country="CN" if ind_immigration_country=="484"
	replace ind_i_country="KG" if ind_immigration_country=="502"
	replace ind_i_country="KI" if ind_immigration_country=="815"
	replace ind_i_country="KW" if ind_immigration_country=="496"
	replace ind_i_country="LA" if ind_immigration_country=="504"
	replace ind_i_country="LB" if ind_immigration_country=="508"
	replace ind_i_country="MO" if ind_immigration_country=="510"
	replace ind_i_country="MY" if ind_immigration_country=="512"
	replace ind_i_country="MV" if ind_immigration_country=="513"
	replace ind_i_country="MH" if ind_immigration_country=="835"
	replace ind_i_country="MN" if ind_immigration_country=="516"
	replace ind_i_country="MM" if ind_immigration_country=="420"
	replace ind_i_country="NP" if ind_immigration_country=="528"
	replace ind_i_country="KP" if ind_immigration_country=="488"
	replace ind_i_country="MP" if ind_immigration_country=="840"
	replace ind_i_country="OM" if ind_immigration_country=="520"
	replace ind_i_country="PK" if ind_immigration_country=="534"
	replace ind_i_country="PW" if ind_immigration_country=="839"
	replace ind_i_country="QA" if ind_immigration_country=="540"
	replace ind_i_country="SA" if ind_immigration_country=="544"
	replace ind_i_country="SG" if ind_immigration_country=="548"
	replace ind_i_country="LK" if ind_immigration_country=="424"
	replace ind_i_country="SH" if ind_immigration_country=="209"
	replace ind_i_country="SY" if ind_immigration_country=="564"
	replace ind_i_country="KR" if ind_immigration_country=="492"
	replace ind_i_country="TJ" if ind_immigration_country=="550"
	replace ind_i_country="TW" if ind_immigration_country=="432"
	replace ind_i_country="TH" if ind_immigration_country=="568"
	replace ind_i_country="TM" if ind_immigration_country=="552"
	replace ind_i_country="UZ" if ind_immigration_country=="554"
	replace ind_i_country="VU" if ind_immigration_country=="812"
	replace ind_i_country="VN" if ind_immigration_country=="575"
	replace ind_i_country="YE" if ind_immigration_country=="578"
	replace ind_i_country="TL" if ind_immigration_country=="537"
	replace ind_i_country="AG" if ind_immigration_country=="603"
	replace ind_i_country="BS" if ind_immigration_country=="605"
	replace ind_i_country="BB" if ind_immigration_country=="602"
	replace ind_i_country="BZ" if ind_immigration_country=="604"
	replace ind_i_country="BM" if ind_immigration_country=="606"
	replace ind_i_country="BQ" if ind_immigration_country=="659"
	replace ind_i_country="CA" if ind_immigration_country=="612"
	replace ind_i_country="KY" if ind_immigration_country=="613"
	replace ind_i_country="CR" if ind_immigration_country=="616"
	replace ind_i_country="CU" if ind_immigration_country=="620"
	replace ind_i_country="VI" if ind_immigration_country=="601"
	replace ind_i_country="VG" if ind_immigration_country=="608"
	replace ind_i_country="DO" if ind_immigration_country=="624"
	replace ind_i_country="IO" if ind_immigration_country=="213"
	replace ind_i_country="DM" if ind_immigration_country=="622"
	replace ind_i_country="SV" if ind_immigration_country=="672"
	replace ind_i_country="GD" if ind_immigration_country=="629"
	replace ind_i_country="GP" if ind_immigration_country=="631"
	replace ind_i_country="GT" if ind_immigration_country=="632"
	replace ind_i_country="HT" if ind_immigration_country=="636"
	replace ind_i_country="HN" if ind_immigration_country=="644"
	replace ind_i_country="JM" if ind_immigration_country=="648"
	replace ind_i_country="MQ" if ind_immigration_country=="650"
	replace ind_i_country="MX" if ind_immigration_country=="652"
	replace ind_i_country="MS" if ind_immigration_country=="654"
	replace ind_i_country="NI" if ind_immigration_country=="664"
	replace ind_i_country="PA" if ind_immigration_country=="668"
	replace ind_i_country="PR" if ind_immigration_country=="685"
	replace ind_i_country="KN" if ind_immigration_country=="677"
	replace ind_i_country="LC" if ind_immigration_country=="678"
	replace ind_i_country="VC" if ind_immigration_country=="679"
	replace ind_i_country="BL" if ind_immigration_country=="687"
	replace ind_i_country="MF" if ind_immigration_country=="686"
	replace ind_i_country="PM" if ind_immigration_country=="676"
	replace ind_i_country="SX" if ind_immigration_country=="658"
	replace ind_i_country="TT" if ind_immigration_country=="680"
	replace ind_i_country="TC" if ind_immigration_country=="681"
	replace ind_i_country="US" if ind_immigration_country=="684"
	replace ind_i_country="AR" if ind_immigration_country=="705"
	replace ind_i_country="BO" if ind_immigration_country=="710"
	replace ind_i_country="BR" if ind_immigration_country=="715"
	replace ind_i_country="CL" if ind_immigration_country=="725"
	replace ind_i_country="CO" if ind_immigration_country=="730"
	replace ind_i_country="EC" if ind_immigration_country=="735"
	replace ind_i_country="FK" if ind_immigration_country=="740"
	replace ind_i_country="GF" if ind_immigration_country=="745"
	replace ind_i_country="GY" if ind_immigration_country=="720"
	replace ind_i_country="PY" if ind_immigration_country=="755"
	replace ind_i_country="PE" if ind_immigration_country=="760"
	replace ind_i_country="SR" if ind_immigration_country=="765"
	replace ind_i_country="UY" if ind_immigration_country=="770"
	replace ind_i_country="VE" if ind_immigration_country=="775"
	replace ind_i_country="AS" if ind_immigration_country=="802"
	replace ind_i_country="AU" if ind_immigration_country=="805"
	replace ind_i_country="CX" if ind_immigration_country=="807"
	replace ind_i_country="CK" if ind_immigration_country=="809"
	replace ind_i_country="FJ" if ind_immigration_country=="811"
	replace ind_i_country="PF" if ind_immigration_country=="814"
	replace ind_i_country="GU" if ind_immigration_country=="817"
	replace ind_i_country="CC" if ind_immigration_country=="808"
	replace ind_i_country="FM" if ind_immigration_country=="826"
	replace ind_i_country="NR" if ind_immigration_country=="818"
	replace ind_i_country="NZ" if ind_immigration_country=="820"
	replace ind_i_country="NU" if ind_immigration_country=="821"
	replace ind_i_country="NF" if ind_immigration_country=="822"
	replace ind_i_country="NC" if ind_immigration_country=="833"
	replace ind_i_country="PG" if ind_immigration_country=="827"
	replace ind_i_country="PN" if ind_immigration_country=="828"
	replace ind_i_country="SB" if ind_immigration_country=="806"
	replace ind_i_country="WS" if ind_immigration_country=="830"
	replace ind_i_country="TG" if ind_immigration_country=="376"
	replace ind_i_country="TK" if ind_immigration_country=="829"
	replace ind_i_country="TV" if ind_immigration_country=="816"
	replace ind_i_country="UM" if ind_immigration_country=="819"
	replace ind_i_country="WF" if ind_immigration_country=="832"
	replace ind_i_country="XZ" if ind_immigration_country=="980"
	replace ind_i_country="XX" if ind_immigration_country=="990"
	
	label var ind_i_country "Immigration country 99fewobs"
	tab  ind_i_country
	drop ind_immigration_country
    sort ID
    d
    sum
	compress
save $temp\immigrator.dta, replace 

   keep ID 
   duplicates drop 
   sort ID
   gen immigrates=1
   label var immigrates "immigrates at some point, dummy"
save $temp\immigrates_dummy.dta,replace 
 
* Create annual datasets for when immigrating
foreach yr in 00 01 02 03 04 05 06 07 08 09 10 11 12 13 {
   use $temp\immigrator.dta, clear
	   keep if ind_immigration_year==20`yr'
	   keep ID ind_i_country
	   label var ind_i_country "immigrating to this country this year 99fewobs"
	   sort ID
   save $temp\immigrator_`yr'.dta,replace 
   }

* Fix the education dataset
use $source\w141281_utd_avid.dta, clear
	 duplicates drop
	 rename lopenr_fnr ID 
	 destring ID, replace
	 drop if ID==.
	 gen ind_edulevel=""
	 replace ind_edulevel="0" if substr(utd_2013,1,1)=="0" 
	 replace ind_edulevel="1" if substr(utd_2013,1,1)=="1" | substr(utd_2013,1,1)=="2"
	 replace ind_edulevel="2" if substr(utd_2013,1,1)=="3" | substr(utd_2013,1,1)=="4" | substr(utd_2013,1,1)=="5"
	 replace ind_edulevel="3" if substr(utd_2013,1,1)=="6" | substr(utd_2013,1,1)=="7" | substr(utd_2013,1,1)=="8"
	 label var ind_edulevel "observed 2013- 1:primary 2:secundary 3:tertiary"
	 tab ind_edulevel, m 
	 duplicates tag ID , generate(dupl)
	 tab dupl
	 sort ID ind_edulevel
	 by ID: keep if _n==_N
	 tab dupl
	 drop dupl
	 gen ind_university=(ind_edulevel=="3")
	 label variable ind_university "completed university degree"
	 tab ind_university, m
	 gen ind_edu_bus=(utd_2013=="64" | utd_2013=="74" | utd_2013=="84" )
	 label var ind_edu_bus "higher education in business administration"
	 tab ind_edu_bus, m
	 sort ID
	 keep ID ind*
	 compress
save $temp\edulevel.dta, replace
 
 
* Number of children
use $source\slekt, clear
	keep if KNY_KNYTNING_TYPE=="BARN"
	drop KNY_KNYTNING_TYPE
	duplicates report FNR_FRA_NN
	duplicates report FNR_TIL_NN
	*the parent is indicated by FNR_FRA_NN 
    rename FNR_FRA_NN ID
	rename FNR_TIL_NN ind_children
	drop if ID==.
	count
	collapse (count) ind_children, by(ID)
	label var ind_children "number of children"
	replace ind_children=0 if ind_children==.
	tab ind_children, m
	sort ID
	compress
save $temp\children.dta, replace
 
 
************************************************************************
*** PART C: 80% WEALTH TAX REDUCTION RULE
************************************************************************
use $source\nye_80nedsettelse_nov2016\nedsettelse80.dta, clear
   rename nedsettelse avoid_80reduction_amount
   label var avoid_80reduction_amount "amount tax reduction 80% rule"   
   
   * the amount is rounded to the nearest 1000, meaning that any positive amount is 
   * rounded to 0. Replace all 0's with the expected mean in the interval 0-499: 250
   replace avoid_80reduction_amount=250 if avoid_80reduction_amount==0   
   
   *make dummy for ever having wealth tax reduction
   gen avoid_80reduction_ever=1
   label var avoid_80reduction_ever "dummy, has ever had tax reduction 80% rule"
   
   *how many years with tax reduction?
   egen avoid_80reduction_numberyears=sum(avoid_80reduction_ever), by(ID)
   label var avoid_80reduction_numberyears "number years with tax reduction 80% rule"
   
   sort ID year
   tab year
   sum
save $temp\wealth80_allinfo.dta, replace
   sort year
   collapse (sum) avoid_80reduction_amount, by(year)
   
   *make dataset with dummy ever haveing tax reductino 80% rule
use  $temp\wealth80_allinfo.dta, clear
   keep ID avoid_80reduction_numberyears avoid_80reduction_ever
   duplicates drop
   sort ID
save $temp\wealth80_dummy.dta, replace
   
   *make annual datasest on tax reductino 80% rule
foreach yr in 01 02 03 04 05 06 07 08 09 10 11 12 13 {
    use  $temp\wealth80_allinfo.dta, clear
	keep if year==20`yr'
	keep ID avoid_80reduction_amount
	sort ID
save $temp\wealth80_`yr'.dta, replace
}


*********************************************************************************
* PART D: COMBINE DATASETS TO CREATE PERSKAR
*********************************************************************************
 
* Make permanent panels with personal characteristics
foreach yr in 02 03 04 05 06 07 08 09 10 11 12 13 {
use $temp\temp_dsf.dta, clear
	keep if year==20`yr'
	drop ind_immigration* ind_emigration* lag_stat year
	sort ID	
  merge 1:1 ID using $temp\emigrator_`yr'.dta
	drop if _m==2
	drop _m
	sort ID
  merge 1:1 ID using $temp\immigrator_`yr'.dta
	drop if _m==2
	drop _m
	sort ID  
  merge 1:1 ID using $temp\emigrates_dummy.dta
	drop if _m==2
	drop _m
	sort ID  
  merge 1:1 ID using $temp\immigrates_dummy.dta
	drop if _m==2
	drop _m
	rename immigrates ind_immigrates
	sort ID
  merge 1:1 ID using $data\vd_dummy.dta
	drop if _m==2
	drop _m
	sort ID 
  merge 1:1 ID using $data\voluntary_disclosure.dta 
	drop if _m==2
	drop _m
	sort ID
  merge 1:1 ID using $temp\edulevel.dta
	drop if _m==2
	drop _m
	sort ID
  merge 1:1 ID using $temp\children.dta
	   drop if _m==2
	   drop _m
	   sort ID
  merge 1:1 ID using $temp\wealth80_`yr'.dta
	   drop if _m==2
	   drop _m
	   sort ID
  merge 1:1 ID using $temp\wealth80_dummy.dta
	   drop if _m==2
	   drop _m
	   sort ID
       
	   cap drop year	   
	   duplicates report ID
	   cap replace vd_evader=0 if vd_evader==.
	   cap replace fr_reporting=0 if fr_reporting==.
	   cap replace ind_emigrates=0 if ind_emigrates==.
	   cap replace ind_immigrates=0 if ind_immigrates==.
	   cap replace avoid_80reduction_numberyears=0 if avoid_80reduction_numberyears==.
	   cap replace avoid_80reduction_ever=0 if avoid_80reduction_ever==.
	   cap replace avoid_80reduction_amount=0 if avoid_80reduction_amount==.
	   	
** Make variable for age
	   tab ind_birth_year, m
	   rename ind_birth_year ind_dob
	   label var ind_dob "Date of birth"
* Make dob continous
	   replace ind_dob=ind_dob-5+int(10*runiform())
	   gen ind_age=20`yr'-ind_dob
	   label var ind_age "age"   
*correct for the inaccurate age definitino from the rounding up of the birth year
	   replace ind_age=0 if ind_age<0
	   tab ind_age, m	   
	   
	   gen ind_emigrates_thisyear=(ind_e_country!="")
	   label var ind_emigrates_thisyear "emigrates this year"
	   cap drop year
	   compress
	   sort ID  
	   sum
	   d, fullname
save $data\perskar_`yr'.dta, replace
}
 


*********************************************************************************  
*we only have personal characteristics from 2002 and onward. 
* so keep the constant characteristics for 2002 and use those also for 2001, including household info, and make missing for the rest 
 
use $data\perskar_02.dta, clear
  keep ID ind_dob ind_ID_spouse ind_status ind_foreign_country ind_county ind_children ind_male ind_foreigner ind_emigrates ind_immigrates vd_evader vd_year_of_contact vd_taxed_disclosed_income vd_taxed_disclosed_wealth vd_year_of_decision vd_disclosed_country vd_case_in_process vd_case_dropped vd_case_closed ind_edulevel ind_university ind_edu_bus avoid_80reduction_ever avoid_80reduction_numberyears 
  gen ind_age=2001-ind_dob
  label var ind_age "age"   

*correct for the inaccurate age definitino from the rounding up of the birth year
  replace ind_age=0 if ind_age<0

* add on evader info, which we do have for 2001
   sort ID
  merge 1:1 ID using $temp\penalty_01.dta
   drop if _m==2
   drop _m
   sort ID 
  merge 1:1 ID using $temp\wealth80_01.dta
   drop if _m==2
   drop _m
   sort ID
merge 1:1 ID using $temp\wealth80_dummy.dta
   drop if _m==2
   drop _m
   sort ID
   duplicates report ID
	   cap replace vd_evader=0 if vd_evader==.
	   cap replace fr_reporting=0 if fr_reporting==.
	   cap replace ind_emigrates=0 if ind_emigrates==.
	   cap replace ind_immigrates=0 if ind_immigrates==.
	   cap replace avoid_80reduction_numberyears=0 if avoid_80reduction_numberyears==.
	   cap replace avoid_80reduction_ever=0 if avoid_80reduction_ever==.
	   cap replace avoid_80reduction_amount=0 if avoid_80reduction_amount==.

*create missing for the variables we do not have here
       gen  ind_marital=.
       label var ind_marital "1:unmarried, 2:married, 3:widow/er, 4:divorced, 5:separated"             
       gen  ind_divorced=. 
       label var ind_divorced "divorced during the year"
       gen   ind_married=.
       label var ind_married "got married during the year"
       gen   ind_e_country=""
       label var ind_e_country "emigrating to this country this year 99fewobs"
       gen ind_i_country=""
       label var ind_i_country "immigrating to this country this year 99fewobs"
       gen  ind_emigrates_thisyear=.
       label var ind_emigrates_thisyear "emigrates this year"   

      d, fullname
      sum
	  compress
      sort ID
      save $data\perskar_01.dta, replace


********************************************************	
 clear
 log close
 
  
 
	 

 
  
