
clear
set more off

	global prog   "\\...\CLEAN\prog"
	global source "\\...\source_data\no"
	global data   "\\...\CLEAN\data"
    global temp   "\\...\data\no-backup"
	
cap log close
log using $prog\makedata3_firm_infoCLEAN.log, replace

/*******************************************************************************
*
*  Add all informations on all firms from all sources:
*	  Accounting data, income and profits: 2000-2012
*	  Firm register: sector, whether holding company and foreign relations, county, etc 2002-2013
*	  Share register: share capital, total dividends, total shares, firm level, 2004-2013 
* 	  Employment register: sum number of emplyees whe received payments, except board members
*     Role register: Board members and CEOs
*     
********************************************************************************/

* Make dummies for whether the shareholder is board member, ceo, employee. 
* identify the CEO by the board/CEO member with the higher wage in LTO employment register*
* count number of employees in the firm, not board members, based on the employment register

foreach yr in 02 03 04 05 06 07 08 09 10 11 12 13 {
 
use $source\roller, clear
  keep if aar==20`yr'
  drop aar
  rename ORGNR_NN as_orgnr
  rename FNR_NN ID
  sort as_orgnr ID
  compress
save $temp\roller_`yr', replace
 
use $source\lto, clear
  keep if aar==20`yr'
  keep ORGNR_NN FNR_NN belop
  rename ORGNR_NN as_orgnr
  rename FNR_NN ID
  rename belop ind_lto_wage
  drop if ind_lto_wage<=0  
  sort as_orgnr ID
*have mulitple observations per firm per individual, can be due to multiple employment spells, and have one line per spell per firm.
  collapse (sum) ind_lto_wage, by(as_orgnr ID)
  sort as_orgnr ID
  compress
save $temp\lto`yr', replace
  merge 1:1 as_orgnr ID using $temp\roller_`yr'
  keep if _m==3
  drop _m
  sort as_orgnr ind_lto_wage
  by as_orgnr: keep if _n==_N
  drop ind_lto_wage
  sort as_orgnr ID
  gen CEO=1
  merge 1:1 as_orgnr ID using $temp\roller_`yr'
  drop if _m==1
  drop _m
  replace CEO=0 if CEO==.
  tab CEO
  sort as_orgnr ID
  compress
save  $data\board_`yr', replace

*count the number of employees in a firm, excluding board members
  drop if CEO==1
  merge 1:1 as_orgnr ID  using $temp\lto`yr'
  drop if _m==3
  keep as_orgnr ID
  collapse (count) ID, by(as_orgnr)
  rename ID firm_employees
  label var firm_employees "number employees excl board"
  sum firm_employees, det
  duplicates report, as_orgnr
  sort as_orgnr
  compress
save $data\employees_`yr', replace
 }
 
* generate empty datasets for 2000 and 2001 
  clear
  foreach var in ID as_orgnr CEO {
  gen `var'=.
  }
  sort as_orgnr ID
save $data\board_00, replace
save $temp\board_01, replace
  keep as_orgnr
  gen firm_employees=.
  label var firm_employees "number employees excl board"
  sort as_orgnr
save $data\employees_00, replace
save $data\employees_01, replace
 

********************************************************************************
* find total dividends distributed from the firm based on payments in the shareholder register
* can then use that to impute change in retained earnings, based on after-tax profits net of dividends.
foreach yr in 04 05 06 07 08 09 10 11 12 13 {
  use $source\AR_selskap.dta, clear
  keep if aar==20`yr'
  keep ORGNR_NN UTBYTTE_TOTALT TOT_KAPITAL_3112
  rename ORGNR_NN as_orgnr
  rename UTBYTTE_TOTALT firm_dividends
  rename TOT_KAPITAL_3112 firm_sharecapital
* deal with mulitple observations
  collapse (sum) firm_dividends (first) firm_sharecapital, by(as_orgnr)
  label var firm_sharecapital "total face value nominal equity"
  label var firm_dividends "distributed dividends total"
  sort as_orgnr
  compress
save $temp\div`yr', replace
}
 
*generate empty data sets for 2000-2003, when share register does not exist
  clear
  foreach var in as_orgnr firm_dividends firm_sharecapital {
  gen `var'=.
  }
  label var firm_sharecapital "total face value nominal equity"
  label var firm_dividends "distributed dividends total"
  sort as_orgnr
save $temp\div00, replace
save $temp\div01, replace
save $temp\div02, replace
save $temp\div03, replace
	

******************************************************************************** 
*sector indicator, is it a holding company? + other info form Foretaksregisteret
foreach yr in 02 03 04 05 06 07 08 09 10 11 12 13 {
use $source\Enhetsregisteret.dta, clear
  keep if aar==20`yr'
  rename ORGNR_NN as_orgnr
  rename fylke firm_county
  gen firm_holding=(holdingselskap=="J")
  label var firm_holding "sector code indicates holding company -only until 2008"
  gen firm_foreign=(UTL_SEKTOR=="J")
  label var firm_foreign "sector code indicates foreign ownerhship"
  rename  UTLAND_KODE2 firm_foreign_country
  label var firm_foreign_country "country of foreign ownership"
  rename NAERING_HOVEDOMRAADE_KODE firm_sector
  keep as_orgnr firm*
  sort as_orgnr
  compress
save $temp\for`yr', replace
 }
 
*generate empty datasets for missing years
  clear
  foreach var in as_orgnr firm_county firm_holding firm_foreign firm_foreign_country  firm_sector {
  gen  `var'=. 
  }
  label var firm_holding "sector code indicates holding company -only until 2008"
  label var firm_foreign "sector code indicates foreign ownerhship"
  label var firm_foreign_country "country of foreign ownership"
  sort as_orgnr
save $temp\for00, replace
save $temp\for01, replace
 
********************************************************************************
* income variables from accounting register
 
foreach yr in 05 06 07 08 09 10 11 12 {
use $source\w141281_regnskap_2005_2012_avid.dta, clear
  keep if aar=="20`yr'"
  keep lopenr_orgnr p9000 p9060 p9010 p9100 p9200 
  rename lopenr_orgnr as_orgnr
  rename p9000 firm_operating_income
  rename p9010 firm_operating_costs
  rename p9100 firm_profits_beforetax
  rename p9200 firm_profits_aftertax
  rename p9060 firm_financial_income 
  label var firm_operating_income "operating income"
  label var firm_profits_beforetax "before tax profits"
  label var firm_profits_aftertax "after tax profits"
  label var firm_operating_costs "operating costs"
  label var firm_financial_income "financial income" 
* make alternative holding indcator, based on turnover structure, only for current year
  replace firm_operating_income=0 if firm_operating_income==.
  replace firm_financial_income=0 if firm_financial_income==.
  gen firm_holding2=(firm_operating_income<1 & firm_financial_income>1 & firm_financial_income<.)
  label var firm_holding2 "defined as holding company if all income as financial income"
  tab firm_holding2, m   
  sort as_orgnr
  compress
save $temp\regn`yr', replace
   }
   
foreach yr in 00 01 02 03 04  {
use $source\w141281_regnskap_1999_2004_avid.dta, clear
  keep if aar=="20`yr'"
  keep lopenr_orgnr drinnt drkost ordfskat reseskat sumfinnt  
  rename lopenr_orgnr as_orgnr  
* until 2004, the accounting data are in 1000 NOK, now correct for that
  gen  firm_operating_income=drinnt*1000
  gen  firm_profits_beforetax=ordfskat*1000 
  gen  firm_profits_aftertax=reseskat*1000 
  gen  firm_operating_costs=drkost*1000
  gen  firm_financial_income=sumfinnt*1000
  drop drinnt ordfska reseskat drkost sumfinnt
  label var firm_operating_income "operating income"
  label var firm_profits_beforetax "before tax profits"
  label var firm_profits_aftertax "after tax profits"
  label var firm_operating_costs "operating costs"
  label var firm_financial_income "financial income"
* make alternative holding indcator, based on turnover structure, only for current year
  replace firm_operating_income=0 if firm_operating_income==.
  replace firm_financial_income=0 if firm_financial_income==.
  gen firm_holding2=(firm_operating_income<1 & firm_financial_income>1 & firm_financial_income<.)
  label var firm_holding2 "defined as holding company if all income as financial income"
  tab firm_holding2, m
  sort as_orgnr
  compress
save $temp\regn`yr', replace
}
   
*generate empty data sets for 2013
  clear
  foreach var in as_orgnr firm_operating_income firm_profits_beforetax firm_profits_aftertax firm_operating_costs firm_financial_income firm_holding2 {
   gen `var'=.
  }
   label var firm_operating_income "operating income"
   label var firm_profits_beforetax "before tax profits"
   label var firm_profits_aftertax "after tax profits"
   label var firm_operating_costs "operating costs"
   label var firm_financial_income "financial income"
   label var firm_holding2 "defined as holding company if all income as financial income"
   sort as_orgnr
save $temp\regn13, replace
	
********************************************************************************************************* 
* indentify dividend maximizing firms
use $temp\regn04, clear
  keep as_orgnr  firm_profits_aftertax
  sum
  sum firm_profits_aftertax, det
  drop if firm_profits_aftertax==.
  sort as_orgnr
save $temp\04, replace
   
use $temp\div05, clear
  keep as_orgnr  firm_dividends
  sum
  sum firm_dividends
  drop if firm_dividends==.
  sort as_orgnr
  merge 1:1 as_orgnr using $temp\04
  keep if _m==3
  drop _m
*now make two dummies for maximizing dividends, based on previous years total after-tax profits
*got same result for the dummy if using the imputed retained earnings.
  gen avoid_divmax05_prof=(firm_dividends>=firm_profits_aftertax & firm_dividends>0)
  tab avoid_divmax05_prof, m
  keep as_orgnr avoid*
  label var avoid_divmax05_prof "dividend maximiser05, paid more than aftertaxprofits04"
  sort as_orgnr
  compress
save $temp\avoid, replace
  
*****************************************************************************************************************
* Merge all data sets together. 
* Keep all firms that are either in the accounting data or in the share data
*****************************************************************************************************************
foreach yr in 00 01 02 03 04 05 06 07 08 09 10 11 12 13 {
use $temp\regn`yr', clear
* construct simplified imputed retained earnings, based on available variables
  merge 1:1 as_orgnr using $temp\div`yr'
  drop _m
  gen firm_retained_earnings = firm_profits_aftertax - firm_dividends
  label var firm_retained_earnings "Change in retained earnings, profits-dividneds, same years of obs"
  sum firm_retained_earnings, det
  sort as_orgnr 
*add firm level info
  merge 1:1 as_orgnr using $temp\for`yr'
  drop if _m==2
  drop _m
  sort as_orgnr 
*add number of employees imputed from the employment register
  merge 1:1 as_orgnr using $data\employees_`yr'
  drop if _m==2
  drop _m
  sort as_orgnr  

* add info on whether the firm is dividend maximizing pre-2006, to prepare for dividend tax
  merge 1:1 as_orgnr using  $temp\avoid
  drop if _m==2
  drop _m
  replace avoid_divmax05_prof=0 if avoid_divmax05_prof==.
  drop if as_orgnr==.
  sort as_orgnr
  compress
  sum
save  $temp\corporate_info_`yr', replace
 
*now make dataset to indicate when first appear in data
  keep as_orgnr 
  gen year=20`yr'
save  $temp\orgnr_`yr', replace
} 
   
use $temp\orgnr_01, clear
foreach yr in 00 01 02 03 04 05 06 07 08 09 10 11 12 13 {
  append using $temp\orgnr_`yr'
}
  tab year
  sort as_orgnr year
  by as_orgnr, sort: egen firm_firstyear=min(year)
  keep as_orgnr firm_firstyear
  duplicates drop 
  replace firm_firstyear=. if firm_firstyear==2000 
  label var firm_firstyear "first year the firm is observed, appr.foundation year from 2002 onward"
  tab firm_firstyear, m
  sort as_orgnr
save $temp\firstyear, replace
  
*add this to the main data and make permanent annual firm level data sets
foreach yr in 00 01 02 03 04 05 06 07 08 09 10 11 12 13 {
use $temp\corporate_info_`yr', clear
  sort as_orgnr
  merge 1:1 as_orgnr using $temp\firstyear
  drop if _m==2
  drop _m
  sort as_orgnr
  compress
  tab firm_firstyear firm_holding, m
  sum
save  $data\corporate_info_`yr', replace
} 
 
********************************************************************************************************

clear
log close


  
  
 
 
  
