
clear
set more off

	global prog   "\\...\CLEAN\prog"
	global source "\\...\source_data\no"
	global data   "\\...\CLEAN\data"
    global temp   "\\...\data\no-backup"

cap log close
log using $prog\makedata6_indlevelfirminfoCLEAN.log, replace

********************************************************************************
* Add firm level info to shareholder level
********************************************************************************

 
* tax avoicance inticators, for majority owner

foreach yr in  04 05 06 07 08 09 10 11 12 {
use $data\total_ownshares`yr'_ind.dta, clear
  keep if ownshare>=0.5 & ownshare<.
  keep ID as_orgnr
  sort as_orgnr
  merge n:1 as_orgnr using $data\corporate_info_`yr'
  keep if _m==3
  drop _m
  compress
  d
  sum
save $temp\pre`yr', replace
   
*make indicator for dividend maximizer or holding company based 
*define as holding company if all turnover from financial income
  keep ID  firm_firstyear firm_holding2
  replace firm_holding2=0 if firm_holding2==. 
  rename firm_holding2 avoid_holding2_currentown 
  gen avoid_holding2_establ_05=(firm_firstyear==2005 & avoid_holding2_currentown==1)
  gen avoid_holding2_establ_pre09=(firm_firstyear<2009 & avoid_holding2_currentown==1)
  gen avoid_holding2_currentfound=(firm_firstyear==20`yr' & avoid_holding2_currentown==1)
  gen avoid_holding2_establ_post09=(firm_firstyear>=2009 & firm_firstyear<. &  avoid_holding2_currentown==1)
  collapse (max)  avoid_holding2_currentown avoid_holding2_currentfound avoid_holding2_establ_05 avoid_holding2_establ_pre09 avoid_holding2_establ_post09, by(ID)
  label var avoid_holding2_currentown "majority owner holding2 current year"
  label var avoid_holding2_establ_05 "establishes majority own holding2 2005"
  label var avoid_holding2_establ_pre09 "establishes majority own holding2 before 2009"
  label var avoid_holding2_establ_post09 "establishes majority own holding2 2009 or later"
  label var avoid_holding2_currentfound "establishes majority own holding2 current year"   
  sort ID
  compress
  d
  sum
save $temp\holding2_`yr', replace
} 

*make dummy for ever being holding2 or dividend avoider company   
use $temp\holding2_04, clear
foreach yr in  05 06 07 08 09 10 11 12  {
  append using $temp\holding2_`yr' 
  }
  drop avoid_holding2_currentfound
  rename avoid_holding2_currentown avoid_holding2
  replace avoid_holding2=0 if avoid_holding2==.
  replace avoid_holding2_establ_05=0 if avoid_holding2_establ_05==.
  replace avoid_holding2_establ_pre09=0 if avoid_holding2_establ_pre09==.
  replace avoid_holding2_establ_post09=0 if avoid_holding2_establ_post09==.
  collapse (max) avoid* , by(ID)
  label var avoid_holding2 "majority owner holding company at some point 04-08"
  label var avoid_holding2_establ_05 "establishes majority own holding 2005"
  label var avoid_holding2_establ_pre09 "establishes majority own holding before 2009"
  label var avoid_holding2_establ_post09 "establishes majority own holding2 2009 or later"
  compress
  sort ID
save $temp\hold2, replace
   
* make indicator for holding company based on NACE-code, only available until 2004-2008 
foreach yr in  04 05 06 07 08  {
use $temp\pre`yr', clear
  keep if firm_holding==1 
  rename firm_holding avoid_holding_currentown
  gen avoid_holding_establ_05=(firm_firstyear==2005)
  gen avoid_holding_establ_pre09=(firm_firstyear<2009)
  gen avoid_holding_currentfound=(firm_firstyear==20`yr')
  keep ID avoid*
  collapse (max) avoid_holding* , by(ID)
  label var avoid_holding_currentown "majority owner holding current year"
  label var avoid_holding_establ_05 "establishes majority own holding 2005"
  label var avoid_holding_establ_pre09 "establishes majority own holding before 2009"
  label var avoid_holding_currentfound "establishes majority own holding current year"
  compress
  sort ID
save $temp\hold`yr', replace
} 

*make dummy for ever being holding company 
use $temp\hold04, clear
  foreach yr in  05 06 07 08  {
  append using $temp\hold`yr' 
  }
  drop avoid_holding_currentfound
  rename avoid_holding_currentown avoid_holding
  replace avoid_holding=0 if avoid_holding==.
  replace avoid_holding_establ_05=0 if avoid_holding_establ_05==.
  replace avoid_holding_establ_pre09=0 if avoid_holding_establ_pre09==.
  collapse (max) avoid* , by(ID)
  sort ID
  label var avoid_holding "majority owner holding company at some point 04-08"
  label var avoid_holding_establ_05 "establishes majority own holding 2005"
  label var avoid_holding_establ_pre09 "establishes majority own holding before 2009"
  compress
save $temp\hold, replace
  
foreach yr in  04 05 06 07 08  {
use $temp\hold`yr', clear
  keep ID avoid_holding_currentfound avoid_holding_currentown
  sort ID
  merge 1:1 ID using $temp\holding2_`yr'
  tab _m
  keep ID avoid_holding_currentfound avoid_holding_currentown avoid_holding2_currentfound avoid_holding2_currentown
  replace avoid_holding_currentfound=0 if avoid_holding_currentfound==.
  replace avoid_holding_currentown=0 if avoid_holding_currentown==.
  replace avoid_holding2_currentfound=0 if avoid_holding2_currentfound==.
  replace avoid_holding2_currentown=0 if avoid_holding2_currentown==.
  gen year=20`yr'
  sort ID
save $data\annualholding_`yr', replace
}
  
*the variable holding does only exist to 2008
foreach yr in   09 10 11 12  { 
use $temp\holding2_`yr'
  keep ID avoid_holding2_currentfound avoid_holding2_currentown
  gen avoid_holding_currentfound=.
  gen avoid_holding_currentown=.
  label var avoid_holding_currentown "majority owner holding current year"
  label var avoid_holding_currentfound "establishes majority own holding current year"
  gen year=20`yr'
  sort ID
save $data\annualholding_`yr', replace
}
  
* make empty data sets for 2001-2003 and 2013, for consistency. These years we do not have ownership data for.
foreach yr in 01 02 03 13  { 
  clear
  foreach var in ID avoid_holding_currentfound avoid_holding_currentown avoid_holding2_currentown avoid_holding2_currentfound  {
   gen  `var'=. 
   }
   label var avoid_holding_currentown "majority owner holding current year"
   label var avoid_holding_currentfound "establishes majority own holding current year"
   label var avoid_holding2_currentown "majority owner holding2 current year"
   label var avoid_holding2_currentfound "establishes majority own holding2 current year"
   gen year=20`yr'
   sort ID
save $data\annualholding_`yr', replace
}
  
* display number of individuals each year who are majority owners of holdings
use $data\annualholding_04, clear
  foreach yr in 05 06 07 08 09 10 11 12  { 
  append using $data\annualholding_`yr'
  }
  foreach var in avoid_holding_currentfound avoid_holding_currentown avoid_holding2_currentfound avoid_holding2_currentown  { 
  tab year `var' , m
  }  

   
* dividend maximizer dummy for 2005, and add rest of variables
use $data\total_ownshares05_ind.dta, clear
  keep if ownshare>=0.5 & ownshare<.
  keep ID as_orgnr
  sort as_orgnr
  merge n:1 as_orgnr using $temp\avoid.dta 
  drop if _m==2
  drop _m
  rename avoid_divmax05_prof avoid_divmax05_prof_infirm
  replace avoid_divmax05_prof_infirm=0 if avoid_divmax05_prof_infirm==.
  collapse (max) avoid* , by(ID)
  label var avoid_divmax05_prof_infirm "majority owner of dividend maximise firm in 2005"
  sort ID 
*add on holding company dummies
   merge 1:1 ID  using $temp\hold
   drop _m
   sort ID  
   merge 1:1 ID using $temp\hold2
   drop _m

   foreach var in avoid_holding avoid_holding_establ_05 avoid_holding_establ_pre09 avoid_holding2 avoid_holding2_establ_05 avoid_holding2_establ_pre09 avoid_holding2_establ_post09 avoid_divmax05_prof_infirm { 
     replace `var'=0 if  `var'==.
   }
   sum
   d
   compress 
   sort ID
save $data\indlevelfirminfo_avoid.dta, replace
   
***************
   
clear
log close
