
/*****************************************************************
16 August 2017

This do-file produces standard errors on Figure 5A: 
the share of offshore wealth belonging to each wealth bin

******************************************************************/


/*** define paths ***/
*global datapath "C:\Users\okonj\Dropbox\Project Nordic Offshore Evasion\PaperInequality"
*global outputpath "C:\Users\okonj\Dropbox\Project Nordic Offshore Evasion\PaperInequality\WorkScandinavia\BootstrapStandardErrors"

*GZ:
global datapath "/Users/gzucman/Dropbox/AlstadsaeterEtal2015/PaperInequality"
global outputpath "/Users/gzucman/Dropbox/AlstadsaeterEtal2015/PaperInequality/WorkScandinavia/BootstrapStandardErrors"


/*** define parameters ***/
global sek = 7.378 
global dkk = 5.947 
global nok06 = 6.413 
global nok07 = 5.862


***********************************************************************************************************************
***********************************************************************************************************************
/************1. Produce synthethic micro dataset of HSBC account holders and amnesty participants ********************/
***********************************************************************************************************************
***********************************************************************************************************************

*********** 1A. Import raw datasets ***********

/*** Import Norwegian HSBC data ***/
import excel using "$datapath/WorkNorway/HSBCListNorway/hsbc_skatt.xlsx", sh(ToStata) first clear
drop nb_hsbc nb_hsbc_pos amt_hsbc // GZ: use 2007 distribution for Scandinavia (Paul Gunnar says he made a mistake in 2006 distrib, this makes barely any diff)
rename nb_hsbc_07 		nb_hsbc
rename nb_hsbc_pos_07 	nb_hsbc_pos
rename amt_hsbc_07 		amt_hsbc
rename se_amt_hsbc_07	se_amt_hsbc
gen country = "Norway"
save "$outputpath/hsbc_norway.dta", replace

/*** Import Swedish HSBC data ***/
import excel using "$datapath/WorkSweden/HSBCSweden/hsbc_scb.xlsx", sh(ToStata) first clear
gen country = "Sweden"
save "$outputpath/hsbc_sweden.dta", replace

/*** Import Danish HSBC data ***/
import excel using "$datapath/WorkDenmark/HSBC/hsbc_soren.xlsx", sh(ToStata) first clear
gen country = "Denmark"
save "$outputpath/hsbc_denmark.dta", replace

/*** Import Norwegian discloser data ***/
use "$datapath/WorkNorway/SmallFiles/small06hhold.dta", clear
*use "$datapath/WorkNorway/SmallFiles/small06hhold.dta", clear
replace ptile_w = round(1000 * ptile_w)
replace vd_evader = round(vd_evader * weight)
replace vd_case_dropped = round(vd_evader * vd_case_dropped)
gen nb_disc = vd_evader - vd_case_dropped
rename disclosed_wealth07C disclosed_wealth
rename disclosed_wealth07C_SD se_disclosed_wealth
gen country = "Norway_discl"
keep country ptile_w nb_disc disclosed_wealth se_disclosed_wealth
*adapt for merging with hsbc data*
rename nb_disc nb_hsbc
replace nb_hsbc=0 if nb_hsbc==.
gen nb_hsbc_pos = nb_hsbc
rename disclosed_wealth amt_hsbc
rename se_disclosed_wealth se_amt_hsbc
save "$outputpath/disclosers_norway.dta", replace

/*** Combine 4 datasets ***/
append using "$outputpath/hsbc_norway.dta" "$outputpath/hsbc_sweden.dta" "$outputpath/hsbc_denmark.dta"
replace amt_hsbc = 0 if amt_hsbc==.
replace se_amt_hsbc = 0 if se_amt_hsbc==.

/*** Translate to USD ***/
gen excrate = .
replace excrate = $nok06 if country=="Norway" 
replace excrate = $nok07 if country=="Norway_discl"
replace excrate = $dkk if country=="Denmark"
replace excrate = $sek if country=="Sweden"
replace amt_hsbc = amt_hsbc / excrate
replace se_amt_hsbc = se_amt_hsbc / excrate

/*** Expand dataset to full size ***/
drop if nb_hsbc==0
expand nb_hsbc
by country ptile_w, sort: gen obsno = _n
sort country ptile_w
gen zeroaccount = (obsno<=nb_hsbc-nb_hsbc_pos)

/*** Save true sample sizes in globals ***/
sum ptile_w, d
global samplesize = r(N)
sum ptile_w if country == "Norway_discl", d
global samplesize_disc = r(N)
sum ptile_w if country ~= "Norway_discl", d
global samplesize_hsbc = r(N)

/*** Define wealth groups ***/
*for figure 5A*
gen wealthgroup=.
replace wealthgroup=1 if ptile_w>=0 & ptile_w<50000
replace wealthgroup=2 if ptile_w>=50000 & ptile_w<90000
replace wealthgroup=3 if ptile_w>=90000 & ptile_w<99000
replace wealthgroup=4 if ptile_w>=99000 & ptile_w<99900
replace wealthgroup=5 if ptile_w>=99900 & ptile_w<99990
replace wealthgroup=6 if ptile_w>=99990 & ptile_w~=.
*for figure 5B*
gen wealthgroupB = .
replace wealthgroupB = 1 if ptile_w>=0 & ptile_w<10000
replace wealthgroupB = 2 if ptile_w>=10000 & ptile_w<20000
replace wealthgroupB = 3 if ptile_w>=20000 & ptile_w<30000
replace wealthgroupB = 4 if ptile_w>=30000 & ptile_w<40000
replace wealthgroupB = 5 if ptile_w>=40000 & ptile_w<50000
replace wealthgroupB = 6 if ptile_w>=50000 & ptile_w<60000
replace wealthgroupB = 7 if ptile_w>=60000 & ptile_w<70000
replace wealthgroupB = 8 if ptile_w>=70000 & ptile_w<80000
replace wealthgroupB = 9 if ptile_w>=80000 & ptile_w<90000
replace wealthgroupB = 10 if ptile_w>=90000 & ptile_w<95000
replace wealthgroupB = 11 if ptile_w>=95000 & ptile_w<99000
replace wealthgroupB = 12 if ptile_w>=99000 & ptile_w<99500
replace wealthgroupB = 13 if ptile_w>=99500 & ptile_w<99900
replace wealthgroupB = 14 if ptile_w>=99900 & ptile_w<99950
replace wealthgroupB = 15 if ptile_w>=99950 & ptile_w<99990
replace wealthgroupB = 16 if ptile_w>=99990 & ptile_w<100000



*********** 1B. Add parameters of tax system and income distribution ***********
/*** define shares of taxable income (source: Appendix J, sheet "T.AX3", column B) ***/
gen taxincshare = .
replace taxincshare = 0.07462 if wealthgroupB==1
replace taxincshare = 0.03684 if wealthgroupB==2
replace taxincshare = 0.05716 if wealthgroupB==3
replace taxincshare = 0.07762 if wealthgroupB==4
replace taxincshare = 0.08394 if wealthgroupB==5
replace taxincshare = 0.08998 if wealthgroupB==6
replace taxincshare = 0.10742 if wealthgroupB==7
replace taxincshare = 0.11964 if wealthgroupB==8
replace taxincshare = 0.13927 if wealthgroupB==9
replace taxincshare = 0.07603 if wealthgroupB==10
replace taxincshare = 0.08413 if wealthgroupB==11
replace taxincshare = 0.01652 if wealthgroupB==12
replace taxincshare = 0.01869 if wealthgroupB==13
replace taxincshare = 0.00542 if wealthgroupB==14
replace taxincshare = 0.00599 if wealthgroupB==15
replace taxincshare = 0.00673 if wealthgroupB==16

/*** define marginal tax rate (source: Appendix J, sheet "T.J7b", column C) ***/
gen margtaxrate = .
replace margtaxrate = 0.31022 if wealthgroupB==1
replace margtaxrate = 0.29547 if wealthgroupB==2
replace margtaxrate = 0.30832 if wealthgroupB==3
replace margtaxrate = 0.31281 if wealthgroupB==4
replace margtaxrate = 0.32569 if wealthgroupB==5
replace margtaxrate = 0.32912 if wealthgroupB==6
replace margtaxrate = 0.34242 if wealthgroupB==7
replace margtaxrate = 0.36168 if wealthgroupB==8
replace margtaxrate = 0.39876 if wealthgroupB==9
replace margtaxrate = 0.44518 if wealthgroupB==10
replace margtaxrate = 0.48849 if wealthgroupB==11
replace margtaxrate = 0.51138 if wealthgroupB==12
replace margtaxrate = 0.51221 if wealthgroupB==13
replace margtaxrate = 0.51625 if wealthgroupB==14
replace margtaxrate = 0.51538 if wealthgroupB==15
replace margtaxrate = 0.52178 if wealthgroupB==16

/*** define average tax rate (source: Appendix J, sheet "T.J7", column B) ***/
gen avgtaxrate = .
replace avgtaxrate = 0.27908 if wealthgroupB==1
replace avgtaxrate = 0.27109 if wealthgroupB==2
replace avgtaxrate = 0.29143 if wealthgroupB==3
replace avgtaxrate = 0.30711 if wealthgroupB==4
replace avgtaxrate = 0.31076 if wealthgroupB==5
replace avgtaxrate = 0.30760 if wealthgroupB==6
replace avgtaxrate = 0.30834 if wealthgroupB==7
replace avgtaxrate = 0.31022 if wealthgroupB==8
replace avgtaxrate = 0.31590 if wealthgroupB==9
replace avgtaxrate = 0.32953 if wealthgroupB==10
replace avgtaxrate = 0.35287 if wealthgroupB==11
replace avgtaxrate = 0.42202 if wealthgroupB==12
replace avgtaxrate = 0.42961 if wealthgroupB==13
replace avgtaxrate = 0.45575 if wealthgroupB==14
replace avgtaxrate = 0.45575 if wealthgroupB==15
replace avgtaxrate = 0.45575 if wealthgroupB==16

/*** define the share of hidden income in total income (source: Appendix J; sheet "T.J2", "T.J2c" and "T.J2d"; cell B23)***/
gen agghiddenincshare_mainscen = 0.0036902
gen agghiddenincshare_highscen = 0.0073492
gen agghiddenincshare_lowscen = 0.0013331

/***save dataset ***/
save "$outputpath/sample_scandinavia.dta", replace



******* 1C. Produce dataset with weights on HSBC and Discloser samples equal to their actual sample size ******
/*** Further expand dataset by factor 100 to have less noise in the simulated distributions ***/
use "$outputpath/sample_scandinavia.dta", clear
expand 100

/*** Impute hidden wealth according to parameters in tabulations ***/
*set parameters and initiate variables*
gen control = (zeroaccount==0)
gen iterations = -1
gen s = 0
gen imputed = 0 if zeroaccount==1
replace imputed = amt_hsbc if zeroaccount==0
local seed = 1
local control = 5
*impute hidden wealth*
while `control' > 0 {
set seed `seed'
replace s = runiform()
replace imputed = ///
			 	exp( ///
			 	ln(amt_hsbc / sqrt(1 + se_amt_hsbc^2 / amt_hsbc^2)) ///
			 	+ sqrt(ln(1 + se_amt_hsbc^2 / amt_hsbc^2)) * invnorm(s)) ///
				if control>0.05 & zeroaccount==0
replace iterations = iterations + 1 if control>0.05 & control~=. & zeroaccount==0
sum iterations, d
if r(max)==0 {
gen imputed_nocorr = imputed
}
*check that average of imputed hidden wealth is within 5% of true average*
by country ptile_w, sort: egen temp1 = mean(amt_hsbc) if zeroaccount==0
by country ptile_w, sort: egen temp2 = mean(imputed) if zeroaccount==0
replace control = abs((temp2 - temp1) / temp1) if zeroaccount==0
sum control if control>=0.05
local control = r(N)
local seed = `seed' + 1	
drop temp1 temp2
}

/*** Save dataset without scaling up HSBC sample ***/
gen id = _n
sort id
save "$outputpath/sample_scandinavia_full_noreweighting.dta", replace



**************** 1D. Produce dataset with equal weights on HSBC and Discloser sample **************** 
/*** Construct dataset that scales up HSBC sample to give same weight as on Disclosers***/
use "$outputpath/sample_scandinavia.dta", clear

/*** Expand dataset to get same weight on HSBC and Discloser samples (and to have less noise in the simulated distributions) ***/
gen weight = .
replace weight = round($samplesize_hsbc/10) if country == "Norway_discl"
replace weight = round($samplesize_disc/10) if country ~= "Norway_discl"
expand weight

/*** Impute hidden wealth according to parameters in tabulations ***/
*set parameters and initiate variables*
gen control = (zeroaccount==0)
gen iterations = -1
gen s = 0
gen imputed = 0 if zeroaccount==1
replace imputed = amt_hsbc if zeroaccount==0
local seed = 1
local control = 5
*impute hidden wealth*
while `control' > 0 {
set seed `seed'
replace s = runiform()
replace imputed = ///
			 	exp( ///
			 	ln(amt_hsbc / sqrt(1 + se_amt_hsbc^2 / amt_hsbc^2)) ///
			 	+ sqrt(ln(1 + se_amt_hsbc^2 / amt_hsbc^2)) * invnorm(s)) ///
				if control>0.05 & zeroaccount==0
replace iterations = iterations + 1 if control>0.05 & control~=. & zeroaccount==0
sum iterations, d
if r(max)==0 {
gen imputed_nocorr = imputed
}
*check that average of imputed hidden wealth is within 5% of true average*
by country ptile_w, sort: egen temp1 = mean(amt_hsbc) if zeroaccount==0
by country ptile_w, sort: egen temp2 = mean(imputed) if zeroaccount==0
replace control = abs((temp2 - temp1) / temp1) if zeroaccount==0
sum control if control>=0.05
local control = r(N)
local seed = `seed' + 1	
drop temp1 temp2
}

/*** Save dataset where HSBC sample is scaled up to have same weight as on the Discloser sample***/
gen id = _n
sort id
save "$outputpath/sample_scandinavia_full_reweighting.dta", replace






***********************************************************************************************************
***********************************************************************************************************
/*************************** 2. Bootstrap standard errors on Figure 5A ***********************************/
***********************************************************************************************************
***********************************************************************************************************

*********** 2A. Define program that computes wealth shares **************
cap program drop HSBCwealthshares
program HSBCwealthshares, rclass
args y
cap drop groupwealth totalwealth wealthshare
sort wealthgroup id
by wealthgroup: egen groupwealth=sum(`y')
egen totalwealth=sum(`y')
gen wealthshare = groupwealth / totalwealth
summarize wealthshare if wealthgroup==1, meanonly
return scalar N1 = r(mean)
summarize wealthshare if wealthgroup==2, meanonly
return scalar N2 = r(mean)
summarize wealthshare if wealthgroup==3, meanonly
return scalar N3 = r(mean)
summarize wealthshare if wealthgroup==4, meanonly
return scalar N4 = r(mean)
summarize wealthshare if wealthgroup==5, meanonly
return scalar N5 = r(mean)
summarize wealthshare if wealthgroup==6, meanonly
return scalar N6 = r(mean)
end


*********** 2B. Standard errors with weights on HSBC and Discloser samples equal to their actual sample size **************** 
use "$outputpath/sample_scandinavia_full_noreweighting.dta", clear

/*** Run program on full sample***/
gen truehsbc = amt_hsbc 
replace truehsbc = 0 if zeroaccount==1
HSBCwealthshares truehsbc
disp r(N1) r(N2) r(N3) r(N4) r(N5) r(N6)
*save coefficients*
gen wealthshare_true = .
forvalues x=1/6 {
replace wealthshare_true = r(N`x') if wealthgroup==`x'
}

/*** Use program to bootstrap disclosure rates and standard errors ***/
gen wealthshare_bs = .
gen wealthshare_se = .
gen wealthshare_upper = .
gen wealthshare_lower = .
bootstrap r(N1) r(N2) r(N3) r(N4) r(N5) r(N6), seed(1) reps(100) size($samplesize) nowarn nodots: HSBCwealthshares imputed
matrix confintervals = e(ci_normal)
forvalues x=1/6 {
replace wealthshare_bs = _b[_bs_`x'] if wealthgroup==`x'
replace wealthshare_se = _se[_bs_`x'] if wealthgroup==`x'
replace wealthshare_upper = confintervals[2,`x'] if wealthgroup==`x'
replace wealthshare_lower = confintervals[1,`x'] if wealthgroup==`x'
}

/*** Clean up and save ***/
cap drop obsno
by wealthgroup, sort: gen obsno = _n
keep if obsno==1
keep wealthgroup wealthshare_true wealthshare_bs wealthshare_se wealthshare_upper wealthshare_lower
save "$outputpath/Fig5A_results_noreweighting.dta", replace


/*** Make figure 5A with standard errors ***/
label define categories 1 "P0-50" 2 "P50-90" 3 "P90-99" 4 "P99-99.9" 5 "P99.9-99.99" 6 "P99.99-100"
label values wealthgroup categories
twoway (connect wealthshare_bs wealthgroup) (rcap wealthshare_upper wealthshare_lower wealthgroup) ///
if wealthgroup>=1 & wealthgroup<=6, xscale(range(1 6)) xlabel(1/6) ///
scheme(s1mono) xlabel(1 2 3 4 5 6, valuelabel labsize(small) angle(90)) legend(off) xtitle("") ///
title("Share of hidden wealth by wealth group" "(bootstrapped standard errors)")  note("hsbc and discloser samples are not reweighted to have same weight")
graph export "$outputpath/Fig5A_graph_noreweighting.pdf", as(pdf) replace



*********** 2C. Standard errors with equal weights on HSBC and Discloser sample **************** 
use "$outputpath/sample_scandinavia_full_reweighting.dta", clear

/*** Run program on full sample***/
gen truehsbc = amt_hsbc 
replace truehsbc = 0 if zeroaccount==1
HSBCwealthshares truehsbc
disp r(N1) r(N2) r(N3) r(N4) r(N5) r(N6)
*save coefficients*
gen wealthshare_true = .
forvalues x=1/6 {
replace wealthshare_true = r(N`x') if wealthgroup==`x'
}

/*** Use program to bootstrap disclosure rates and standard errors ***/
gen wealthshare_bs = .
gen wealthshare_se = .
gen wealthshare_upper = .
gen wealthshare_lower = .
bootstrap r(N1) r(N2) r(N3) r(N4) r(N5) r(N6), seed(1) reps(100) size($samplesize) nowarn nodots: HSBCwealthshares imputed
matrix confintervals = e(ci_normal)
forvalues x=1/6 {
replace wealthshare_bs = _b[_bs_`x'] if wealthgroup==`x'
replace wealthshare_se = _se[_bs_`x'] if wealthgroup==`x'
replace wealthshare_upper = confintervals[2,`x'] if wealthgroup==`x'
replace wealthshare_lower = confintervals[1,`x'] if wealthgroup==`x'
}

/*** Clean up and save ***/
cap drop obsno
by wealthgroup, sort: gen obsno = _n
keep if obsno==1
keep wealthgroup wealthshare_true wealthshare_bs wealthshare_se wealthshare_upper wealthshare_lower
save "$outputpath/Fig5A_results_reweighting.dta", replace


/*** Make figure 5A with standard errors ***/
label define categories 1 "P0-50" 2 "P50-90" 3 "P90-99" 4 "P99-99.9" 5 "P99.9-99.99" 6 "P99.99-100"
label values wealthgroup categories
twoway (connect wealthshare_bs wealthgroup) (rcap wealthshare_upper wealthshare_lower wealthgroup) ///
if wealthgroup>=1 & wealthgroup<=6, xscale(range(1 6)) xlabel(1/6) ///
scheme(s1mono) xlabel(1 2 3 4 5 6, valuelabel labsize(small) angle(90)) legend(off) xtitle("") ///
title("Share of hidden wealth by wealth group" "(bootstrapped standard errors)")  note("hsbc and discloser samples are reweighted to have same weight")
graph export "$outputpath/Fig5A_graph_reweighting.pdf", as(pdf) replace



*********** 2D. Standard errors for sample including only HSBC customers **************** 
use "$outputpath/sample_scandinavia_full_noreweighting.dta", clear
keep if country~="Norway_discl"

/*** Run program on full sample***/
gen truehsbc = amt_hsbc 
replace truehsbc = 0 if zeroaccount==1
HSBCwealthshares truehsbc
disp r(N1) r(N2) r(N3) r(N4) r(N5) r(N6)
*save coefficients*
gen wealthshare_true = .
forvalues x=1/6 {
replace wealthshare_true = r(N`x') if wealthgroup==`x'
}

/*** Use program to bootstrap disclosure rates and standard errors ***/
gen wealthshare_bs = .
gen wealthshare_se = .
gen wealthshare_upper = .
gen wealthshare_lower = .
bootstrap r(N1) r(N2) r(N3) r(N4) r(N5) r(N6), seed(1) reps(100) size($samplesize_hsbc) nowarn nodots: HSBCwealthshares imputed
matrix confintervals = e(ci_normal)
forvalues x=1/6 {
replace wealthshare_bs = _b[_bs_`x'] if wealthgroup==`x'
replace wealthshare_se = _se[_bs_`x'] if wealthgroup==`x'
replace wealthshare_upper = confintervals[2,`x'] if wealthgroup==`x'
replace wealthshare_lower = confintervals[1,`x'] if wealthgroup==`x'
}

/*** Clean up and save ***/
cap drop obsno
by wealthgroup, sort: gen obsno = _n
keep if obsno==1
keep wealthgroup wealthshare_true wealthshare_bs wealthshare_se wealthshare_upper wealthshare_lower
save "$outputpath/Fig5A_results_hsbconly.dta", replace


/*** Make figure 5A with standard errors ***/
label define categories 1 "P0-50" 2 "P50-90" 3 "P90-99" 4 "P99-99.9" 5 "P99.9-99.99" 6 "P99.99-100"
label values wealthgroup categories
twoway (connect wealthshare_bs wealthgroup) (rcap wealthshare_upper wealthshare_lower wealthgroup) ///
if wealthgroup>=1 & wealthgroup<=6, xscale(range(1 6)) xlabel(1/6) ///
scheme(s1mono) xlabel(1 2 3 4 5 6, valuelabel labsize(small) angle(90)) legend(off) xtitle("") ///
title("Share of hidden wealth by wealth group" "(bootstrapped standard errors)")  note("hsbc customers only")
graph export "$outputpath/Fig5A_graph_hsbconly.pdf", as(pdf) replace



*********** 2E. Standard errors for sample including only Disclossers **************** 
use "$outputpath/sample_scandinavia_full_noreweighting.dta", clear
keep if country=="Norway_discl"

/*** Run program on full sample***/
gen truehsbc = amt_hsbc 
replace truehsbc = 0 if zeroaccount==1
HSBCwealthshares truehsbc
disp r(N1) r(N2) r(N3) r(N4) r(N5) r(N6)
*save coefficients*
gen wealthshare_true = .
forvalues x=1/6 {
replace wealthshare_true = r(N`x') if wealthgroup==`x'
}

/*** Use program to bootstrap disclosure rates and standard errors ***/
gen wealthshare_bs = .
gen wealthshare_se = .
gen wealthshare_upper = .
gen wealthshare_lower = .
bootstrap r(N1) r(N2) r(N3) r(N4) r(N5) r(N6), seed(1) reps(100) size($samplesize_disc) nowarn nodots: HSBCwealthshares imputed
matrix confintervals = e(ci_normal)
forvalues x=1/6 {
replace wealthshare_bs = _b[_bs_`x'] if wealthgroup==`x'
replace wealthshare_se = _se[_bs_`x'] if wealthgroup==`x'
replace wealthshare_upper = confintervals[2,`x'] if wealthgroup==`x'
replace wealthshare_lower = confintervals[1,`x'] if wealthgroup==`x'
}

/*** Clean up and save ***/
cap drop obsno
by wealthgroup, sort: gen obsno = _n
keep if obsno==1
keep wealthgroup wealthshare_true wealthshare_bs wealthshare_se wealthshare_upper wealthshare_lower
save "$outputpath/Fig5A_results_disclosersonly.dta", replace


/*** Make figure 5A with standard errors ***/
label define categories 1 "P0-50" 2 "P50-90" 3 "P90-99" 4 "P99-99.9" 5 "P99.9-99.99" 6 "P99.99-100"
label values wealthgroup categories
twoway (connect wealthshare_bs wealthgroup) (rcap wealthshare_upper wealthshare_lower wealthgroup) ///
if wealthgroup>=1 & wealthgroup<=6, xscale(range(1 6)) xlabel(1/6) ///
scheme(s1mono) xlabel(1 2 3 4 5 6, valuelabel labsize(small) angle(90)) legend(off) xtitle("") ///
title("Share of hidden wealth by wealth group" "(bootstrapped standard errors)")  note("disclosers only")
graph export "$outputpath/Fig5A_graph_disclosersonly.pdf", as(pdf) replace



***********************************************************************************************************
***********************************************************************************************************
/*************************** 3. Bootstrap standard errors on Figure 5B ***********************************/
***********************************************************************************************************
***********************************************************************************************************



******************************    MAIN SCENARIO    ******************************    

*********** 3A. Define program that computes offshore evasion rates **************
cap program drop Evasionrates
program Evasionrates, rclass
args y
cap drop groupwealth totalwealth offincshare allincshare hiddeninc taxespaid taxesevaded evasionrate
sort wealthgroupB id
by wealthgroupB: egen groupwealth=sum(`y')
egen totalwealth=sum(`y')
gen offincshare = groupwealth / totalwealth /*sheet T.J2, column L*/
gen allincshare = offincshare*agghiddenincshare_mainscen + taxincshare*(1-agghiddenincshare_mainscen) /*sheet T.J2, column G*/
gen hiddeninc = offincshare*agghiddenincshare_mainscen / allincshare /*sheet T.J2, column B*/
gen taxespaid = avgtaxrate * (1-hiddeninc)
gen taxesevaded = margtaxrate * hiddeninc
gen evasionrate = taxesevaded / (taxesevaded + taxespaid)
forvalues x=1/16 {
summarize evasionrate if wealthgroupB==`x', meanonly
return scalar N`x' = r(mean)
}
end


*********** 3B. Standard errors with weights on HSBC and Discloser samples equal to their actual sample size **************** 
use "$outputpath/sample_scandinavia_full_noreweighting.dta", clear

/*** Run program on full sample***/
gen truehsbc = amt_hsbc 
replace truehsbc = 0 if zeroaccount==1
Evasionrates truehsbc
disp r(N11) r(N12) r(N13) r(N14) r(N15) r(N16) 
*save coefficients*
gen evasionrate_true = .
forvalues x=1/16 {
replace evasionrate_true = r(N`x') if wealthgroupB==`x'
}
*

/*** Use program to bootstrap disclosure rates and standard errors ***/
gen evasionrate_bs = .
gen evasionrate_se = .
gen evasionrate_upper = .
gen evasionrate_lower = .
bootstrap r(N1) r(N2) r(N3) r(N4) r(N5) r(N6) r(N7) r(N8) r(N9) r(N10) r(N11) r(N12) r(N13) r(N14) r(N15) r(N16), seed(1) reps(100) size($samplesize) nowarn nodots: Evasionrates imputed
matrix confintervals = e(ci_normal)
forvalues x=1/16 {
replace evasionrate_bs = _b[_bs_`x'] if wealthgroupB==`x'
replace evasionrate_se = _se[_bs_`x'] if wealthgroupB==`x'
replace evasionrate_upper = confintervals[2,`x'] if wealthgroupB==`x'
replace evasionrate_lower = confintervals[1,`x'] if wealthgroupB==`x'
}

/*** Clean up and save ***/
cap drop obsno
by wealthgroupB, sort: gen obsno = _n
keep if obsno==1
keep wealthgroupB evasionrate_true evasionrate_bs evasionrate_se evasionrate_upper evasionrate_lower
save "$outputpath/Fig5B_results_mainscen_noreweighting.dta", replace


/*** Make figure 5B with standard errors ***/
label define categories2 10 "P90-95" 11 "P95-99" 12 "P99-99.5" 13 "P99.5-99.9" 14 "P99.9-99.95" 15 "P99.95-99.99" 16 "P99.99-100"
label values wealthgroupB categories2
twoway (connect evasionrate_bs wealthgroupB) (rcap evasionrate_upper evasionrate_lower wealthgroupB) ///
if wealthgroupB>=10 & wealthgroupB<=16, xscale(range(10 16)) xlabel(10/16) ///
scheme(s1mono) xlabel(10 11 12 13 14 15 16, valuelabel labsize(small) angle(90)) legend(off) xtitle("") ///
title("Offshore evasion rates by wealth group" "(bootstrapped standard errors)")  note("hsbc and discloser samples are not reweighted to have same weight") subtitle("main scenario")
graph export "$outputpath/Fig5B_graph_mainscen_noreweighting.pdf", as(pdf) replace


*********** 3C. Standard errors with equal weights on HSBC and Discloser sample **************** 
use "$outputpath/sample_scandinavia_full_reweighting.dta", clear

/*** Run program on full sample***/
gen truehsbc = amt_hsbc 
replace truehsbc = 0 if zeroaccount==1
Evasionrates truehsbc
disp r(N11) r(N12) r(N13) r(N14) r(N15) r(N16) 
*save coefficients*
gen evasionrate_true = .
forvalues x=1/16 {
replace evasionrate_true = r(N`x') if wealthgroupB==`x'
}
*

/*** Use program to bootstrap disclosure rates and standard errors ***/
gen evasionrate_bs = .
gen evasionrate_se = .
gen evasionrate_upper = .
gen evasionrate_lower = .
bootstrap r(N1) r(N2) r(N3) r(N4) r(N5) r(N6) r(N7) r(N8) r(N9) r(N10) r(N11) r(N12) r(N13) r(N14) r(N15) r(N16), seed(1) reps(100) size($samplesize) nowarn nodots: Evasionrates imputed
matrix confintervals = e(ci_normal)
forvalues x=1/16 {
replace evasionrate_bs = _b[_bs_`x'] if wealthgroupB==`x'
replace evasionrate_se = _se[_bs_`x'] if wealthgroupB==`x'
replace evasionrate_upper = confintervals[2,`x'] if wealthgroupB==`x'
replace evasionrate_lower = confintervals[1,`x'] if wealthgroupB==`x'
}

/*** Clean up and save ***/
cap drop obsno
by wealthgroupB, sort: gen obsno = _n
keep if obsno==1
keep wealthgroupB evasionrate_true evasionrate_bs evasionrate_se evasionrate_upper evasionrate_lower
save "$outputpath/Fig5B_results_mainscen_reweighting.dta", replace


/*** Make figure 5B with standard errors ***/
label define categories2 10 "P90-95" 11 "P95-99" 12 "P99-99.5" 13 "P99.5-99.9" 14 "P99.9-99.95" 15 "P99.95-99.99" 16 "P99.99-100"
label values wealthgroupB categories2
twoway (connect evasionrate_bs wealthgroupB) (rcap evasionrate_upper evasionrate_lower wealthgroupB) ///
if wealthgroupB>=10 & wealthgroupB<=16, xscale(range(10 16)) xlabel(10/16) ///
scheme(s1mono) xlabel(10 11 12 13 14 15 16, valuelabel labsize(small) angle(90)) legend(off) xtitle("") ///
title("Offshore evasion rates by wealth group" "(bootstrapped standard errors)")  note("hsbc and discloser samples are reweighted to have same weight") subtitle("main scenario")
graph export "$outputpath/Fig5B_graph_mainscen_reweighting.pdf", as(pdf) replace








******************************    HIGH SCENARIO    ******************************    

*********** 3A. Define program that computes offshore evasion rates **************
cap program drop Evasionrates
program Evasionrates, rclass
args y
cap drop groupwealth totalwealth offincshare allincshare hiddeninc taxespaid taxesevaded evasionrate
sort wealthgroupB id
by wealthgroupB: egen groupwealth=sum(`y')
egen totalwealth=sum(`y')
gen offincshare = groupwealth / totalwealth /*sheet T.J2, column L*/
gen allincshare = offincshare*agghiddenincshare_highscen + taxincshare*(1-agghiddenincshare_highscen) /*sheet T.J2, column G*/
gen hiddeninc = offincshare*agghiddenincshare_highscen / allincshare /*sheet T.J2, column B*/
gen taxespaid = avgtaxrate * (1-hiddeninc)
gen taxesevaded = margtaxrate * hiddeninc
gen evasionrate = taxesevaded / (taxesevaded + taxespaid)
forvalues x=1/16 {
summarize evasionrate if wealthgroupB==`x', meanonly
return scalar N`x' = r(mean)
}
end


*********** 3B. Standard errors with weights on HSBC and Discloser samples equal to their actual sample size **************** 
use "$outputpath/sample_scandinavia_full_noreweighting.dta", clear

/*** Run program on full sample***/
gen truehsbc = amt_hsbc 
replace truehsbc = 0 if zeroaccount==1
Evasionrates truehsbc
disp r(N11) r(N12) r(N13) r(N14) r(N15) r(N16) 
*save coefficients*
gen evasionrate_true = .
forvalues x=1/16 {
replace evasionrate_true = r(N`x') if wealthgroupB==`x'
}
*

/*** Use program to bootstrap disclosure rates and standard errors ***/
gen evasionrate_bs = .
gen evasionrate_se = .
gen evasionrate_upper = .
gen evasionrate_lower = .
bootstrap r(N1) r(N2) r(N3) r(N4) r(N5) r(N6) r(N7) r(N8) r(N9) r(N10) r(N11) r(N12) r(N13) r(N14) r(N15) r(N16), seed(1) reps(100) size($samplesize) nowarn nodots: Evasionrates imputed
matrix confintervals = e(ci_normal)
forvalues x=1/16 {
replace evasionrate_bs = _b[_bs_`x'] if wealthgroupB==`x'
replace evasionrate_se = _se[_bs_`x'] if wealthgroupB==`x'
replace evasionrate_upper = confintervals[2,`x'] if wealthgroupB==`x'
replace evasionrate_lower = confintervals[1,`x'] if wealthgroupB==`x'
}

/*** Clean up and save ***/
cap drop obsno
by wealthgroupB, sort: gen obsno = _n
keep if obsno==1
keep wealthgroupB evasionrate_true evasionrate_bs evasionrate_se evasionrate_upper evasionrate_lower
save "$outputpath/Fig5B_results_highscen_noreweighting.dta", replace


/*** Make figure 5B with standard errors ***/
label define categories2 10 "P90-95" 11 "P95-99" 12 "P99-99.5" 13 "P99.5-99.9" 14 "P99.9-99.95" 15 "P99.95-99.99" 16 "P99.99-100"
label values wealthgroupB categories2
twoway (connect evasionrate_bs wealthgroupB) (rcap evasionrate_upper evasionrate_lower wealthgroupB) ///
if wealthgroupB>=10 & wealthgroupB<=16, xscale(range(10 16)) xlabel(10/16) ///
scheme(s1mono) xlabel(10 11 12 13 14 15 16, valuelabel labsize(small) angle(90)) legend(off) xtitle("") ///
title("Offshore evasion rates by wealth group" "(bootstrapped standard errors)")  note("hsbc and discloser samples are not reweighted to have same weight") subtitle("high scenario")
graph export "$outputpath/Fig5B_graph_highscen_noreweighting.pdf", as(pdf) replace


*********** 3C. Standard errors with equal weights on HSBC and Discloser sample **************** 
use "$outputpath/sample_scandinavia_full_reweighting.dta", clear

/*** Run program on full sample***/
gen truehsbc = amt_hsbc 
replace truehsbc = 0 if zeroaccount==1
Evasionrates truehsbc
disp r(N11) r(N12) r(N13) r(N14) r(N15) r(N16) 
*save coefficients*
gen evasionrate_true = .
forvalues x=1/16 {
replace evasionrate_true = r(N`x') if wealthgroupB==`x'
}
*

/*** Use program to bootstrap disclosure rates and standard errors ***/
gen evasionrate_bs = .
gen evasionrate_se = .
gen evasionrate_upper = .
gen evasionrate_lower = .
bootstrap r(N1) r(N2) r(N3) r(N4) r(N5) r(N6) r(N7) r(N8) r(N9) r(N10) r(N11) r(N12) r(N13) r(N14) r(N15) r(N16), seed(1) reps(100) size($samplesize) nowarn nodots: Evasionrates imputed
matrix confintervals = e(ci_normal)
forvalues x=1/16 {
replace evasionrate_bs = _b[_bs_`x'] if wealthgroupB==`x'
replace evasionrate_se = _se[_bs_`x'] if wealthgroupB==`x'
replace evasionrate_upper = confintervals[2,`x'] if wealthgroupB==`x'
replace evasionrate_lower = confintervals[1,`x'] if wealthgroupB==`x'
}

/*** Clean up and save ***/
cap drop obsno
by wealthgroupB, sort: gen obsno = _n
keep if obsno==1
keep wealthgroupB evasionrate_true evasionrate_bs evasionrate_se evasionrate_upper evasionrate_lower
save "$outputpath/Fig5B_results_highscen_reweighting.dta", replace


/*** Make figure 5B with standard errors ***/
label define categories2 10 "P90-95" 11 "P95-99" 12 "P99-99.5" 13 "P99.5-99.9" 14 "P99.9-99.95" 15 "P99.95-99.99" 16 "P99.99-100"
label values wealthgroupB categories2
twoway (connect evasionrate_bs wealthgroupB) (rcap evasionrate_upper evasionrate_lower wealthgroupB) ///
if wealthgroupB>=10 & wealthgroupB<=16, xscale(range(10 16)) xlabel(10/16) ///
scheme(s1mono) xlabel(10 11 12 13 14 15 16, valuelabel labsize(small) angle(90)) legend(off) xtitle("") ///
title("Offshore evasion rates by wealth group" "(bootstrapped standard errors)")  note("hsbc and discloser samples are reweighted to have same weight") subtitle("high scenario")
graph export "$outputpath/Fig5B_graph_highscen_reweighting.pdf", as(pdf) replace







******************************    LOW SCENARIO    ******************************    

*********** 3A. Define program that computes offshore evasion rates **************
cap program drop Evasionrates
program Evasionrates, rclass
args y
cap drop groupwealth totalwealth offincshare allincshare hiddeninc taxespaid taxesevaded evasionrate
sort wealthgroupB id
by wealthgroupB: egen groupwealth=sum(`y')
egen totalwealth=sum(`y')
gen offincshare = groupwealth / totalwealth /*sheet T.J2, column L*/
gen allincshare = offincshare*agghiddenincshare_lowscen + taxincshare*(1-agghiddenincshare_lowscen) /*sheet T.J2, column G*/
gen hiddeninc = offincshare*agghiddenincshare_lowscen / allincshare /*sheet T.J2, column B*/
gen taxespaid = avgtaxrate * (1-hiddeninc)
gen taxesevaded = margtaxrate * hiddeninc
gen evasionrate = taxesevaded / (taxesevaded + taxespaid)
forvalues x=1/16 {
summarize evasionrate if wealthgroupB==`x', meanonly
return scalar N`x' = r(mean)
}
end


*********** 3B. Standard errors with weights on HSBC and Discloser samples equal to their actual sample size **************** 
use "$outputpath/sample_scandinavia_full_noreweighting.dta", clear

/*** Run program on full sample***/
gen truehsbc = amt_hsbc 
replace truehsbc = 0 if zeroaccount==1
Evasionrates truehsbc
disp r(N11) r(N12) r(N13) r(N14) r(N15) r(N16) 
*save coefficients*
gen evasionrate_true = .
forvalues x=1/16 {
replace evasionrate_true = r(N`x') if wealthgroupB==`x'
}
*

/*** Use program to bootstrap disclosure rates and standard errors ***/
gen evasionrate_bs = .
gen evasionrate_se = .
gen evasionrate_upper = .
gen evasionrate_lower = .
bootstrap r(N1) r(N2) r(N3) r(N4) r(N5) r(N6) r(N7) r(N8) r(N9) r(N10) r(N11) r(N12) r(N13) r(N14) r(N15) r(N16), seed(1) reps(100) size($samplesize) nowarn nodots: Evasionrates imputed
matrix confintervals = e(ci_normal)
forvalues x=1/16 {
replace evasionrate_bs = _b[_bs_`x'] if wealthgroupB==`x'
replace evasionrate_se = _se[_bs_`x'] if wealthgroupB==`x'
replace evasionrate_upper = confintervals[2,`x'] if wealthgroupB==`x'
replace evasionrate_lower = confintervals[1,`x'] if wealthgroupB==`x'
}

/*** Clean up and save ***/
cap drop obsno
by wealthgroupB, sort: gen obsno = _n
keep if obsno==1
keep wealthgroupB evasionrate_true evasionrate_bs evasionrate_se evasionrate_upper evasionrate_lower
save "$outputpath/Fig5B_results_lowscen_noreweighting.dta", replace


/*** Make figure 5B with standard errors ***/
label define categories2 10 "P90-95" 11 "P95-99" 12 "P99-99.5" 13 "P99.5-99.9" 14 "P99.9-99.95" 15 "P99.95-99.99" 16 "P99.99-100"
label values wealthgroupB categories2
twoway (connect evasionrate_bs wealthgroupB) (rcap evasionrate_upper evasionrate_lower wealthgroupB) ///
if wealthgroupB>=10 & wealthgroupB<=16, xscale(range(10 16)) xlabel(10/16) ///
scheme(s1mono) xlabel(10 11 12 13 14 15 16, valuelabel labsize(small) angle(90)) legend(off) xtitle("") ///
title("Offshore evasion rates by wealth group" "(bootstrapped standard errors)")  note("hsbc and discloser samples are not reweighted to have same weight") subtitle("low scenario")
graph export "$outputpath/Fig5B_graph_lowscen_noreweighting.pdf", as(pdf) replace


*********** 3C. Standard errors with equal weights on HSBC and Discloser sample **************** 
use "$outputpath/sample_scandinavia_full_reweighting.dta", clear

/*** Run program on full sample***/
gen truehsbc = amt_hsbc 
replace truehsbc = 0 if zeroaccount==1
Evasionrates truehsbc
disp r(N11) r(N12) r(N13) r(N14) r(N15) r(N16) 
*save coefficients*
gen evasionrate_true = .
forvalues x=1/16 {
replace evasionrate_true = r(N`x') if wealthgroupB==`x'
}
*

/*** Use program to bootstrap disclosure rates and standard errors ***/
gen evasionrate_bs = .
gen evasionrate_se = .
gen evasionrate_upper = .
gen evasionrate_lower = .
bootstrap r(N1) r(N2) r(N3) r(N4) r(N5) r(N6) r(N7) r(N8) r(N9) r(N10) r(N11) r(N12) r(N13) r(N14) r(N15) r(N16), seed(1) reps(100) size($samplesize) nowarn nodots: Evasionrates imputed
matrix confintervals = e(ci_normal)
forvalues x=1/16 {
replace evasionrate_bs = _b[_bs_`x'] if wealthgroupB==`x'
replace evasionrate_se = _se[_bs_`x'] if wealthgroupB==`x'
replace evasionrate_upper = confintervals[2,`x'] if wealthgroupB==`x'
replace evasionrate_lower = confintervals[1,`x'] if wealthgroupB==`x'
}

/*** Clean up and save ***/
cap drop obsno
by wealthgroupB, sort: gen obsno = _n
keep if obsno==1
keep wealthgroupB evasionrate_true evasionrate_bs evasionrate_se evasionrate_upper evasionrate_lower
save "$outputpath/Fig5B_results_lowscen_reweighting.dta", replace


/*** Make figure 5B with standard errors ***/
label define categories2 10 "P90-95" 11 "P95-99" 12 "P99-99.5" 13 "P99.5-99.9" 14 "P99.9-99.95" 15 "P99.95-99.99" 16 "P99.99-100"
label values wealthgroupB categories2
twoway (connect evasionrate_bs wealthgroupB) (rcap evasionrate_upper evasionrate_lower wealthgroupB) ///
if wealthgroupB>=10 & wealthgroupB<=16, xscale(range(10 16)) xlabel(10/16) ///
scheme(s1mono) xlabel(10 11 12 13 14 15 16, valuelabel labsize(small) angle(90)) legend(off) xtitle("") ///
title("Offshore evasion rates by wealth group" "(bootstrapped standard errors)")  note("hsbc and discloser samples are reweighted to have same weight") subtitle("low scenario")
graph export "$outputpath/Fig5B_graph_lowscen_reweighting.pdf", as(pdf) replace



***********************************************************************************************************
***********************************************************************************************************
/*************** 4. Combine Figures 6 and 5B to produce Figure 1 with standard errors ********************/
***********************************************************************************************************
***********************************************************************************************************

*********** 4A. Prepare random audit results **************
* use "$datapath\WorkDenmark\RandomAudits\BootstrapStandardErrors\BootstrapResults.dta", clear 
use "$datapath/WorkDenmark/RandomAudits/BootstrapStandardErrors/BootstrapResults.dta", clear 
expand 4 if wealthgroup2==13
sort wealthgroup2
gen wealthgroupB = _n
save "$outputpath/RandomAudits.dta", replace


*********** 4B. Weights on HSBC and Discloser samples equal to their actual sample size **************** 
/*** Construct combined point estimates and standard errors ***/
use "$outputpath/Fig5B_results_mainscen_noreweighting.dta", clear
sort wealthgroupB
merge 1:1 wealthgroupB using "$outputpath/RandomAudits.dta"
keep wealthgroupB evasionrate_true evasionrate_se errorrate_baseline errorrate_se
expand 10000
gen evasionrate_simul = rnormal(evasionrate_true, evasionrate_se)
gen errorrate_simul = rnormal(errorrate_baseline, errorrate_se)
gen totevasionrate_simul = errorrate_simul*(1-evasionrate_simul) + evasionrate_simul*(1-errorrate_simul)
gen totevasionrate_true = errorrate_baseline*(1-evasionrate_true) + evasionrate_true*(1-errorrate_baseline)
gen totevasionrate_upper = .
gen totevasionrate_lower = .
gen totevasionrate_mean = .
forvalues x=1/16 {
*_pctile totevasionrate_simul if wealthgroupB==`x', p(2.5, 97.5)
*replace totevasionrate_lower = r(r1) if wealthgroupB==`x'
*replace totevasionrate_upper = r(r2) if wealthgroupB==`x'
sum totevasionrate_simul if wealthgroupB==`x'
replace totevasionrate_lower = totevasionrate_true - 1.96*r(sd) if wealthgroupB==`x'
replace totevasionrate_upper = totevasionrate_true + 1.96*r(sd) if wealthgroupB==`x'
replace totevasionrate_mean = r(mean) if wealthgroupB==`x'
}
bysort wealthgroupB: keep if _n==1
drop evasionrate_simul errorrate_simul totevasionrate_simul
save "$outputpath/Fig1_results_noreweighting.dta", replace

/*** Make figure 1 with standard errors ***/
label define categories3 1 "P0-10" 2 "P10-20" 3 "P20-30" 4 "P30-40" 5 "P40-50" 6 "P50-60" 7 "P60-70" 8 "P70-80" 9 "P80-90" 10 "P90-95" 11 "P95-99" 12 "P99-99.5" 13 "P99.5-99.9" 14 "P99.9-99.95" 15 "P99.95-99.99" 16 "P99.99-100"
label values wealthgroupB categories3
twoway (connect totevasionrate_true wealthgroupB) (rcap totevasionrate_upper totevasionrate_lower wealthgroupB) ///
if wealthgroupB>=1 & wealthgroupB<=16, xscale(range(1 16)) xlabel(1/16) ///
scheme(s1mono) xlabel(1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16, valuelabel labsize(small) angle(90)) legend(off) xtitle("") ///
title("Total evasion rates by wealth group" "(bootstrapped standard errors)")  note("hsbc and discloser samples are not reweighted to have same weight")
graph export "$outputpath/Fig1_graph_noreweighting.pdf", as(pdf) replace



*********** 4C. Equal weights on HSBC and Discloser sample **************** 
/*** Construct combined point estimates and standard errors ***/
use "$outputpath/Fig5B_results_mainscen_reweighting.dta", clear
sort wealthgroupB
merge 1:1 wealthgroupB using "$outputpath/RandomAudits.dta"
keep wealthgroupB evasionrate_true evasionrate_se errorrate_baseline errorrate_se
expand 10000
gen evasionrate_simul = rnormal(evasionrate_true, evasionrate_se)
gen errorrate_simul = rnormal(errorrate_baseline, errorrate_se)
gen totevasionrate_simul = errorrate_simul*(1-evasionrate_simul) + evasionrate_simul*(1-errorrate_simul)
gen totevasionrate_true = errorrate_baseline*(1-evasionrate_true) + evasionrate_true*(1-errorrate_baseline)
gen totevasionrate_upper = .
gen totevasionrate_lower = .
gen totevasionrate_mean = .
forvalues x=1/16 {
*_pctile totevasionrate_simul if wealthgroupB==`x', p(2.5, 97.5)
*replace totevasionrate_lower = r(r1) if wealthgroupB==`x'
*replace totevasionrate_upper = r(r2) if wealthgroupB==`x'
sum totevasionrate_simul if wealthgroupB==`x'
replace totevasionrate_lower = totevasionrate_true - 1.96*r(sd) if wealthgroupB==`x'
replace totevasionrate_upper = totevasionrate_true + 1.96*r(sd) if wealthgroupB==`x'
replace totevasionrate_mean = r(mean) if wealthgroupB==`x'
}
bysort wealthgroupB: keep if _n==1
drop evasionrate_simul errorrate_simul totevasionrate_simul
save "$outputpath/Fig1_results_reweighting.dta", replace

/*** Make figure 1 with standard errors ***/
label define categories3 1 "P0-10" 2 "P10-20" 3 "P20-30" 4 "P30-40" 5 "P40-50" 6 "P50-60" 7 "P60-70" 8 "P70-80" 9 "P80-90" 10 "P90-95" 11 "P95-99" 12 "P99-99.5" 13 "P99.5-99.9" 14 "P99.9-99.95" 15 "P99.95-99.99" 16 "P99.99-100"
label values wealthgroupB categories3
twoway (connect totevasionrate_true wealthgroupB) (rcap totevasionrate_upper totevasionrate_lower wealthgroupB) ///
if wealthgroupB>=1 & wealthgroupB<=16, xscale(range(1 16)) xlabel(1/16) ///
scheme(s1mono) xlabel(1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16, valuelabel labsize(small) angle(90)) legend(off) xtitle("") ///
title("Total evasion rates by wealth group" "(bootstrapped standard errors)")  note("hsbc and discloser samples are reweighted to have same weight")
graph export "$outputpath/Fig1_graph_reweighting.pdf", as(pdf) replace



/*
************************************************************************************************************************
/*** Check that micro-data correspond to macro totals in appendix ***/
use "$outputpath/sample_scandinavia.dta", clear
keep if zeroaccount==0
replace country = "hsbc" if country~="Norway_discl"
collapse (sum) amt_hsbc, by(wealthgroupB country)
by country, sort: egen total = sum(amt_hsbc)
gen fraction = amt_hsbc / total
sort country wealthgroup
************************************************************************************************************************

