*! Generate Norway + Sweden dataset (population-wide) using g-ptiner
* and impute Panama and discloser dummies


* First, need to run gpinter to generate nor+swe datasets (http://wid.world/gpinter/)


*************************************************************************
* Generate Norway + Sweden file (full sampling top 10%, partial bottom 90%) *
*************************************************************************
/*
	import delimited "$root/WorkScandinavia/Programs/gpinter/output/sample_norswe.csv", varn(1)  clear
	rename merged2006 wealthusd
	su wealthusd, det 
	local nb_hhold = r(N)
	cumul wealthusd, gen(rank_scand)
	gen weight = 1
	set seed 8573
	gen double r = runiform() if rank_scand <= .9
	sort r 
	qui su r if rank_scand <= .9
	drop if _n >= r(N)/50 & rank_scand <= .9
	replace weight = 50 if rank_scand <= .9
	di "NUMBER OF HOUSEHOLDS IN NORWAY + SWEDEN: `nb_hhold'"
	qui su weight, det 
	di "NUMBER OF HOUSEHOLDS IN NORWAY + SWEDEN, BIG FILE: `r(sum)'"
	* assert `r(sum)' == `nb_hhold'
	gen ctry = ""
	keep wealthusd weight ctry
	compress
	saveold "$root/WorkScandinavia/temp/big_norswe.dta", replace

*************************************************************************
* Import Panam and discloser dummies in big Norway + Sweden file
*************************************************************************

* Collapse evasion2006 dataset to same format as raw Panama and discloser tabulations (= ToStata Excel sheets)	
	use "$root/WorkScandinavia/Output/evasion2006.dta", clear
	gen group = ptile_w
	foreach i of numlist 0/8 {
		local j = `i' + 1
		replace group = `i' * 10000 if ptile_w >= `i' * 10000 & ptile_w < `j' * 10000
	}	
	* Impute discloser and Panama dummies (`dummy') within top 0.01% (assume binomial distrib with same proba in each .001% bin)
	gen top = (ptile_w >= 99990)
	foreach dummy in panama disc {
		bys top ctry: egen nb_`dummy'_by_group=sum(nb_`dummy')
		set seed 5397
		sort ctry ptile
		gen impute_`dummy' = rbinomial(nb_`dummy'_by_group, 0.1) if top == 1
		local ii = 1
		local control = 1
		while `control' != 0 {
			cap drop nb_`dummy'_by_group 
			bys top ctry: egen nb_`dummy'_by_group=sum(nb_`dummy') if top == 1
			cap drop check 
			bys top ctry: egen check = sum(impute_`dummy') if top == 1
			replace check = ((check - nb_`dummy'_by_group)^2 >= 1e-5) if top == 1
			set seed `ii'
			sort ctry ptile
			replace impute_`dummy' = rbinomial(nb_`dummy'_by_group, 0.1) if top == 1 & check == 1
			qui su check, meanonly
			local control = r(sum)
			local ii = `ii' + 1
		}
		replace nb_`dummy' = impute_`dummy' if ptile_w >= 99990
		saveold "$root/WorkScandinavia/temp/evasion06forimputation_`dummy'.dta", replace
	}

* Create dataset of frequencies by US$ wealth bin for imputation	
foreach dummy in panama disc {
	use "$root/WorkScandinavia/temp/evasion06forimputation_`dummy'.dta", clear
	replace wealth_inf = wealth_inf / fx
	replace wealth_sup = wealth_sup / fx
	egen bin = group(group ctry)
	collapse (min) group wealth_inf (max) wealth_sup (sum) nb_`dummy'  (first) ctry, by(bin)
	drop if nb_`dummy' == 0
	keep wealth_inf wealth_sup nb_`dummy' ctry
	replace nb_`dummy' = round(nb_`dummy')
	saveold "$root/WorkScandinavia/temp/frequ_`dummy'.dta", replace
}

* Impute dummy in population-wide NOR + SWE file (country-by-country)

	use "$root/WorkScandinavia/temp/big_norswe.dta", clear
	foreach dummy in panama disc {
		cap drop `dummy'
		gen `dummy' = 0	
	saveold "$root/WorkScandinavia/temp/big_norswe.dta", replace
	}

	mat drop _all
	foreach dummy in panama disc {
		foreach country in SWE NOR {
			use "$root/WorkScandinavia/temp/frequ_`dummy'.dta", clear
			keep if ctry == "`country'"
			drop ctry
			mkmat _all, mat(frequ_`country')
			di "IMPUTATION MATRIX FOR COUNTRY `country'"
			mat list frequ_`country'
			use "$root/WorkScandinavia/temp/big_norswe.dta", clear
			sort wealthusd
			local ii = 1
			local nb_bins = rowsof(frequ_`country')
			local count = 0
			set seed 736
			while `ii' <= `nb_bins' {
				di "WEALTH BIN MIN - MAX IN `country'"
				di frequ_`country'[`ii', 1]
				di frequ_`country'[`ii', 2] 
				cap drop bin
				qui gen bin = 1 if wealthusd >= frequ_`country'[`ii', 1] & wealthusd < frequ_`country'[`ii', 2] & ctry == ""
				cap drop r
				sort wealthusd
				qui gen double r = runiform() if wealthusd >= frequ_`country'[`ii', 1] & wealthusd < frequ_`country'[`ii', 2] & ctry == ""
				sort bin r 
				replace `dummy' = `dummy' + 1/weight if _n <= frequ_`country'[`ii', 3]
				replace ctry = "`country'" if _n <= frequ_`country'[`ii', 3]
				local count = `count' + frequ_`country'[`ii', 3]
				sum `dummy' [fw = weight] if ctry == "`country'", meanonly
				di "TOTAL NUMBER OF `dummy' EVADERS  IN `country': `count'"
				assert round(r(sum)) == `count'
				local ii = `ii' + 1
			}
			compress
			saveold "$root/WorkScandinavia/temp/big_norswe.dta", replace
		}	
	}
	
	foreach dummy in panama disc {
		expand weight if `dummy' > 0 & `dummy' < 1, gen(new_`dummy')
		replace weight = 1 	if `dummy' > 0 & `dummy' < 1
		replace new_`dummy' = . if `dummy' == 0 | `dummy' >= 1
		replace `dummy' = 1 if new_`dummy' == 0
		replace `dummy' = 0 if new_`dummy' == 1
		replace ctry = ""   if new_`dummy' == 1
	}	
	cumul wealthusd [fw = weight], gen(rank_scand)
	keep wealthusd weight panama disc ctry rank_scand
	compress
	saveold "$root/WorkScandinavia/temp/big_norswe.dta", replace

*************************************************************************
* Impute Swedish amounts based on Norway ranked by wealth excluding disclosed wealth *
*************************************************************************


* Create Norwegian discloser table with amounts disclosed by bins of pre-disclosure wealth, in US$
	use "$root/WorkNorway/SmallFiles/small06hhold_PRE.dta", clear
		replace ptile_w = round(1000 * ptile_w)
		replace vd_evader = round(vd_evader * weight)
		replace vd_case_dropped = round(vd_evader * vd_case_dropped)
		gen nb_disc = vd_evader - vd_case_dropped
		replace disclosed_wealth07C = (disclosed_wealth07C * vd_evader) / nb_disc
		rename thwealth wealth_inf
		gen wealth_sup = wealth_inf[_n+1]
		gen ctry = "NOR"
	merge m:1 year ctry using $root/WorkScandinavia/temp/exchange_rates.dta, keepusing(fx) keep(match master)
	replace wealth_inf = wealth_inf / fx
	replace wealth_sup = wealth_sup / fx
	gen wealthusd = mwealth / fx
	gen amt_disc_usd = disclosed_wealth07C / fx
	gen tot_hidden = amt_disc_usd * nb_disc
 	qui su tot_hidden
 		local tot_hidden = round(r(sum)/1e9, .01)
 		di "TOTAL HIDDEN WEALTH = `tot_hidden' BILLION US$"
 	gen se_disc_usd = disclosed_wealth07C_SD / fx
 	keep  ptile_w wealth_inf wealth_sup nb_disc amt_disc_usd se_disc_usd wealthusd vd_evader vd_case_dropped weight
 	order ptile_w wealth_inf wealth_sup nb_disc amt_disc_usd se_disc_usd wealthusd vd_evader vd_case_dropped weight
 	saveold "$root/WorkScandinavia/temp/tab_NOR_disc.dta", replace

* Collapse Norwegian table so as to have at least 5 obs in each wealth bracket
	use "$root/WorkScandinavia/temp/tab_NOR_disc.dta", clear
		keep ptile_w wealth_inf wealth_sup nb_disc amt_disc_usd se_disc_usd
		sort ptile_w
		keep if _n == 1
		saveold "$root/WorkScandinavia/temp/tab_NOR_disc_collapsed.dta", replace
	use "$root/WorkScandinavia/temp/tab_NOR_disc.dta", clear
	sort ptile_w
	local ii = 2
	local control = 0
	su nb_disc
	local totnumdisc = r(sum)
	while `control' != `totnumdisc' {
		use "$root/WorkScandinavia/temp/tab_NOR_disc.dta", clear
		drop if _n < `ii'
		cap drop cumul
		gen cumul = sum(nb_disc)
		keep if _n== 1 | cumul[_n-1] < 5
		qui su
		local numobs = r(N)
		gen sd_over_mean = se_disc_usd / amt_disc_usd
		su sd_over_mean
		local sd_over_mean = r(mean)
		replace amt_disc_usd = amt_disc_usd * nb_disc
		collapse (min) ptile_w wealth_inf (max) wealth_sup (sum) nb_disc amt_disc_usd
		replace amt_disc_usd = amt_disc_usd / nb_disc 
		gen se_disc_usd = amt_disc_usd * `sd_over_mean'
		append using "$root/WorkScandinavia/temp/tab_NOR_disc_collapsed.dta"
		saveold "$root/WorkScandinavia/temp/tab_NOR_disc_collapsed.dta", replace
		su nb_disc
		local control = r(sum)
		local ii = `ii' + `numobs'
	}
	sort ptile_w_pre
	saveold "$root/WorkScandinavia/temp/tab_NOR_disc_collapsed.dta", replace

* Impute wealth disclosed in Sweden, bracket by bracket
	use "$root/WorkScandinavia/temp/tab_NOR_disc_collapsed.dta", clear
	sort ptile_w
	replace wealth_inf = -1e13 if _n == 1
	replace wealth_sup = . if _n == _N
		mkmat _all, mat(disc_NOR)
		mat list disc_NOR
	use "$root/WorkScandinavia/temp/big_norswe.dta", clear
	keep if ctry == "SWE"
	sort wealthusd
	local ii = 1
	local nb_bins = rowsof(disc_NOR)
	local count = 0
	set seed 666
	cap drop amt_disc
	qui gen amt_disc = 0
	while `ii' <= `nb_bins' {
		di "WEALTH BIN MIN - MAX"
		di disc_NOR[`ii', 2]
		di disc_NOR[`ii', 3] 
		cap drop bin
		qui gen bin = 1 if wealthusd >= disc_NOR[`ii', 2] & wealthusd < disc_NOR[`ii', 3] 

		local control = 1	
		local jj = 1
		while `control' > .05 {		
			cap drop s 
			set seed `jj'
			sort wealthusd
		 	gen double s = runiform() if bin == 1 
		 	cap drop imputed
		 	gen imputed = ///
		 	exp( ///
		 	ln(disc_NOR[`ii', 5] / sqrt(1 + disc_NOR[`ii', 6]^2 / disc_NOR[`ii', 5]^2)) ///
		 	+ sqrt(ln(1 + disc_NOR[`ii', 6]^2 / disc_NOR[`ii', 5]^2)) * invnorm(s) ///
		 	)
		 	replace amt_disc = imputed if bin == 1

			* Check: average amount in bin is within 5% of Norwegian average
			di "TRUE AVERAGE AMOUNT IN BIN"
			di disc_NOR[`ii', 5]
			local control = 0
			qui su bin if bin == 1
			if r(N) != 0 {
				qui su amt_disc  [fw = weight] if bin == 1, meanonly
				local imputed_amt = r(mean)
				di "IMPUTED AVERAGE AMOUNT IN BIN = `imputed_amt'"
				local control = abs((`imputed_amt' - disc_NOR[`ii', 5])) / disc_NOR[`ii', 5]
				di "GAP BETWEEN IMPUTED HSBC AVERAGE IN BIN AND TRUE AVERAGE = `control'"
			}	
			local jj = `jj' + 1	
		}
	local ii = `ii' + 1
	}
	drop bin s imputed
	save "$root/WorkScandinavia/temp/imputed_disc_swe.dta", replace
	use "$root/WorkScandinavia/temp/big_norswe.dta", clear
	sort rank_scand ctry disc
	merge 1:1 rank_scand ctry disc using "$root/WorkScandinavia/temp/imputed_disc_swe.dta", nogen keepusing(amt_disc)
	saveold "$root/WorkScandinavia/temp/big_norswe.dta", replace
*/
*************************************************************************
* Add HSBC wealth in Norway and Sweden
*************************************************************************

	use "$root/WorkScandinavia/temp/big_scand.dta", clear
		keep if hsbc == 1 & (ctry == "NOR" | ctry == "SWE")
		drop rank_scand
		saveold "$root/WorkScandinavia/temp/hsbc_to_append.dta", replace
	
	use "$root/WorkScandinavia/temp/big_norswe.dta", clear
		total weight
		qui su weight, det
		local total1 = r(sum)
		append using "$root/WorkScandinavia/temp/hsbc_to_append.dta"
		sort wealthusd
		replace weight = weight - 1 if hsbc[_n+1] == 1  & hsbc != 1
		total weight 
		qui su weight, det
		local total2 = r(sum)
		assert round(`total1') == round(`total2')
		* Check small overlap HSBC-discloser and Panama-discloser
		total disc if hsbc[_n+1] == 1
		total panama if hsbc[_n+1] == 1 
		cap drop rank_scand
		cumul wealthusd [fw=weight], gen(rank_scand)
		foreach var of varlist hsbc hsbc_pos amt_hsbc {
			replace `var' = 0 if `var' == .
		}
	compress 	
	saveold "$root/WorkScandinavia/temp/big_norswe_with_hsbc.dta", replace
