*! Generate Scandinavian dataset (population-wide) using g-ptiner
* and impute HSBC dummies


*************************************************************************
* Prepare data for g-pinter *
*************************************************************************
/*
* Prepare inputs for gpinter
	foreach ctr in NOR SWE DNK {
		use "$root/WorkScandinavia/Output/evasion2006.dta", clear
		keep if ctry == "`ctr'"
		rename ctry country
		gen bracketavg = mwealth / fx
		replace ptile_w = ptile_w / 100000
		rename ptile_w p
		gen  thr = wealth_inf / fx
		qui su bracketavg [fw=weight]
		gen average = r(mean)
		egen popsize = total(weight)
		sort country p
		order year country popsize average p thr bracketavg
		keep year country  popsize average p thr bracketavg
		foreach var of varlist year popsize average {
			replace `var' = . if _n > 1
		}
		replace country = "" if _n > 1
		export excel "$root/WorkScandinavia/Programs/gpinter/input/to_gpinter.xlsx", sh(`ctr') sheetreplace first(var)
	}

* Run gpinter to generate scand dataset (http://wid.world/gpinter/)
*/

*************************************************************************
* Generate big Scandinavian file (full sampling top 10%, partial bottom 90%) *
*************************************************************************

foreach country in swe nor dnk scand {
	import delimited "$root/WorkScandinavia/Programs/gpinter/output/sample_`country'.csv", varn(1)  clear
	rename *2006 wealthusd
	su wealthusd, det 
	local nb_hhold = r(N)
	sort wealthusd
	cumul wealthusd, gen(rank_`country')
	gen weight = 1
	set seed 8373
	gen double r = runiform() if rank_`country' <= .9
	sort r 
	qui su r if rank_`country' <= .9
	drop if _n >= r(N)/50 & rank_`country' <= .9
	replace weight = 50 if rank_`country' <= .9
	drop r
	saveold "$root/WorkScandinavia/temp/big_`country'.dta", replace
}

*************************************************************************
* Import HSBC dummies in big Scandinavian file
*************************************************************************
	

* Impute HSBC dummies in big file (country by country)

	
	use "$root/WorkScandinavia/temp/big_scand.dta", clear
		cap drop hsbc
		gen hsbc = 0
		cap drop ctry
		gen ctry = ""
		cap drop hsbc_pos
		gen hsbc_pos = 0
		cap drop amt_hsbc
		gen amt_hsbc = 0
	saveold "$root/WorkScandinavia/temp/big_scand.dta", replace
	mat drop _all
	foreach country in DNK SWE NOR  {
		use "$root/WorkScandinavia/temp/tab_`country'_hsbc.dta", clear
		drop if nb_hsbc == 0 | nb_hsbc == .
		keep  wealth_inf wealth_sup nb_hsbc nb_hsbc_pos amt_hsbc se_amt_hsbc 
		order wealth_inf wealth_sup nb_hsbc nb_hsbc_pos amt_hsbc se_amt_hsbc
		mkmat _all, mat(frequ_`country')
		di "IMPUTATION MATRIX FOR COUNTRY `country'"
		mat list frequ_`country'
		use "$root/WorkScandinavia/temp/big_scand.dta", clear
		local ii = 1
		local nb_bins = rowsof(frequ_`country')

		while `ii' <= `nb_bins' {

			di "WEALTH BIN MIN - MAX IN `country'"
			di frequ_`country'[`ii', 1]
			di frequ_`country'[`ii', 2] 
			cap drop bin
			qui gen bin = 1 if wealthusd >= frequ_`country'[`ii', 1] & wealthusd < frequ_`country'[`ii', 2]  & ctry==""
			cap drop r
			set seed 83981
			sort wealthusd
			qui gen double r = runiform() if wealthusd >= frequ_`country'[`ii', 1] & wealthusd < frequ_`country'[`ii', 2]
			sort bin r 
			replace hsbc = hsbc + 1/weight if _n <= frequ_`country'[`ii', 3]
			qui replace ctry = "`country'" if  _n <= frequ_`country'[`ii', 3]
			set seed 303
			cap drop q
			sort wealthusd
			qui gen double q = runiform() if wealthusd >= frequ_`country'[`ii', 1] & wealthusd < frequ_`country'[`ii', 2] 
			gsort bin -hsbc q
			replace hsbc_pos = hsbc_pos + 1/weight if _n <= frequ_`country'[`ii', 4] 

			
			local control = 1	
			local jj = 1
			while `control' > .05 {

			* *	local jj = 1
			* *	local check_imputed_less_than_wealth = 1
			* *	while `check_imputed_less_than_wealth' != 0 {

				cap drop s 
				set seed `jj'
			 	sort wealthusd
			 	gen double s = runiform() if bin == 1 & hsbc_pos > 0
			 	cap drop imputed
			 	gen imputed = ///
			 	exp( ///
			 	ln(frequ_`country'[`ii', 5] / sqrt(1 + frequ_`country'[`ii', 6]^2 / frequ_`country'[`ii', 5]^2)) ///
			 	+ sqrt(ln(1 + frequ_`country'[`ii', 6]^2 / frequ_`country'[`ii', 5]^2)) * invnorm(s) ///
			 	)
			 	replace amt_hsbc = imputed if bin == 1 & hsbc_pos > 0

				* * Check: imputed amount less than wealth for all individuals with more than 1 million in net wealth 
				* count if bin == 1 & hsbc_pos > 0 & wealthusd > 1e6 
				* 	local count1 = r(N)
				* count if bin == 1 & hsbc_pos > 0 & wealthusd > 1e6  & imputed <= wealthusd 
				* 	local count2 = r(N)
				* if `count1' == `count2' local check_imputed_less_than_wealth = 0

				* Check: average amount in bin is within 5% of true average
				di "TRUE AVERAGE AMOUNT IN BIN"
				di frequ_`country'[`ii', 5]
				local control = 0
				if frequ_`country'[`ii', 4] != 0 {
					qui su amt_hsbc  [fw = weight] if bin == 1 & hsbc_pos > 0, meanonly
					local imputed_amt = r(mean)
					di "IMPUTED AVERAGE AMOUNT IN BIN = `imputed_amt'"
					local control = abs((`imputed_amt' - frequ_`country'[`ii', 5])) / frequ_`country'[`ii', 5]
					di "GAP BETWEEN IMPUTED HSBC AVERAGE IN BIN AND TRUE AVERAGE = `control'"
				}	
			local jj = `jj' + 1	
			}
			* local kk = `kk' + 1
			* }

			local ii = `ii' + 1
		}
		
		expand weight if hsbc > 0 & hsbc < 1, gen(new_hsbc)
		replace new_hsbc = . if hsbc == 0 | hsbc >= 1
		foreach var of varlist hsbc hsbc_pos {
			replace `var' = weight * `var' if new_hsbc == 0
			replace `var' = 0 			   if new_hsbc == 1
		}
		replace weight = 1 	if new_hsbc == 0 | new_hsbc == 1
		replace ctry = ""	if new_hsbc == 1
		replace hsbc_pos = 0 if hsbc_pos == .
		replace amt_hsbc = 0 if hsbc_pos == 0

		keep wealthusd weight hsbc hsbc_pos amt_hsbc ctry
		compress
		saveold "$root/WorkScandinavia/temp/big_scand.dta", replace
	}	

	use "$root/WorkScandinavia/temp/big_scand.dta", clear
		cumul wealthusd [fw = weight], gen(rank_scand)
	saveold "$root/WorkScandinavia/temp/big_scand.dta", replace	


* Check that totals add up
	use "$root/WorkScandinavia/temp/big_scand.dta", clear
	table ctry  [fw = weight], c(sum  amt_hsbc sum hsbc sum hsbc_pos) row col
	qui su amt_hsbc [fw = weight]
		local imputed_amount_hsbc = round(`r(sum)' / 1e6)
		di "IMPUTED AMOUNT HSBC WEALTH: `imputed_amount_hsbc' US$ millions"
	qui use "$root/WorkScandinavia/Output/evasion2006.dta", clear
	replace amt_hsbc = amt_hsbc / fx
	qui su amt_hsbc [w = nb_hsbc_pos]
		local total_amount_hsbc = round(`r(sum)' / 1e6)
	 	di "TOTAL AMOUNT HSBC WEALTH: `total_amount_hsbc' US$  billion"
	 local control = abs(`total_amount_hsbc' - `imputed_amount_hsbc') / `total_amount_hsbc'
	 assert `control' <= .05



