*! Distribution of disclosers in Norway, Sweden, and Norway + Sweden

* Outputs results in Appendix G Excel file (formerly discloser_by_bin.xlsx)
	global out_disc "$root/ExcelFiles/AJZ2017AppendixG.xlsx"


*************************************************************************
* Norwegian disclosers * 
*************************************************************************

* By bins of Norwegian wealth, from P0-10 up to P99.95-P100
	use $root/WorkScandinavia/Output/evasion2006.dta, clear
	keep if ctry == "NOR"
	gen group = ""
	foreach i of numlist 0/9 {
		local j = `i' + 1
		replace group = "P`i'0-`j'0" if ptile_w >= `i'*10000   & ptile_w < `j'*10000
	}	
	replace group = "P90-95"		 if ptile_w >= 90000  	& ptile_w < 95000
	replace group = "P95-99"		 if ptile_w >= 95000  	& ptile_w < 99000
	replace group = "P99-99.5"		 if ptile_w >= 99000  	& ptile_w < 99500
	replace group = "P99.5-99.9"	 if ptile_w >= 99500 	& ptile_w < 99900
	replace group = "P99.9-P99.95"	 if ptile_w >= 99900 	& ptile_w < 99950
	replace group = "P99.95-P100"	 if ptile_w >= 99950
	gen tot_wealth =  mwealth * weight
	replace disclosed_wealth = disclosed_wealth * vd_evader
	collapse (min) wealth_inf (sum) tot_wealth vd* disclosed_wealth weight nb_disc, by(group)
	replace  tot_wealth = tot_wealth / weight
	rename tot_wealth wealth
	order group weight wealth_inf wealth vd_evader vd_case_dropped disclosed_wealth nb_disc
	export excel using "$out_disc", sheetmodify first(var) sh(discloser(NOR1))


* By bins of Norwegian wealth, from P0-50 up to P99.99
	use $root/WorkScandinavia/Output/evasion2006.dta, clear
	keep if ctry == "NOR"
	gen group = "P0-50"
	replace group = "P50-90"		if  ptile_w >= 50000  	& ptile_w < 90000
	replace group = "P90-95"		if  ptile_w >= 90000  	& ptile_w < 95000
	replace group = "P95-99"		if  ptile_w >= 95000  	& ptile_w < 99000
	replace group = "P99-99.5"		if  ptile_w >= 99000  	& ptile_w < 99500
	replace group = "P99.5-99.9"	if  ptile_w >= 99500 	& ptile_w < 99900
	replace group = "P99.9-P99.95"	if  ptile_w >= 99900 	& ptile_w < 99950
	replace group = "P99.95-P99.99"	if  ptile_w >= 99950	& ptile_w < 99990
	replace group = "P99.99-P100"	if  ptile_w >= 99990	 
	gen tot_wealth =  mwealth * weight
	replace disclosed_wealth = disclosed_wealth * vd_evader
	collapse (min) wealth_inf (sum) tot_wealth vd* disclosed_wealth weight nb_disc, by(group)
	replace  tot_wealth = tot_wealth / weight
	rename tot_wealth wealth
	order group weight wealth_inf wealth vd_evader vd_case_dropped disclosed_wealth nb_disc
	export excel using "$out_disc", sheetmodify first(var) sh(discloser(NOR2))


* By bins of Norwegian wealth excluding disclosed wealth, in US$
	use "$root/WorkScandinavia/temp/tab_NOR_disc.dta", clear
	gen group = "P0-50"
	replace group = "P50-90"		if  ptile_w >= 50000  	& ptile_w < 90000
	replace group = "P90-95"		if  ptile_w >= 90000  	& ptile_w < 95000
	replace group = "P95-99"		if  ptile_w >= 95000  	& ptile_w < 99000
	replace group = "P99-99.5"		if  ptile_w >= 99000  	& ptile_w < 99500
	replace group = "P99.5-99.9"	if  ptile_w >= 99500 	& ptile_w < 99900
	replace group = "P99.9-P99.95"	if  ptile_w >= 99900 	& ptile_w < 99950
	replace group = "P99.95-P99.99"	if  ptile_w >= 99950	& ptile_w < 99990
	replace group = "P99.99-P100"	if  ptile_w >= 99990	 
	gen tot_wealth =  wealthusd * weight
	replace amt_disc_usd = amt_disc_usd * vd_evader
	collapse (min) wealth_inf   (sum) tot_wealth amt_disc_usd vd* nb_disc weight, by(group)
	replace  tot_wealth = tot_wealth / weight
	rename tot_wealth wealthusd
	order group weight wealth_inf wealthusd vd_evader vd_case_dropped amt_disc_usd nb_disc
	export excel using "$out_disc", sheetmodify first(var) sh(discloser(NOR3))


*************************************************************************
* Swedish disclosers * 
*************************************************************************


* By bins of Swedish wealth, from P0-10 up to P99.95-P100
	use $root/WorkScandinavia/Output/evasion2006.dta, clear
	keep if ctry == "SWE"
	gen group = ""
	foreach i of numlist 0/9 {
		local j = `i' + 1
		replace group = "P`i'0-`j'0" if ptile_w >= `i'*10000   & ptile_w < `j'*10000
	}	
	replace group = "P90-95"		 if ptile_w >= 90000  	& ptile_w < 95000
	replace group = "P95-99"		 if ptile_w >= 95000  	& ptile_w < 99000
	replace group = "P99-99.5"		 if ptile_w >= 99000  	& ptile_w < 99500
	replace group = "P99.5-99.9"	 if ptile_w >= 99500 	& ptile_w < 99900
	replace group = "P99.9-P99.95"	 if ptile_w >= 99900 	& ptile_w < 99950
	replace group = "P99.95-P100"	 if ptile_w >= 99950
	gen tot_wealth =  mwealth * weight
	collapse (min) wealth_inf (sum) tot_wealth weight nb_disc, by(group)
	replace  tot_wealth = tot_wealth / weight
	rename tot_wealth wealth
	order group weight wealth_inf wealth nb_disc
	export excel using "$out_disc", sheetmodify first(var) sh(discloser(SWE1))


* By bins of Swedish wealth, from P0-50 up to P99.99
	use $root/WorkScandinavia/Output/evasion2006.dta, clear
	keep if ctry == "SWE"
	gen group = "P0-50"
	replace group = "P50-90"		if  ptile_w >= 50000  	& ptile_w < 90000
	replace group = "P90-95"		if  ptile_w >= 90000  	& ptile_w < 95000
	replace group = "P95-99"		if  ptile_w >= 95000  	& ptile_w < 99000
	replace group = "P99-99.5"		if  ptile_w >= 99000  	& ptile_w < 99500
	replace group = "P99.5-99.9"	if  ptile_w >= 99500 	& ptile_w < 99900
	replace group = "P99.9-P99.95"	if  ptile_w >= 99900 	& ptile_w < 99950
	replace group = "P99.95-P99.99"	if  ptile_w >= 99950	& ptile_w < 99990
	replace group = "P99.99-P100"	if  ptile_w >= 99990	 
	gen tot_wealth =  mwealth * weight
	collapse (min) wealth_inf (sum) tot_wealth weight nb_disc, by(group)
	replace  tot_wealth = tot_wealth / weight
	rename tot_wealth wealth
	order group weight wealth_inf wealth nb_disc
	export excel using "$out_disc", sheetmodify first(var) sh(discloser(SWE2))

* By bins of Swedish wealth, included imputed amount of disclosed wealth 
	use "$root/WorkScandinavia/temp/big_norswe.dta", clear
	keep if ctry == "SWE" & disc == 1
	keep wealthusd weight disc amt_disc
	saveold "$root/WorkScandinavia/temp/disc_swe.dta", replace 
	use "$root/WorkScandinavia/temp/big_swe.dta", clear
	keep wealthusd weight
	gen disc = 0
	gen amt_disc = 0
	order wealthusd weight disc amt_disc
	total weight 
	append using "$root/WorkScandinavia/temp/disc_swe.dta"
	sort wealthusd
	replace weight = weight - 1 if disc[_n+1] == 1  & disc != 1
	total weight 
	replace amt_disc = 0 if amt_disc == . 
	replace wealthusd = wealthusd + amt_disc
	cap drop rank_scand
	cumul wealthusd [fw=weight], gen(rank_scand)
	cap drop group
	gen group = "P0-50"
	replace group = "P50-90" if rank_scand >= .5  	& rank_scand < .9
	replace group = "P90-95" if  rank_scand >= .9 & rank_scand < .95
	replace group = "P95-99" if  rank_scand >= .95  		& rank_scand < .99
	replace group = "P99-99.5" if  rank_scand >= .99  		& rank_scand < .995
	replace group = "P99.5-99.9" if  rank_scand >= .995 		& rank_scand < .999
	replace group = "P99.9-P99.95" if  rank_scand >= .999 		& rank_scand < .9995
	replace group = "P99.95-P99.99" if rank_scand >= .9995 & rank_scand < .9999
	replace group = "P99.99-P100" if rank_scand >= .9999
	gen pop = 1
	collapse (min) th_usd = wealthusd (mean) wealthusd (sum) nb_disc = disc pop [fw = weight], by(group)
	rename pop weight
	gen frac = nb_disc / weight
	order group th_usd wealthusd nb_disc weight frac 
	export excel using "$out_disc", sheetmodify first(var) sh(discloser(SWE3))


*************************************************************************
* Pool Norwegian and Swedish disclosers *
*************************************************************************

* Distribution of disclosure dummies in pop-wide file  (binning 1, from P0-10 up to 99.95)
	use "$root/WorkScandinavia/temp/big_norswe.dta", clear
	cap drop group
	gen group = ""
	foreach i of numlist 0/9 {
		local j = `i' + 1
		replace group = "P`i'0-`j'0" if rank_scand >= `i'/10 & rank_scand < `j'/10
	}	
	replace group = "P90-95" if  rank_scand >= .9 & rank_scand < .95
	replace group = "P95-99" if  rank_scand >= .95  		& rank_scand < .99
	replace group = "P99-99.5" if  rank_scand >= .99  		& rank_scand < .995
	replace group = "P99.5-99.9" if  rank_scand >= .995 		& rank_scand < .999
	replace group = "P99.9-P99.95" if  rank_scand >= .999 		& rank_scand < .9995
	replace group = "P99.95-P100" if rank_scand >= .9995
	gen pop = 1
	collapse (min) th_usd = wealthusd (mean) wealthusd (sum) nb_disc = disc pop [fw = weight], by(group)
	rename pop weight
	gen frac = nb_disc / weight
	order group th_usd wealthusd nb_disc weight frac 
	export excel using "$out_disc", sheetmodify first(var) sh(Stata-fullpop1)

* Distribution of disclosure dummies in pop-wide file  (binning 2, from P0-50 up to P99.99)
	use "$root/WorkScandinavia/temp/big_norswe.dta", clear
	cap drop group
	gen group = "P0-50"
	replace group = "P50-90" if rank_scand >= .5  	& rank_scand < .9
	replace group = "P90-95" if  rank_scand >= .9 & rank_scand < .95
	replace group = "P95-99" if  rank_scand >= .95  		& rank_scand < .99
	replace group = "P99-99.5" if  rank_scand >= .99  		& rank_scand < .995
	replace group = "P99.5-99.9" if  rank_scand >= .995 		& rank_scand < .999
	replace group = "P99.9-P99.95" if  rank_scand >= .999 		& rank_scand < .9995
	replace group = "P99.95-P99.99" if rank_scand >= .9995 & rank_scand < .9999
	replace group = "P99.99-P100" if rank_scand >= .9999
	gen pop = 1
	collapse (min) th_usd = wealthusd (mean) wealthusd (sum) nb_disc = disc pop [fw = weight], by(group)
	rename pop weight
	gen frac = nb_disc / weight
	order group th_usd wealthusd nb_disc weight frac 
	export excel using "$out_disc", sheetmodify first(var) sh(Stata-fullpop2)


* Disclosure by bins of wealth including disclosed wealth, imputed in Sweden
	use "$root/WorkScandinavia/temp/big_norswe.dta", clear
		replace amt_disc = 0 if amt_disc == . 
		replace wealthusd = wealthusd + amt_disc if ctry=="SWE"
		cap drop rank_scand
		cumul wealthusd [fw=weight], gen(rank_scand)
		cap drop group
		gen group = "P0-50"
		replace group = "P50-90" if rank_scand >= .5  	& rank_scand < .9
		replace group = "P90-95" if  rank_scand >= .9 & rank_scand < .95
		replace group = "P95-99" if  rank_scand >= .95  		& rank_scand < .99
		replace group = "P99-99.5" if  rank_scand >= .99  		& rank_scand < .995
		replace group = "P99.5-99.9" if  rank_scand >= .995 		& rank_scand < .999
		replace group = "P99.9-P99.95" if  rank_scand >= .999 		& rank_scand < .9995
		replace group = "P99.95-P99.99" if rank_scand >= .9995 & rank_scand < .9999
		replace group = "P99.99-P100" if rank_scand >= .9999
		gen pop = 1
		collapse (min) th_usd = wealthusd (mean) wealthusd (sum) nb_disc = disc pop [fw = weight], by(group)
		rename pop weight
		gen frac = nb_disc / weight
		order group th_usd wealthusd nb_disc weight frac 
		export excel using "$out_disc", sheetmodify first(var) sh(Stata-fullpop3)


* Distribution of HSBC + discloser dummies by bins of wealth including disclosed wealth, imputed in Sweden
use "$root/WorkScandinavia/temp/big_norswe_with_hsbc.dta", clear
		replace amt_disc = 0 if amt_disc == . 
		replace wealthusd = wealthusd + amt_disc if ctry=="SWE"
		cap drop rank_scand
		cumul wealthusd [fw=weight], gen(rank_scand)
		cap drop group
		gen group = "P0-50"
		replace group = "P50-90" if rank_scand >= .5  	& rank_scand < .9
		replace group = "P90-95" if  rank_scand >= .9 & rank_scand < .95
		replace group = "P95-99" if  rank_scand >= .95  		& rank_scand < .99
		replace group = "P99-99.5" if  rank_scand >= .99  		& rank_scand < .995
		replace group = "P99.5-99.9" if  rank_scand >= .995 		& rank_scand < .999
		replace group = "P99.9-P99.95" if  rank_scand >= .999 		& rank_scand < .9995
		replace group = "P99.95-P99.99" if rank_scand >= .9995 & rank_scand < .9999
		replace group = "P99.99-P100" if rank_scand >= .9999
		gen pop = 1
		gen evader = max(disc, hsbc)
		collapse (min) th_usd = wealthusd (mean) wealthusd (sum) nb_evader = evader pop [fw = weight], by(group)
		rename pop weight
		gen frac = nb_evader / weight
		order group th_usd wealthusd nb_evader weight frac 
		export excel using "$out_disc", sheetmodify first(var) sh(Stata-fullpop4)
		