*! Distribution of HSBC evaders in Scandinavia

* Outputs results in Appendix E Excel file (formerly hsbc_by_bin.xls)
	global out_hsbc "$root/ExcelFiles/AJZ2017AppendixE.xlsx"

*************************************************************************
* Distribution in appended evasion2006 file (only useful for country by country distrib) *
*************************************************************************

* HSBC evaders by Scandinavian wealth bins (binning 1)
	use $root/WorkScandinavia/Output/evasion2006.dta, clear
	gen wealth_usd = mwealth / fx
	replace weight = round(weight)
	cumul wealth_usd [w=weight], gen(rank_scand)
	gen group = ""
	foreach i of numlist 0/9 {
		local j = `i' + 1
		replace group = "P`i'0-`j'0" if rank_scand >= `i'/10 & rank_scand < `j'/10
	}	
	replace group = "P90-95"		if rank_scand >= .9  	& rank_scand < .95
	replace group = "P95-99"		if rank_scand >= .95  	& rank_scand < .99
	replace group = "P99-99.5"		if rank_scand >= .99  	& rank_scand < .995
	replace group = "P99.5-99.9"	if rank_scand >= .995 	& rank_scand < .999
	replace group = "P99.9-P99.95"	if rank_scand >= .999 	& rank_scand < .9995
	replace group = "P99.95-P100"	if rank_scand >= .9995

	gen tot_wealth_usd =  wealth_usd * weight
	replace amt_hsbc = 0 if amt_hsbc < 0
	gen tot_hsbc = amt_hsbc * nb_hsbc_pos / fx
	collapse (min) th_usd = wealth_usd (sum) tot_wealth_usd nb_hsbc nb_hsbc_pos weight tot_hsbc, by(group)
	gen frac = nb_hsbc / weight
	gen frac_pos = nb_hsbc_pos / weight
	replace  tot_wealth_usd = tot_wealth_usd / weight
	rename tot_wealth_usd wealth_usd 
	order group th_usd wealth_usd nb_hsbc nb_hsbc_pos weight frac frac_pos 
	export excel using "$out_hsbc", sheetmodify first(var) sh(Stata-scand1)


* HSBC evaders by Scandinavian wealth bins (binning 2)
	use $root/WorkScandinavia/Output/evasion2006.dta, clear
	gen wealth_usd = mwealth / fx
	replace weight = round(weight)
	cumul wealth_usd [w=weight], gen(rank_scand)
	cap drop group
	gen group = "P0-50"
	replace group = "P50-90"		if rank_scand >= .5  	& rank_scand < .9
	replace group = "P90-95"		if rank_scand >= .9  	& rank_scand < .95
	replace group = "P95-99"		if rank_scand >= .95  	& rank_scand < .99
	replace group = "P99-99.5"		if rank_scand >= .99  	& rank_scand < .995
	replace group = "P99.5-99.9"	if rank_scand >= .995 	& rank_scand < .999
	replace group = "P99.9-P99.95"	if rank_scand >= .999 	& rank_scand < .9995
	replace group = "P99.95-P99.99"	if  rank_scand >= .99950	& rank_scand < .99990
	replace group = "P99.99-P100"	if  rank_scand >= .99990

	gen tot_wealth_usd =  wealth_usd * weight
	gen tot_hsbc = amt_hsbc * nb_hsbc_pos / fx	
	collapse (min) th_usd = wealth_usd (sum) tot_wealth_usd nb_hsbc nb_hsbc_pos weight tot_hsbc, by(group)
	gen frac = nb_hsbc / weight
	gen frac_pos = nb_hsbc_pos / weight
	replace  tot_wealth_usd = tot_wealth_usd / weight
	rename tot_wealth_usd wealth_usd 
	order group th_usd wealth_usd nb_hsbc nb_hsbc_pos weight frac frac_pos tot_hsbc
	export excel using "$out_hsbc", sheetmodify first(var) sh(Stata-scand2)


* Country-by-country distribution of evaders
	foreach country in NOR SWE DNK {
		use $root/WorkScandinavia/Output/evasion2006.dta, clear
		keep if ctry == "`country'"
		gen wealth_usd = mwealth / fx
		cap drop group
		gen group = "P0-50"
		replace group = "P50-90" if  ptile_w >= 50000  	& ptile_w < 90000
		replace group = "P90-95" if  ptile_w >= 90000  	& ptile_w < 95000
		replace group = "P95-99" if  ptile_w >= 95000  	& ptile_w < 99000
		replace group = "P99-99.5" if  ptile_w >= 99000  	& ptile_w < 99500
		replace group = "P99.5-99.9" if  ptile_w >= 99500 	& ptile_w < 99900
		replace group = "P99.9-P99.95" if  ptile_w >= 99900 	& ptile_w < 99950
		replace group = "P99.95-P99.99" if  ptile_w >= 99950 & ptile_w < 99990
		replace group = "P99.99-P100" if  ptile_w >= 99990 
		*replace group = "P99.95-P100" if  ptile_w >= 99950 
	 
		gen tot_wealth_usd =  wealth_usd * weight
		gen tot_hsbc = amt_hsbc * nb_hsbc_pos / fx	
		collapse (min) th_usd = wealth_usd (sum) tot_wealth_usd nb_hsbc nb_hsbc_pos weight tot_hsbc, by(group)
		gen frac = nb_hsbc / weight
		gen frac_pos = nb_hsbc_pos / weight
		replace  tot_wealth_usd = tot_wealth_usd / weight
		rename tot_wealth_usd wealth_usd 
		order group th_usd wealth_usd nb_hsbc nb_hsbc_pos weight frac frac_pos tot_hsbc
		export excel using "$out_hsbc", sheetmodify first(var) sh(Stata-`country')
	}


*************************************************************************
* Distribution in big population-wide file *
*************************************************************************


* Stats distribution of HSBC dummies in pop-wide file for hsbc_by_bin (binning 1, from P0-10 up to 99.95)
	use "$root/WorkScandinavia/temp/big_scand.dta", clear
	cap drop group
	gen group = ""
	foreach i of numlist 0/9 {
		local j = `i' + 1
		replace group = "P`i'0-`j'0" if rank_scand >= `i'/10 & rank_scand < `j'/10
	}	
	replace group = "P90-95" if  rank_scand >= .9 & rank_scand < .95
	replace group = "P95-99" if  rank_scand >= .95  		& rank_scand < .99
	replace group = "P99-99.5" if  rank_scand >= .99  		& rank_scand < .995
	replace group = "P99.5-99.9" if  rank_scand >= .995 		& rank_scand < .999
	replace group = "P99.9-P99.95" if  rank_scand >= .999 		& rank_scand < .9995
	replace group = "P99.95-P100" if rank_scand >= .9995

	gen pop = 1
	collapse (min) th_usd = wealthusd (mean) wealthusd (sum) nb_hsbc = hsbc nb_hsbc_pos = hsbc_pos pop tot_hsbc = amt_hsbc [fw = weight], by(group)
	rename pop weight
	gen frac = nb_hsbc / weight
	gen frac_pos = nb_hsbc_pos / weight
	order group th_usd wealthusd nb_hsbc nb_hsbc_pos weight frac frac_pos tot_hsbc
	export excel using "$out_hsbc", sheetmodify first(var) sh(Stata-fullpop1)

* Stats distribution of HSBC dummies in pop-wide file for hsbc_by_bin (alternative binning, from P0-50 up to P99.99)
	use "$root/WorkScandinavia/temp/big_scand.dta", clear
	cap drop group
	gen group = "P0-50"
	replace group = "P50-90" if rank_scand >= .5  	& rank_scand < .9
	replace group = "P90-95" if  rank_scand >= .9 & rank_scand < .95
	replace group = "P95-99" if  rank_scand >= .95  		& rank_scand < .99
	replace group = "P99-99.5" if  rank_scand >= .99  		& rank_scand < .995
	replace group = "P99.5-99.9" if  rank_scand >= .995 		& rank_scand < .999
	replace group = "P99.9-P99.95" if  rank_scand >= .999 		& rank_scand < .9995
	replace group = "P99.95-P99.99" if rank_scand >= .9995 & rank_scand < .9999
	replace group = "P99.99-P100" if rank_scand >= .9999

	gen pop = 1
	collapse (min) th_usd = wealthusd (mean) wealthusd (sum) nb_hsbc = hsbc nb_hsbc_pos = hsbc_pos pop tot_hsbc = amt_hsbc [fw = weight], by(group)
	rename pop weight
	gen frac = nb_hsbc / weight
	gen frac_pos = nb_hsbc_pos / weight
	order group th_usd wealthusd nb_hsbc nb_hsbc_pos weight frac frac_pos tot_hsbc
	export excel using "$out_hsbc", sheetmodify first(var) sh(Stata-fullpop2)

* Excluding HSBC wealth from wealth for ranking
	use "$root/WorkScandinavia/temp/big_scand.dta", clear
	replace amt_hsbc = 0 if amt_hsbc == . 
	replace wealthusd = max(0, wealthusd - amt_hsbc)
	cap drop rank_scand
	cumul wealthusd [fw=weight], gen(rank_scand)
	cap drop group
	gen group = "P0-50"
	replace group = "P50-90" if rank_scand >= .5  	& rank_scand < .9
	replace group = "P90-95" if  rank_scand >= .9 & rank_scand < .95
	replace group = "P95-99" if  rank_scand >= .95  		& rank_scand < .99
	replace group = "P99-99.5" if  rank_scand >= .99  		& rank_scand < .995
	replace group = "P99.5-99.9" if  rank_scand >= .995 		& rank_scand < .999
	replace group = "P99.9-P99.95" if  rank_scand >= .999 		& rank_scand < .9995
	replace group = "P99.95-P99.99" if rank_scand >= .9995 & rank_scand < .9999
	replace group = "P99.99-P100" if rank_scand >= .9999

	gen pop = 1
	collapse (min) th_usd = wealthusd (mean) wealthusd (sum) nb_hsbc = hsbc nb_hsbc_pos = hsbc_pos pop tot_hsbc = amt_hsbc [fw = weight], by(group)
	rename pop weight
	gen frac = nb_hsbc / weight
	gen frac_pos = nb_hsbc_pos / weight
	order group th_usd wealthusd nb_hsbc nb_hsbc_pos weight frac frac_pos tot_hsbc
	export excel using "$out_hsbc", sheetmodify first(var) sh(Stata-fullpop3)
