*! Computes fraction of households evading taxes by wealth group, with S.E.
* Computes average amont hidden by wealth group, with S.E.


*************************************************************************
* Fraction of households evading taxes by wealth group, with S.E. *
*************************************************************************

* HSBC, Panama, disclosers separately
	foreach binning in one two {
	cap erase "$root/WorkScandinavia/Output/Average_`binning'.xls"
	cap erase "$root/WorkScandinavia/Output/Average_`binning'.txt"
		foreach dummy in hsbc panama disc evader {

			if "`dummy'" == "hsbc" 	use "$root/WorkScandinavia/temp/big_scand.dta", clear
			if "`dummy'" == "panama" | "`dummy'" == "disc"  {
				use "$root/WorkScandinavia/temp/big_norswe.dta", clear
				replace amt_disc = 0 if amt_disc == . 
				replace wealthusd = wealthusd + amt_disc if ctry=="SWE"
				cap drop rank_scand
				cumul wealthusd [fw=weight], gen(rank_scand)
			}
			if "`dummy'" == "evader" {
				use "$root/WorkScandinavia/temp/big_norswe_with_hsbc.dta", clear
				replace amt_disc = 0 if amt_disc == . 
				replace wealthusd = wealthusd + amt_disc if ctry=="SWE"
				cap drop rank_scand
				cumul wealthusd [fw=weight], gen(rank_scand)
				gen evader = max(disc, hsbc)
			}	 
				

			quietly {
				// Prepare groups
				if 	"`binning'" == "one" { 		
					cap drop group
					gen group = "P0-90"
					replace group = "P90-95"		if rank_scand >= .9  	& rank_scand < .95
					replace group = "P95-99"		if rank_scand >= .95  	& rank_scand < .99
					replace group = "P99-99.5"		if rank_scand >= .99  	& rank_scand < .995
					replace group = "P99.5-99.9"	if rank_scand >= .995 	& rank_scand < .999
					replace group = "P99.9-P99.95"	if rank_scand >= .999 	& rank_scand < .9995
					replace group = "P99.95-P99.99"	if rank_scand >= .99950	& rank_scand < .99990
					replace group = "P99.99-P100"	if rank_scand >= .99990
				}
				if 	"`binning'" == "two" { 		
					cap drop group
					gen group = "P0-90"
					replace group = "P90-95"		if rank_scand >= .9  	& rank_scand < .95
					replace group = "P95-99"		if rank_scand >= .95  	& rank_scand < .99
					replace group = "P99-99.5"		if rank_scand >= .99  	& rank_scand < .995
					replace group = "P99.5-99.9"	if rank_scand >= .995 	& rank_scand < .999
					replace group = "P99.9-P99.95"	if rank_scand >= .999 	& rank_scand < .9995
					replace group = "P99.95-P100"	if rank_scand >= .99950	
				}

			* * 	// Fraction of evader by bin with bootstraped S.E.
			* 	cap drop bin
			* 	egen bin = group(group), label
			* }
			* 	di "`dummy' sample"
			* 	qui replace `dummy' = `dummy' * 100
			* 	drop if group == "P0-90"
			* 	set seed 1
			* 	reg `dummy' ibn.bin, nocons vce(bootstrap, rep(1000))
			* 	outreg2 using  "$root/WorkScandinavia/Output/Average_`binning'_boot.xls", append excel dec(2) noaster label ctitle("`dummy'")
			* 	margins bin, pwcompare(group)
			* 	* margins bin, pwcompare(pveffects group)

				// Fraction of evader by bin with robust S.E. (makes negligible difference with boostrap, but much faster)
				gen pop = 1
				collapse (sum) nb_`dummy' = `dummy' pop [fw = weight], by(group)
				qui su nb_`dummy'
				local nbevader = r(sum)
				rename pop weight
				gen freq1 = nb_`dummy'
				gen freq0 = weight - nb_`dummy'
				keep group freq*
				reshape long freq, i(group) j(`dummy')
				egen bin = group(group), label
			}
				di "`dummy' sample"
				replace `dummy' = `dummy' * 100
				qui reg `dummy' ibn.bin [fw=freq], nocons robust
				outreg2 using  "$root/WorkScandinavia/Output/Average_`binning'.xls", append excel dec(2) noaster label ctitle("`dummy'")  addstat(Number evaders, `nbevader')
				margins bin, pwcompare(group)
				margins bin, pwcompare(pveffects group)
		}
	}


/*
*************************************************************************
* Average amont hidden at HSBC (% of wealth) by wealth group, with S.E. *
*************************************************************************

 	foreach binning in one two {
 		quietly {
	 		use "$root/WorkScandinavia/temp/big_scand.dta", clear
			if 	"`binning'" == "one" { 	
				cap drop group
				gen group = "P0-90"
				replace group = "P90-95"		if rank_scand >= .9  	& rank_scand < .95
				replace group = "P95-99"		if rank_scand >= .95  	& rank_scand < .99
				replace group = "P99-99.5"		if rank_scand >= .99  	& rank_scand < .995
				replace group = "P99.5-99.9"	if rank_scand >= .995 	& rank_scand < .999
				replace group = "P99.9-P99.95"	if rank_scand >= .999 	& rank_scand < .9995
				replace group = "P99.95-P99.99"	if rank_scand >= .99950	& rank_scand < .99990
				replace group = "P99.99-P100"	if rank_scand >= .99990
			}
			if 	"`binning'" == "two" { 	
				cap drop group
				gen group = "P0-90"
				replace group = "P90-95"		if rank_scand >= .9  	& rank_scand < .95
				replace group = "P95-99"		if rank_scand >= .95  	& rank_scand < .99
				replace group = "P99-99.5"		if rank_scand >= .99  	& rank_scand < .995
				replace group = "P99.5-99.9"	if rank_scand >= .995 	& rank_scand < .999
				replace group = "P99.9-P99.95"	if rank_scand >= .999 	& rank_scand < .9995
				replace group = "P99.95-P100"	if rank_scand >= .99950	
			}
			cap drop bin
			egen bin = group(group), label
		}
		// Compute average amount hidden
			qui gen frac_hidden = amt_hsbc / wealthusd
			qui keep if hsbc_pos > 0
			replace frac_hidden = 100 * frac_hidden
			di "Wealth hidden (% true wealth)"
			replace frac_hidden = 100 if frac_hidden > 100
			* reg frac_hidden ibn.bin, nocons vce(bootstrap, rep(1000))  // makes negligible difference with robust
			reg frac_hidden ibn.bin, nocons robust 
			outreg2 using  "$root/WorkScandinavia/Output/Amounts_`binning'_boot.xls", excel dec(2) replace noaster label ctitle("Fraction of wealth hidden")
			margins bin, pwcompare(group)
	
}


*/
*************************************************************************
* Average amount hidden by Norwegian disclosers (% of wealth) by wealth group, with S.E. *
*************************************************************************

	use "....bighhold2006.dta", clear
	cap drop rank_scand
	qui cumul mwealth, gen (rank_scand)

	cap drop group
	qui gen group = "P0-90"
	qui replace group = "P90-95"		if rank_scand >= .9  	& rank_scand < .95
	qui replace group = "P95-99"		if rank_scand >= .95  	& rank_scand < .99
	qui replace group = "P99-99.5"		if rank_scand >= .99  	& rank_scand < .995
	qui replace group = "P99.5-99.9"	if rank_scand >= .995 	& rank_scand < .999
	qui replace group = "P99.9-P99.95"	if rank_scand >= .999 	& rank_scand < .9995
	qui replace group = "P99.95-P99.99"	if rank_scand >= .99950	& rank_scand < .99990
	qui replace group = "P99.99-P100"	if rank_scand >= .99990

	cap drop bin
	qui egen bin = group(group), label
		
	
	keep if vd_evader == 1 
	drop if vd_case_dropped == 1
	gen frac_hidden = disclosed_wealth07C / mwealth
	su frac_hidden, det
	replace frac_hidden = 100 * frac_hidden
	replace frac_hidden = 100 if frac_hidden > 100
	reg frac_hidden ibn.bin, nocons robust 
	outreg2 using "$root/WorkScandinavia/Output/Amounts.xls", excel dec(2) replace noaster label ctitle("Fraction of wealth hidden")
	margins bin, pwcompare(group)


*/
*************************************************************************
*  Predicted proba of HSBC evasion by small wealth bin of US$ 1 million *
*************************************************************************
/*

* Bin US$ 1 million wealth bins 
 use "$root/WorkScandinavia/temp/big_scand.dta", clear
 	forvalue i = 1/6 {
 		gen wealthusd`i' = wealthusd^`i'
 	}
 	logit hsbc wealthusd wealthusd2 wealthusd3 
 	* reg hsbc wealthusd wealthusd2 wealthusd3 
 	predict hsbc_pred
 	su hsbc_pred 
 	gen bin = .
 	local j = 1
 	forvalue i = 0/60 {
 		replace bin = `i' if wealthusd >= `i'*1e6 & wealthusd < `j'*1e6
 		local j = `j' + 1
 	}
 	collapse (min) wealthusd (mean) hsbc_pred hsbc [fw=weight], by(bin)
 	drop if bin == .
 	*twoway scatter (hsbc_pred hsbc wealthusd) 
 	twoway scatter (hsbc_pred wealthusd)  


* By quantiles of hsbc evaders wealth
use "$root/WorkScandinavia/temp/big_scand.dta", clear
	keep if wealthusd >= 1e6
	pctile thres = wealthusd if hsbc == 1, nq(15)
	xtile bin = wealthusd, cut(thres)
	* binscatter hsbc wealthusd, xq(bin)
	collapse (min) minw = wealthusd (mean) avgw = wealthusd hsbc, by(bin)
	 twoway scatter (hsbc minw)    || qfit hsbc minw

* By 10 million bins 
use "$root/WorkScandinavia/temp/big_scand.dta", clear
keep if wealthusd>=0
gen bin = 0
 	local j = 2
 	forvalue i = 1/5 {
 		replace bin = `i' if wealthusd >= `i'*1e7 & wealthusd < `j'*1e7
 		local j = `j' + 1
 	}
 	replace bin = 6 if  wealthusd >= 6e7
 	collapse (min) minw = wealthusd (mean)  hsbc [fw=weight], by(bin)
 	twoway scatter (hsbc minw)    || connect hsbc minw