
*! Computse time series of top wealth shares matching macro totals

*************************************************************************
* Norway *
*************************************************************************

* Export Norway small files totals to Excel
	#delimit;
	local marketwealth "mwealth ma_housing ma_housing_condo 
	ma_housing_leisure ma_f_housing ma_fix ma_equity ma_business ma_pension md_debt";
	local taxwealth 
	"a_housing_condo a_housing_leisure a_f_housing 
	a_business_prop a_business_other 
	a_shares_reg a_shares_nonreg a_bondfunds a_foreignshares a_f_shares 
	a_cash a_deposits a_bonds_reg a_f_bonds a_f_deposits 
	a_pension d_debt taxwealth a_total
	tax_wealth tax_income tax_all 
	a_pf_housing a_pf_shares a_pf_bonds a_pf_deposits p_netwealth
	a_movables a_f_business a_business sumofpart"; 
	#delimit cr

	foreach yr in 01 02 03 04 05 06 07 08 09 10 11 12 13  {
		use "$root/WorkNorway/SmallFiles/small`yr'hhold.dta", clear
		cap gen a_total=0
		cap gen sumofpart=0
		cap gen a_f_business=0
		cap gen sumofpart=0
		keep weight `marketwealth' `taxwealth' 
		gen year=20`yr'
		collapse (first) year (count) pop=weight (sum)  `marketwealth' `taxwealth' [fw=weight]
		foreach var of varlist `marketwealth' `taxwealth' {
			replace `var'=`var'/1e9
		}
		mkmat _all, matrix(year`yr')
	}
	foreach yr in 01 02 03 04 05 06 07 08 09 10 11 12 13 { 
		mat total= nullmat(total) \ year`yr'
	}
	putexcel A1=matrix(total, colnames) using "$root/WorkNorway/MacroNorway/AggregateWealthNorway.xlsx", sh(TotalSmall) modify keepcellformat


* Export Norway totals for taxable households (with taxwealth>=threshold)
	foreach yr in 01 02 03 04 05 06 07 08 09 10 11 12 13  {
		use "$root/WorkNorway/SmallFiles/small`yr'hhold.dta", clear
		cap gen a_total=0
		cap gen a_f_business=0
		cap gen sumofpart=0
		cap drop year
		gen year=20`yr'
		if `yr'==01 local threshold="120000"
		if `yr'==02 local threshold="120000"
		if `yr'==03 local threshold="120000"
		if `yr'==04 local threshold="120000"
		if `yr'==05 local threshold="151000"
		if `yr'==06 local threshold="200000"
		if `yr'==07 local threshold="220000"
		if `yr'==08 local threshold="350000"
		if `yr'==09 local threshold="470000"
		if `yr'==10 local threshold="700000"
		if `yr'==11 local threshold="700000"
		if `yr'==12 local threshold="750000"
		if `yr'==13 local threshold="870000"
		collapse (first) year (count) pop=weight (sum)  `marketwealth' `taxwealth' [fw=weight] if taxwealth>=`threshold'
		foreach var of varlist `marketwealth' `taxwealth' {
			replace `var'=`var'/1e9
		}
		mkmat _all, matrix(taxableyear`yr')
		mat taxabletotal= nullmat(taxabletotal) \ taxableyear`yr'
	}
	putexcel A1=matrix(taxabletotal, colnames) using "$root/ExcelFiles/AJZ2017AppendixB.xlsx", sh(taxbase) modify keepcellf


* Export top wealth shares Norway and compo, excluding disclosed wealth
	foreach part of numlist 1 {
		clear matrix
		if `part'==1 {
			local name     "topsh"
			local x        "ma_equity ma_fix ma_housing ma_business ma_pension"
			local xrank    "ma_equity ma_fix ma_housing ma_business ma_pension"
			*local control  "ttwealth"
			local unit     "hhold"
		}
		if `part'==2 {
			local name     "topsh"
			local x        "ma_equity ma_fix ma_housing ma_business ma_pension"
			local xrank    "ma_equity ma_fix ma_housing ma_business ma_pension"
			*local control  "ttwealth"
			local unit     "indiv"
		}
		if `part'==3 {
			local name     "off"
			local x        "vd_taxed_disclosed_wealth"
			local xrank    "ma_equity ma_fix ma_housing ma_business ma_pension"
			*local control  "ttwealth"
			local unit     "hhold"
		}
		if `part'==4 {
			local name     "off"
			local x        "vd_taxed_disclosed_wealth"
			local xrank    "ma_equity ma_fix ma_housing ma_business ma_pension"
			*local control  "ttwealth"
			local unit     "indiv"
		}
		global nbyears=13
		* Components (equity, fix, etc.) with suffix 0 to 6 to denote groups 
		foreach i of numlist 0/7 {
			local x`i'
			foreach w of local x {
	        	local x`i' `x`i'' `w'`i'
			}
		}
		* 0 suffix denotes aggregates 
		* 1: top 10%; 2: top 5%; 3: top 1%; 4: top 0.5%; 5: top 0.1%; 6: top 0.01%; 7: median
		local nbcompo: list sizeof x 
		matrix results = J($nbyears,(`nbcompo'+5)*8,.)
		#delimit;
		matrix colnames results = 
		year0 total  
				 wsu0 wm0 sh0 `x0'
		year1 w1 wm1 wsu1 sh1 `x1'
		year2 w2 wm2 wsu2 sh2 `x2'
		year3 w3 wm3 wsu3 sh3 `x3'
		year4 w4 wm4 wsu4 sh4 `x4'
		year5 w5 wm5 wsu5 sh5 `x5'
		year6 w6 wm6 wsu6 sh6 `x6'
		year7 w7 wm7 wsu7 sh7 `x7';
		#delimit cr
		* w = group threshold
		* wm = average income or wealth of group
		* wsu = total income or wealth of group
		* sh = income or wealth share of group
		local ii=0
		foreach yr in 01 02 03 04 05 06 07 08 09 10 11 12 13  {
			local ii=`ii'+1
			matrix results[`ii',1]=20`yr'
			use "$root/WorkNorway/SmallFiles/small`yr'`unit'.dta",clear
			cap drop if group==0
			replace ma_housing=ma_housing+md_debt
			drop md_debt

		* income/wealth and rank in the distribution
		egen x=rsum(`x')
		egen xrank=rsum(`xrank') 
		su x [fw=weight]
		local total=r(sum)
		matrix results[`ii',2]=`total'

		* Totals
		quietly: su x [w=weight]
		matrix results[`ii',3]=r(sum)
		matrix results[`ii',4]=r(mean) 
		matrix results[`ii',5]=results[`ii',3]/results[`ii',2] 
		* Totals by components 
		local kk=6
		foreach var of local x {
			quietly: su `var' [w=weight]
			matrix results[`ii',`kk']=r(sum)
					local kk=`kk'+1
		} 

		* Shares and composition by fractile
		local jj=6+`nbcompo'
		foreach fract of numlist 90 95 99 99.5 99.9 99.99 50 {

			matrix results[`ii',`jj']=20`yr' 
			quietly: su xrank [w=weight] if ptile_w>=float(`fract')
			matrix results[`ii',`jj'+1]=r(min)
			quietly: su x [w=weight] if ptile_w>=float(`fract')
			matrix results[`ii',`jj'+2]=r(mean)
			matrix results[`ii',`jj'+3]=r(sum)
			matrix results[`ii',`jj'+4]=results[`ii',`jj'+3]/results[`ii',2]
			
			local ll=`jj'+5
			foreach var of local x {
				quietly: su `var' [w=weight] if ptile_w>=float(`fract')
				matrix results[`ii',`ll']=r(sum)/results[`ii',2]
					local ll=`ll'+1 
			}
			local jj=`jj'+5+`nbcompo'
			}
		}
		xsvmat double results, fast names(col)
		* Rounding, saving
		foreach Y of numlist 0/7 {
		replace wm`Y'=round(wm`Y',1)
		replace wsu`Y'=round(wsu`Y',1)
		replace sh`Y'=round(sh`Y',0.00001)
		foreach var of local x {
			replace `var'`Y'=round(`var'`Y',0.00001)
		}
		}
		foreach Y of numlist  1/7 {
		replace w`Y'=round(w`Y',1)
		}
		mkmat _all, mat(results)
		putexcel A1=matrix(results, colnames) using "$root/ExcelFiles/AJZ2017AppendixB.xlsx", sh(`name'`unit') modify keepcellf
		}

