clear
set more off


*Directory for program files
global source 	"\\...\SourceData" 
global progs 	"\\...\CLEAN\prog" 
global data		"\\...\CLEAN\data" 
global output	"\\...\CLEAN\data\output" 
global temp	    "\\...\temp"

cap log close
log using $progs\sw_makedata1_individual_caractCLEAN_2017_06_21.log, replace



/*******************************************************************************
*                                              
* Construct socio-economic variables from various sources on individuals
*
* Age: have exact age at Dec.31 in income year.
* Immigration/emigration: only have continent, with detailes on Europe
*
* Country info is only on contintent level, with more details within Europe
*
***************************************************************************/

* Individual caracteristics, from Income and tax data, IoT-data

foreach yr in 99 00 01 02 03 04 05 06 07 08 09 10 11 12 13 14 15 {
use $source\iot`yr'_lev.dta, clear
  
  * keep those who are alive and registered as taxable to Sweden on December 31
  keep if brtbtr=="1"
  gen year=20`yr'
  replace year=1999 if year==2099
  tab year
  if year==1999 | year==2000  {
    duplicates drop lopnr, force
  }
  if year<2003 | year==2004  {
    gen Emigration=.
  }
  if year==1999  {
    rename binvar binvarut
	rename bciv bcivut
	rename bfamst bfamstut 
  }
  
  keep lopnr lopnr_fam year kommun bald bkon BBRN18 BBRN17 binvarut bcivut bfamstut fodelseland fodelseland_mor fodelseland_far medborgarskap SUN2000Niva_old SUN2000Inr Emigration
  rename lopnr ID
  label var ID 
  rename lopnr_fam ind_hhold
  
  rename kommun ind_county
  label var ind_county "county -kommun- Stockholm-0180"
  gen ind_stockholm=(ind_county=="0180")
  label var ind_stockholm "Stockholm county"
  tab ind_stockholm
  
  *age, in actual years
  if year==1999 {
   destring bald, replace
   destring bkon, replace
  }
  rename bald ind_age
  label var ind_age "Age at Dec31 of income year"
  drop if ind_age<0
  tab ind_age, m
  
  gen ind_male=1 if bkon==1
  replace ind_male=0 if bkon==2
  drop bkon
  label var ind_male "sex, 1 if male, 0 if female"
  
  gen ind_marital=3
  replace ind_marital=1 if bcivut=="OG"
  replace ind_marital=2 if bcivut=="G" | bcivut=="RP"
  replace ind_marital=4 if bcivut=="S" | bcivut=="SP"
  replace ind_marital=. if bcivut=="KE" | bcivut=="ME" | bcivut=="BE"
  drop bcivut
  label var ind_marital "1:unmarried, 2:married, 3:widow/er, 4:divorced"	
  
  tab bfamstut, m
  gen ind_fam=.
  replace ind_fam=1 if bfamstut=="110" | bfamstut=="120" | bfamstut=="130" | bfamstut=="140" | bfamstut=="150" | bfamstut=="160"
  replace ind_fam=2 if bfamstut=="210" | bfamstut=="230"
  replace ind_fam=3 if bfamstut=="311" | bfamstut=="312" | bfamstut=="313" | bfamstut=="314" | bfamstut=="315" | bfamstut=="316" | bfamstut=="317" | bfamstut=="318"
  replace ind_fam=4 if bfamstut=="321" | bfamstut=="322" | bfamstut=="323" | bfamstut=="324" | bfamstut=="325" | bfamstut=="326" | bfamstut=="327" | bfamstut=="328" 
  replace ind_fam=5 if bfamstut=="220" | bfamstut=="240" | bfamstut=="400" 
  label var ind_fam "1:Cuople, 2:SingleParentB18, 3:ChB18, 4:ChA18, 5:Single
  tab ind_fam, m
  drop bfamstut
  
  tab BBRN18, m
  tab BBRN17, m
  replace BBRN18=0 if BBRN18==.
  replace BBRN17=0 if BBRN17==.
  gen ind_children=BBRN18+BBRN17
  rename BBRN17 ind_children17
  label var ind_children "total number of children"
  label var ind_children17 "number children below 18"
  drop BBRN18
  
  gen ind_foreign_continent="      "
  replace ind_foreign_continent="SWEDEN" if fodelseland=="Sverige" | medborgarskap=="Sverige"
  replace ind_foreign_continent="NORDIC" if fodelseland=="Norden utom Sverige" | medborgarskap=="Norden utom Sverige"
  replace ind_foreign_continent="EU_NNO" if substr(fodelseland,1,3)=="EU2" | substr(medborgarskap,1,3)=="EU2"
  replace ind_foreign_continent="EUR_RE" if substr(fodelseland,1,5)=="Europ" | substr(medborgarskap,1,5)=="Europ"  | fodelseland=="Sovjetunionen" | medborgarskap=="Sovjetunionen"
  replace ind_foreign_continent="OCEANI" if fodelseland=="Oceanien" | medborgarskap=="Oceanien"
  replace ind_foreign_continent="NOR_AM" if fodelseland=="Nordamerika" | medborgarskap=="Nordamerika"
  replace ind_foreign_continent="SOU_AM" if fodelseland=="Sydamerika" | medborgarskap=="Sydamerika"
  replace ind_foreign_continent="AFRICA" if fodelseland=="Afrika" | medborgarskap=="Afrika"
  replace ind_foreign_continent="ASIA  " if fodelseland=="Asien" | medborgarskap=="Asien" 
  label var ind_foreign_continent "nationality or birth country- continent level- foreign connection"
  tab ind_foreign_continent fodelseland, m
  tab ind_foreign_continent medborgarskap, m
  drop fodelseland medborgarskap
  
  tab fodelseland_mor, m
  gen ind_foreign_continent_mother="      "
  replace ind_foreign_continent_mother="SWEDEN" if fodelseland_mor=="Sverige" 
  replace ind_foreign_continent_mother="NORDIC" if fodelseland_mor=="Norden utom Sverige" 
  replace ind_foreign_continent_mother="EU_NNO" if substr(fodelseland_mor,1,3)=="EU2"
  replace ind_foreign_continent_mother="EUR_RE" if substr(fodelseland_mor,1,5)=="Europ" | fodelseland_mor=="Sovjetunionen" 
  replace ind_foreign_continent_mother="OCEANI" if fodelseland_mor=="Oceanien" 
  replace ind_foreign_continent_mother="NOR_AM" if fodelseland_mor=="Nordamerika" 
  replace ind_foreign_continent_mother="SOU_AM" if fodelseland_mor=="Sydamerika" 
  replace ind_foreign_continent_mother="AFRICA" if fodelseland_mor=="Afrika" 
  replace ind_foreign_continent_mother="ASIA  " if fodelseland_mor=="Asien" 
  label var ind_foreign_continent_mother "birth continent mother- foreign connection"
  tab ind_foreign_continent_mother 

  gen ind_foreign_continent_father="      "
  tab fodelseland_far, m
  replace ind_foreign_continent_father="SWEDEN" if fodelseland_far=="Sverige" 
  replace ind_foreign_continent_father="NORDIC" if fodelseland_far=="Norden utom Sverige" 
  replace ind_foreign_continent_father="EU_NNO" if substr(fodelseland_far,1,3)=="EU2"
  replace ind_foreign_continent_father="EUR_RE" if substr(fodelseland_far,1,5)=="Europ" | fodelseland_mor=="Sovjetunionen" 
  replace ind_foreign_continent_father="OCEANI" if fodelseland_far=="Oceanien" 
  replace ind_foreign_continent_father="NOR_AM" if fodelseland_far=="Nordamerika" 
  replace ind_foreign_continent_father="SOU_AM" if fodelseland_far=="Sydamerika" 
  replace ind_foreign_continent_father="AFRICA" if fodelseland_far=="Afrika" 
  replace ind_foreign_continent_father="ASIA  " if fodelseland_far=="Asien" 
  label var ind_foreign_continent_father "birth continent father- foreign connection"
  tab ind_foreign_continent_father
  tab ind_foreign_continent_father ind_foreign_continent_mother
  drop fodelseland_mor fodelseland_far 
   
 *** Make dummy for foreign born or foreign nationality, and for foreign parent
  gen ind_foreigner=1
  replace ind_foreigner=0 if ind_foreign_continent=="SWEDEN" 
  label variable ind_foreigner "dummy equal to 1 if foreigner - foreign born or nationality"
  tab ind_foreigner, m
  gen ind_foreign_parent=(ind_foreign_continent_father!="SWEDEN" & ind_foreign_continent_mother!="SWEDEN")
  label variable ind_foreigner "dummy equal to 1 if foreign born parent"
  replace ind_foreign_parent=. if ind_foreign_continent_father=="      " & ind_foreign_continent_mother=="      "
  tab ind_foreign_parent, m
  tab ind_foreigner ind_foreign_parent
  
  *emigration/immigration info
  rename Emigration ind_emigrates_current_year
  tostring binvarut, replace
  replace   binvarut="." if binvarut=="0"
  gen ind_immigration_year=substr(binvarut,1,4)
  destring ind_immigration_year, replace
  label var ind_immigration_year "immigrating this year"
  drop binvarut 

* Education info
  tab SUN2000Niva_old, m
  tab SUN2000Inr, m
  gen ind_edulevel=""
  replace ind_edulevel="0" if SUN2000Niva_old=="0" 
  replace ind_edulevel="1" if SUN2000Niva_old=="1" | SUN2000Niva_old=="2"
  replace ind_edulevel="2" if SUN2000Niva_old=="3" 
  replace ind_edulevel="3" if SUN2000Niva_old=="4" | SUN2000Niva_old=="5" | SUN2000Niva_old=="6" | SUN2000Niva_old=="7"
  label var ind_edulevel "Eucation level: 1:primary 2:secundary 3:tertiary"
  tab ind_edulevel, m
  gen ind_university=(ind_edulevel=="3")
  label variable ind_university "completed university degree"
  tab ind_university, m
  gen ind_edu_bus=(substr(SUN2000Inr,1,2)=="34") 
  label var ind_edu_bus "higher education in business administration"
  tab ind_edu_bus, m
  drop SUN2000Inr  SUN2000Niva_old
  
  compress  
  sort ID
save $temp\charak`yr'.dta, replace 

*make subset to make panel and create married/divorced variables 
  keep ID year  ind_marital 
save $temp\emi`yr'.dta, replace 
}

****************************************************************************************************
*make variable indicating getting married/divorced during the year, and the year of emigration.
use $temp\emi99.dta, clear
foreach yr in 00 01 02 03 04 05 06 07 08 09 10 11 12 13 14 15 {
  append using $temp\emi`yr'.dta
  }
 
  *make indicator for marriage/divorce
  tab ind_marital, m
  sort ID year
  egen pers=group(ID)
  xtset pers year
  gen lag_marital=l.ind_marital
  gen lag_ID=l.ID
** Make indicator for divorce or marriage
  gen ind_divorced=0
  by pers: replace ind_divorced=1 if lag_marital==2 & ind_marital==4 
  replace ind_divorced=. if ind_marital==.
  label variable ind_divorced "divorced during the year"
  tab ind_divorced, m
  gen ind_married=0
  replace ind_married=1 if ind_marital==2 & (lag_marital==1 | lag_marital==4 | lag_marital==3)
  replace ind_married=. if ind_marital==.
  label variable ind_married "got married during the year
  tab ind_married, m
  keep ID year ind_divorced ind_married
save $temp\mar_pan.dta, replace
 
*make annual datasets with married info, and that defines the sample
foreach yr in 99 00 01 02 03 04 05 06 07 08 09 10 11 12 13 14 15 { 
use $temp\mar_pan.dta, clear
  replace year=2099 if year==1999
  keep if year==20`yr'
  keep ID ind_divorced ind_married
  sort ID
save $temp\mar`yr'.dta, replace
}
 
  use $temp\mar99.dta, clear
  replace ind_divorced=.
  replace ind_married=.
  sort ID
  save $temp\mar99.dta, replace
 ***********

*emigration year
foreach yr in 99 00 01 02 03 04 05 06 07 08 09 10 11 12 13 14 15 { 
use $temp\charak`yr'.dta, clear
  keep ID year ind_emigrates_current_year
  keep if ind_emigrates_current_year==1
  rename year ind_emigration_year
  keep ID ind_emigration_year
save $temp\eyear`yr'.dta, replace 
}
 
*make a full dataset with emigration year
use $temp\eyear99.dta, clear
foreach yr in 00 01 02 03 04 05 06 07 08 09 10 11 12 13 14 15 { 
 append using $temp\eyear`yr'.dta
}
  sort ID ind_emigration_year
  duplicates report ID
  by ID: keep if _n==1
  label var ind_emigration_year "year of emigration, keep first year if dupl"
  sort ID
  tab ind_emigration_year, m
save $temp\eyear_pan.dta, replace
 
********************************************************************************
 *Add on this info to the characteristic dataset
 
foreach yr in 99 00 01 02 03 04 05 06 07 08 09 10 11 12 13 14 15 { 
use $temp\charak`yr'.dta, clear
  sort ID
  merge 1:1 ID using $temp\mar`yr'.dta
 *the using data set defines hte population, have removed those dead
  drop if _m==2
  drop _m
  sort ID
  merge 1:1 ID using $temp\eyear_pan.dta
  drop if _m==2
  drop _m
  gen ind_emigrates=(ind_emigration_year!=.)
  gen ind_immigrates=(ind_immigration_year!=.)
  label var ind_emigrates "emigrates at some point, dummy"
  label var ind_immigrates "immigrates at some point, dummy"
 
  compress
  sort ID
  d, det
  sum
save $data\perskar_`yr'.dta, replace
}

*********************************************************************************
 
clear
log close



