clear
set more off

global source 	"\\...\SourceData" 
global progs 	"\\...\CLEAN\prog" 
global data		"\\...\CLEAN\data" 
global output	"\\...\CLEAN\data\output" 
global temp	    "\\...\temp"


cap log close
log using $progs\sw_makedata2_incomeCLEAN_2017_06_21.log, replace

/*************************************************************************************
*
* Make various income variables
*
*************************************************************************************/

foreach yr in 99 00 01 02 03 04 05 06 07 08 09 10 11 12 13 14 15 {
use $source\iot`yr'_lev.dta, clear  
  gen year=20`yr'
  replace year=1999 if year==2099
  tab year
  sum
  if year==1999 | year==2000  {
  duplicates drop lopnr, force
  } 
  rename lopnr ID

***CAPITAL GAINS
 gen i_kg=kv-kf
 label var i_kg "domestic net taxable realized capital gains"

*** CAPITAL INCOME
 gen i_cap_inc=kiranta
 label var i_cap_inc "capital income excl gain"

*** PENSIONS
 *There was a pension reform that implies a break in the data btw 2002 and 2003. 
 if year==1999 | year==2000 | year==2001 | year==2002 {
  gen i_pensions = pkupens
  }
 if year>=2003 {
  gen i_pensions = paldp + pavtal + ppriv
  }
 label var i_pensions "total pension income-shift2003"

  
****BUSINESS INCOME
 if year<=2002   {
  gen i_business=nrv
 }
 if year>=2003 {
  gen i_business=cftag
 }
 label variable i_business "self-employed busines income, not for 1999-2002 or 2004"
 
***WAGE   
 gen i_wage=carb
 label variable i_wage "wage income"
  * carb            long    %12.0g                RTBSI Arbetsinkomst
 
***TOTAL EARNED INCOME
 gen i_earned_inc = ctxfvi
 label var i_earned_inc "total earned income"

***TOTAL TAXABLE INCOME
gen i_taxable_inc = cbefvi 
label var i_taxable_inc "total taxble income" 

***TAX  
gen tax_total=sslut
label var tax_total "total tax, slutlig skatt"
  
 if year>= 2007 {
 gen sform =0
 } 
gen tax_wealth = sform
label var tax_wealth "wealth tax, until 2007" 

  if year>= 2008 {
  rename sfavg sfast
  } 
gen tax_housing=sfast 
label var tax_housing "housing tax - fastighetsskatt"

gen i_inc= i_wage + i_cap_inc + i_pension + i_business 
label variable i_inc "total taxable income excluding KG"

gen i_inckg = i_inc + max(i_kg,0) 
label var i_inckg "total income incl. KG"
 
gen i_linc=i_wage + i_pension + i_business
label var i_linc "total income from labor and self-employed business" 

keep ID tax_* i_* kkuutd
d, fullname
sum
total tax_* i_* kkuutd

compress
sort ID

save $data\income_`yr'.dta, replace
}

**************************************

log close
clear  
 
 
  
