
clear
set more off


*Directory for program files
global source 	"\\...\SourceData" 
global progs 	"\\...\CLEAN\prog" 
global data		"\\...\CLEAN\data" 
global output	"\\...\CLEAN\data\output" 
global temp	    "\\...\temp"
global smallfiles "\\m...\CLEAN\data\smallfiles"


cap log close
log using $progs\sw_smallfilesINEQpaperCLEAN_2017_06_22.log, replace


/*************************************************************************************
**************************************************************************************
*
* Program that creates big and small files with all demo, income, wealth variables 
* Part A creates big files at individual and household level
* Part B creates small files of averages by wealth x income groups
* Part C creates small ranked by income gropus, as wealth info only exists until 2007

****WE ONLY HAVE WEALTH INFO UNTIL 2007



**************************************************************************************
*************************************************************************************/



**************************** PART A  * CREATES BIG FILES *******************
 						 
***************************************************************************************
						* CREATE SOCIO-DEMOGRAPHIC CHARACTERISTICS *
***************************************************************************************

*  do "$prog\makedata1_individual_caracteristics.do"


***************************************************************************************
						* CREATE INCOME AND WEALTH DATA *
***************************************************************************************

* do "$prog\sw_makedata2_income.do"

* do "$prog\sw_makedata2_wealth.do"


* Wealth data only exist until 2007. After:  create empty datasets of missing values
foreach yr in 08 09 10 11 12 13 14 15 {
use $data\wealth_07.dta, clear
  quietly: ds ID, not
   foreach var of varlist `r(varlist)' {
    replace `var'=.
   }
  compress
save $data\wealth_`yr'.dta, replace
}



***************************************************************************************
			 * MERGE SOCIO-DEMO, INCOME & WEALTH DATA INTO BIG.DTA *
***************************************************************************************


foreach yr in 99 00 01 02 03 04 05 06 07 08 09 10 11 12 13 14 15 {

*start with socio-demographic dataset, this is our base sample 
use $data\perskar_`yr'.dta, clear
  sort ID 
  destring ind_edulevel ind_county , replace
  gen x=1 if ind_male==1
  drop ind_male
  rename x ind_male

*add evader info

  merge 1:1 ID using  $data\ev_panel_only1.dta
  drop if _m==2
  *generate evader dummies
  gen ev_suspected=(_m==3)
  label var ev_suspected "at some point investigated for offshore evasion"
  drop _m 
  sort ID
  tab ev_evader ev_suspected, m
  foreach var in ev_has_decision ev_r_transfers ev_r_creditcard ev_r_other ev_r_panama ev_r_missing ev_evader ev_suspected ev_case_closed ev_case_dropped ev_case_othercontr ev_case_in_process ev_case_not_started {
	replace `var'=0 if `var'==.
  }
 
*add income data
  merge 1:1 ID using $data\income_`yr'.dta
  keep if _m==3
  drop _m 
  sort ID

*add wealth data
  merge 1:1 ID using $data\wealth_`yr'.dta
  drop if _m==2
  drop _m 
  sort ID
* Saves rank in wealth distribution (individual-level) in hard

  cumul mwealth if mwealth!=. & ind_age>=20, gen(rank_w) 

  tab year
  compress
  sort ID
  d, fullname
  sum
save $data\big_`yr'.dta, replace
}

******

clear
cap log close
